@@ -31,7 +31,6 @@ IDL Parser.
 Converts a YAML document to an idl.syntax tree.
 Only validates the document is syntatically correct, not semantically.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 from abc import ABCMeta, abstractmethod
 import io
@@ -55,7 +54,8 @@ class _RuleDesc(object):
     - scalar_or_sequence - means a scalar or sequence node, populates a list
     - sequence - a sequence node, populates a list
     - mapping - a mapping node, calls another parser
-    mapping_parser_func is only called when parsing a mapping yaml node
+    - scalar_or_mapping - means a scalar of mapping node, populates a struct
+    mapping_parser_func is only called when parsing a mapping or scalar_or_mapping yaml node
     """
 
     # TODO: after porting to Python 3, use an enum
@@ -63,11 +63,11 @@ class _RuleDesc(object):
     OPTIONAL = 2
 
     def __init__(self, node_type, required=OPTIONAL, mapping_parser_func=None):
-        # type: (unicode, int, Callable[[errors.ParserContext,yaml.nodes.MappingNode], Any]) -> None
+        # type: (str, int, Callable[[errors.ParserContext,yaml.nodes.MappingNode], Any]) -> None
         """Construct a parser rule description."""
-        assert required == _RuleDesc.REQUIRED or required == _RuleDesc.OPTIONAL
+        assert required in (_RuleDesc.REQUIRED, _RuleDesc.OPTIONAL)
 
-        self.node_type = node_type  # type: unicode
+        self.node_type = node_type  # type: str
         self.required = required  # type: int
         self.mapping_parser_func = mapping_parser_func  # type: Callable[[errors.ParserContext,yaml.nodes.MappingNode], Any]
 
@@ -75,9 +75,9 @@ class _RuleDesc(object):
 def _generic_parser(
         ctxt,  # type: errors.ParserContext
         node,  # type: Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]
-        syntax_node_name,  # type: unicode
+        syntax_node_name,  # type: str
         syntax_node,  # type: Any
-        mapping_rules  # type: Dict[unicode, _RuleDesc]
+        mapping_rules  # type: Dict[str, _RuleDesc]
 ):  # type: (...) -> None
     # pylint: disable=too-many-branches
     field_name_set = set()  # type: Set[str]
@@ -108,20 +108,24 @@ def _generic_parser(
             elif rule_desc.node_type == "sequence":
                 if ctxt.is_scalar_sequence(second_node, first_name):
                     syntax_node.__dict__[first_name] = ctxt.get_list(second_node)
+            elif rule_desc.node_type == "scalar_or_mapping":
+                if ctxt.is_scalar_or_mapping_node(second_node, first_name):
+                    syntax_node.__dict__[first_name] = rule_desc.mapping_parser_func(
+                        ctxt, second_node)
             elif rule_desc.node_type == "mapping":
                 if ctxt.is_mapping_node(second_node, first_name):
                     syntax_node.__dict__[first_name] = rule_desc.mapping_parser_func(
                         ctxt, second_node)
             else:
-                raise errors.IDLError("Unknown node_type '%s' for parser rule" %
-                                      (rule_desc.node_type))
+                raise errors.IDLError(
+                    "Unknown node_type '%s' for parser rule" % (rule_desc.node_type))
         else:
             ctxt.add_unknown_node_error(first_node, syntax_node_name)
 
         field_name_set.add(first_name)
 
     # Check for any missing required fields
-    for name, rule_desc in mapping_rules.items():
+    for name, rule_desc in list(mapping_rules.items()):
         if not rule_desc.required == _RuleDesc.REQUIRED:
             continue
 
@@ -132,16 +136,16 @@ def _generic_parser(
             if syntax_node.__dict__[name] is None:
                 ctxt.add_missing_required_field_error(node, syntax_node_name, name)
         else:
-            raise errors.IDLError("Unknown node_type '%s' for parser required rule" %
-                                  (rule_desc.node_type))
+            raise errors.IDLError(
+                "Unknown node_type '%s' for parser required rule" % (rule_desc.node_type))
 
 
 def _parse_mapping(
         ctxt,  # type: errors.ParserContext
         spec,  # type: syntax.IDLSpec
         node,  # type: Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]
-        syntax_node_name,  # type: unicode
-        func  # type: Callable[[errors.ParserContext,syntax.IDLSpec,unicode,Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]], None]
+        syntax_node_name,  # type: str
+        func  # type: Callable[[errors.ParserContext,syntax.IDLSpec,str,Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]], None]
 ):  # type: (...) -> None
     """Parse a top-level mapping section in the IDL file."""
     if not ctxt.is_mapping_node(node, syntax_node_name):
@@ -154,6 +158,38 @@ def _parse_mapping(
         func(ctxt, spec, first_name, second_node)
 
 
+def _parse_initializer(ctxt, node):
+    # type: (errors.ParserContext, Union[yaml.nodes.ScalarNode, yaml.nodes.MappingNode]) -> syntax.GlobalInitializer
+    """Parse a global initializer."""
+    init = syntax.GlobalInitializer(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+
+    if node.id == 'scalar':
+        init.name = node.value
+        return init
+
+    _generic_parser(ctxt, node, "initializer", init, {
+        "register": _RuleDesc('scalar', _RuleDesc.REQUIRED),
+        "store": _RuleDesc('scalar'),
+    })
+
+    return init
+
+
+def _parse_config_global(ctxt, node):
+    # type: (errors.ParserContext, yaml.nodes.MappingNode) -> syntax.ConfigGlobal
+    """Parse global settings for config options."""
+    config = syntax.ConfigGlobal(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+
+    _generic_parser(
+        ctxt, node, "configs", config, {
+            "section": _RuleDesc("scalar"),
+            "source": _RuleDesc("scalar_or_sequence"),
+            "initializer": _RuleDesc("scalar_or_mapping", mapping_parser_func=_parse_initializer),
+        })
+
+    return config
+
+
 def _parse_global(ctxt, spec, node):
     # type: (errors.ParserContext, syntax.IDLSpec, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
     """Parse a global section in the IDL file."""
@@ -162,10 +198,11 @@ def _parse_global(ctxt, spec, node):
 
     idlglobal = syntax.Global(ctxt.file_name, node.start_mark.line, node.start_mark.column)
 
-    _generic_parser(ctxt, node, "global", idlglobal, {
-        "cpp_namespace": _RuleDesc("scalar"),
-        "cpp_includes": _RuleDesc("scalar_or_sequence"),
-    })
+    _generic_parser(
+        ctxt, node, "global", idlglobal, {
+            "cpp_namespace": _RuleDesc("scalar"), "cpp_includes": _RuleDesc("scalar_or_sequence"),
+            "configs": _RuleDesc("mapping", mapping_parser_func=_parse_config_global)
+        })
 
     spec.globals = idlglobal
 
@@ -182,7 +219,7 @@ def _parse_imports(ctxt, spec, node):
 
 
 def _parse_type(ctxt, spec, name, node):
-    # type: (errors.ParserContext, syntax.IDLSpec, unicode, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
+    # type: (errors.ParserContext, syntax.IDLSpec, str, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
     """Parse a type section in the IDL file."""
     if not ctxt.is_mapping_node(node, "type"):
         return
@@ -204,6 +241,55 @@ def _parse_type(ctxt, spec, name, node):
     spec.symbols.add_type(ctxt, idltype)
 
 
+def _parse_expression(ctxt, node):
+    # type: (errors.ParserContext, Union[yaml.nodes.ScalarNode,yaml.nodes.MappingNode]) -> syntax.Expression
+    """Parse an expression as either a scalar or a mapping."""
+    expr = syntax.Expression(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+
+    if node.id == 'scalar':
+        expr.literal = node.value
+        return expr
+
+    _generic_parser(ctxt, node, "expr", expr, {
+        "expr": _RuleDesc('scalar', _RuleDesc.REQUIRED),
+        "is_constexpr": _RuleDesc('bool_scalar'),
+    })
+
+    return expr
+
+
+def _parse_validator(ctxt, node):
+    # type: (errors.ParserContext, yaml.nodes.MappingNode) -> syntax.Validator
+    """Parse a validator for a field."""
+    validator = syntax.Validator(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+
+    _generic_parser(
+        ctxt, node, "validator", validator, {
+            "gt": _RuleDesc("scalar_or_mapping", mapping_parser_func=_parse_expression),
+            "lt": _RuleDesc("scalar_or_mapping", mapping_parser_func=_parse_expression),
+            "gte": _RuleDesc("scalar_or_mapping", mapping_parser_func=_parse_expression),
+            "lte": _RuleDesc("scalar_or_mapping", mapping_parser_func=_parse_expression),
+            "callback": _RuleDesc("scalar"),
+        })
+
+    return validator
+
+
+def _parse_condition(ctxt, node):
+    # type: (errors.ParserContext, yaml.nodes.MappingNode) -> syntax.Condition
+    """Parse a condition."""
+    condition = syntax.Condition(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+
+    _generic_parser(
+        ctxt, node, "condition", condition, {
+            "preprocessor": _RuleDesc("scalar"),
+            "constexpr": _RuleDesc("scalar"),
+            "expr": _RuleDesc("scalar"),
+        })
+
+    return condition
+
+
 def _parse_field(ctxt, name, node):
     # type: (errors.ParserContext, str, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> syntax.Field
     """Parse a field in a struct/command in the IDL file."""
@@ -220,6 +306,7 @@ def _parse_field(ctxt, name, node):
             "default": _RuleDesc('scalar'),
             "supports_doc_sequence": _RuleDesc("bool_scalar"),
             "comparison_order": _RuleDesc("int_scalar"),
+            "validator": _RuleDesc('mapping', mapping_parser_func=_parse_validator),
             "non_const_getter": _RuleDesc("bool_scalar"),
         })
 
@@ -344,7 +431,7 @@ def _parse_chained_structs(ctxt, node):
 
 
 def _parse_struct(ctxt, spec, name, node):
-    # type: (errors.ParserContext, syntax.IDLSpec, unicode, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
+    # type: (errors.ParserContext, syntax.IDLSpec, str, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
     """Parse a struct section in the IDL file."""
     if not ctxt.is_mapping_node(node, "struct"):
         return
@@ -401,7 +488,7 @@ def _parse_enum_values(ctxt, node):
 
 
 def _parse_enum(ctxt, spec, name, node):
-    # type: (errors.ParserContext, syntax.IDLSpec, unicode, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
+    # type: (errors.ParserContext, syntax.IDLSpec, str, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
     """Parse an enum section in the IDL file."""
     if not ctxt.is_mapping_node(node, "struct"):
         return
@@ -423,7 +510,7 @@ def _parse_enum(ctxt, spec, name, node):
 
 
 def _parse_command(ctxt, spec, name, node):
-    # type: (errors.ParserContext, syntax.IDLSpec, unicode, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
+    # type: (errors.ParserContext, syntax.IDLSpec, str, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
     """Parse a command section in the IDL file."""
     if not ctxt.is_mapping_node(node, "command"):
         return
@@ -446,10 +533,9 @@ def _parse_command(ctxt, spec, name, node):
             "generate_comparison_operators": _RuleDesc("bool_scalar"),
         })
 
-    # TODO: support the first argument as UUID depending on outcome of Catalog Versioning changes.
     valid_commands = [
         common.COMMAND_NAMESPACE_CONCATENATE_WITH_DB, common.COMMAND_NAMESPACE_IGNORED,
-        common.COMMAND_NAMESPACE_TYPE
+        common.COMMAND_NAMESPACE_TYPE, common.COMMAND_NAMESPACE_CONCATENATE_WITH_DB_OR_UUID
     ]
 
     if command.namespace:
@@ -471,8 +557,96 @@ def _parse_command(ctxt, spec, name, node):
     spec.symbols.add_command(ctxt, command)
 
 
+def _parse_server_parameter_class(ctxt, node):
+    # type: (errors.ParserContext, Union[yaml.nodes.ScalarNode,yaml.nodes.MappingNode]) -> syntax.ServerParameterClass
+    """Parse a server_parameter.cpp_class as either a scalar or a mapping."""
+    spc = syntax.ServerParameterClass(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+
+    if node.id == 'scalar':
+        spc.name = node.value
+        return spc
+
+    _generic_parser(
+        ctxt, node, "cpp_class", spc, {
+            "name": _RuleDesc('scalar', _RuleDesc.REQUIRED),
+            "data": _RuleDesc('scalar'),
+            "override_ctor": _RuleDesc('bool_scalar'),
+            "override_set": _RuleDesc('bool_scalar'),
+        })
+
+    return spc
+
+
+def _parse_server_parameter(ctxt, spec, name, node):
+    # type: (errors.ParserContext, syntax.IDLSpec, str, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
+    """Parse a server_parameters section in the IDL file."""
+    if not ctxt.is_mapping_node(node, "server_parameters"):
+        return
+
+    param = syntax.ServerParameter(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+    param.name = name
+
+    # Declare as local to avoid ugly formatting with long line.
+    map_class = _parse_server_parameter_class
+
+    _generic_parser(
+        ctxt, node, "server_parameters", param, {
+            "set_at": _RuleDesc('scalar_or_sequence', _RuleDesc.REQUIRED),
+            "description": _RuleDesc('scalar', _RuleDesc.REQUIRED),
+            "cpp_vartype": _RuleDesc('scalar'),
+            "cpp_varname": _RuleDesc('scalar'),
+            "condition": _RuleDesc('mapping', mapping_parser_func=_parse_condition),
+            "redact": _RuleDesc('bool_scalar'),
+            "default": _RuleDesc('scalar_or_mapping', mapping_parser_func=_parse_expression),
+            "test_only": _RuleDesc('bool_scalar'),
+            "deprecated_name": _RuleDesc('scalar_or_sequence'),
+            "validator": _RuleDesc('mapping', mapping_parser_func=_parse_validator),
+            "on_update": _RuleDesc("scalar"),
+            "cpp_class": _RuleDesc('scalar_or_mapping', mapping_parser_func=map_class),
+        })
+
+    spec.server_parameters.append(param)
+
+
+def _parse_config_option(ctxt, spec, name, node):
+    # type: (errors.ParserContext, syntax.IDLSpec, str, Union[yaml.nodes.MappingNode, yaml.nodes.ScalarNode, yaml.nodes.SequenceNode]) -> None
+    """Parse a configs section in the IDL file."""
+    if not ctxt.is_mapping_node(node, "configs"):
+        return
+
+    option = syntax.ConfigOption(ctxt.file_name, node.start_mark.line, node.start_mark.column)
+    option.name = name
+
+    _generic_parser(
+        ctxt, node, "configs", option, {
+            "short_name": _RuleDesc('scalar'),
+            "single_name": _RuleDesc('scalar'),
+            "deprecated_name": _RuleDesc('scalar_or_sequence'),
+            "deprecated_short_name": _RuleDesc('scalar_or_sequence'),
+            "description": _RuleDesc('scalar_or_mapping', _RuleDesc.REQUIRED, _parse_expression),
+            "section": _RuleDesc('scalar'),
+            "arg_vartype": _RuleDesc('scalar', _RuleDesc.REQUIRED),
+            "cpp_vartype": _RuleDesc('scalar'),
+            "cpp_varname": _RuleDesc('scalar'),
+            "condition": _RuleDesc('mapping', mapping_parser_func=_parse_condition),
+            "conflicts": _RuleDesc('scalar_or_sequence'),
+            "requires": _RuleDesc('scalar_or_sequence'),
+            "hidden": _RuleDesc('bool_scalar'),
+            "redact": _RuleDesc('bool_scalar'),
+            "default": _RuleDesc('scalar_or_mapping', mapping_parser_func=_parse_expression),
+            "implicit": _RuleDesc('scalar_or_mapping', mapping_parser_func=_parse_expression),
+            "source": _RuleDesc('scalar_or_sequence'),
+            "canonicalize": _RuleDesc('scalar'),
+            "duplicate_behavior": _RuleDesc('scalar'),
+            "positional": _RuleDesc('scalar'),
+            "validator": _RuleDesc('mapping', mapping_parser_func=_parse_validator),
+        })
+
+    spec.configs.append(option)
+
+
 def _prefix_with_namespace(cpp_namespace, cpp_name):
-    # type: (unicode, unicode) -> unicode
+    # type: (str, str) -> str
     """Preface a C++ type name with a namespace if not already qualified or a primitive type."""
     if "::" in cpp_name or cpp_types.is_primitive_scalar_type(cpp_name):
         return cpp_name
@@ -502,7 +676,7 @@ def _propagate_globals(spec):
 
 
 def _parse(stream, error_file_name):
-    # type: (Any, unicode) -> syntax.IDLParsedSpec
+    # type: (Any, str) -> syntax.IDLParsedSpec
     """
     Parse a YAML document into an idl.syntax tree.
 
@@ -549,6 +723,10 @@ def _parse(stream, error_file_name):
             _parse_mapping(ctxt, spec, second_node, 'structs', _parse_struct)
         elif first_name == "commands":
             _parse_mapping(ctxt, spec, second_node, 'commands', _parse_command)
+        elif first_name == "server_parameters":
+            _parse_mapping(ctxt, spec, second_node, "server_parameters", _parse_server_parameter)
+        elif first_name == "configs":
+            _parse_mapping(ctxt, spec, second_node, "configs", _parse_config_option)
         else:
             ctxt.add_unknown_root_node_error(first_node)
 
@@ -562,11 +740,9 @@ def _parse(stream, error_file_name):
     return syntax.IDLParsedSpec(spec, None)
 
 
-class ImportResolverBase(object):
+class ImportResolverBase(object, metaclass=ABCMeta):
     """Base class for resolving imported files."""
 
-    __metaclass__ = ABCMeta
-
     def __init__(self):
         # type: () -> None
         """Construct a ImportResolver."""
@@ -574,19 +750,19 @@ class ImportResolverBase(object):
 
     @abstractmethod
     def resolve(self, base_file, imported_file_name):
-        # type: (unicode, unicode) -> unicode
+        # type: (str, str) -> str
         """Return the complete path to an imported file name."""
         pass
 
     @abstractmethod
     def open(self, resolved_file_name):
-        # type: (unicode) -> Any
+        # type: (str) -> Any
         """Return an io.Stream for the requested file."""
         pass
 
 
 def parse(stream, input_file_name, resolver):
-    # type: (Any, unicode, ImportResolverBase) -> syntax.IDLParsedSpec
+    # type: (Any, str, ImportResolverBase) -> syntax.IDLParsedSpec
     """
     Parse a YAML document into an idl.syntax tree.
 
@@ -600,13 +776,13 @@ def parse(stream, input_file_name, resolver):
     if root_doc.errors:
         return root_doc
 
-    imports = []  # type: List[Tuple[common.SourceLocation, unicode, unicode]]
-    needs_include = []  # type: List[unicode]
+    imports = []  # type: List[Tuple[common.SourceLocation, str, str]]
+    needs_include = []  # type: List[str]
     if root_doc.spec.imports:
         imports = [(root_doc.spec.imports, input_file_name, import_file_name)
                    for import_file_name in root_doc.spec.imports.imports]
 
-    resolved_file_names = []  # type: List[unicode]
+    resolved_file_names = []  # type: List[str]
 
     ctxt = errors.ParserContext(input_file_name, errors.ParserErrorCollection())
 
