@@ -1,7 +1,5 @@
 """Defines a mapping of shortened names for logger configuration files to their full path."""
 
-from __future__ import absolute_import
-
 import os
 import os.path
 
@@ -16,7 +14,7 @@ def _get_named_loggers():
     named_loggers = {}
 
     try:
-        (root, _dirs, files) = os.walk(dirname).next()
+        (root, _dirs, files) = next(os.walk(dirname))
         for filename in files:
             (short_name, ext) = os.path.splitext(filename)
             if ext in (".yml", ".yaml"):
