@@ -24,9 +24,7 @@ function SecondaryReadsTest(name = "secondary_reads_test") {
      * two-node replica set running with the latest version.
      */
     function performStandardSetup() {
-        // TODO: Periodic noop writes can be removed once SERVER-33248 is complete.
-        let replSet = new ReplSetTest(
-            {name, nodes: 2, nodeOptions: {setParameter: {writePeriodicNoops: true}}});
+        let replSet = new ReplSetTest({name, nodes: 2});
         replSet.startSet();
 
         const nodes = replSet.nodeList();
@@ -38,7 +36,6 @@ function SecondaryReadsTest(name = "secondary_reads_test") {
     }
 
     this.startSecondaryReaders = function(nReaders, readFn) {
-
         let read = function() {
             db.getMongo().setSlaveOk();
             db = db.getSiblingDB(TestData.dbName);
@@ -72,7 +69,6 @@ function SecondaryReadsTest(name = "secondary_reads_test") {
     // The returned function will return once the batch has reached the point where it has applied
     // but not updated the last applied optime.
     this.pauseSecondaryBatchApplication = function() {
-
         clearRawMongoProgramOutput();
 
         assert.commandWorked(
@@ -104,7 +100,7 @@ function SecondaryReadsTest(name = "secondary_reads_test") {
         assert.writeOK(primaryDB.getCollection(signalColl).insert({_id: testDoneId}));
         for (let i = 0; i < readers.length; i++) {
             const await = readers[i];
-            await();
+            await ();
             print("reader " + i + " done");
         }
         readers = [];
