@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -42,7 +41,6 @@
 #include "mongo/db/audit.h"
 #include "mongo/db/auth/action_set.h"
 #include "mongo/db/auth/action_type.h"
-#include "mongo/db/auth/authorization_manager.h"
 #include "mongo/db/auth/authorization_session.h"
 #include "mongo/db/auth/privilege.h"
 #include "mongo/db/auth/user_management_commands_parser.h"
@@ -57,6 +55,7 @@
 #include "mongo/db/catalog_raii.h"
 #include "mongo/db/clientcursor.h"
 #include "mongo/db/commands.h"
+#include "mongo/db/commands/create_gen.h"
 #include "mongo/db/commands/profile_common.h"
 #include "mongo/db/commands/profile_gen.h"
 #include "mongo/db/commands/server_status.h"
@@ -67,7 +66,6 @@
 #include "mongo/db/exec/working_set_common.h"
 #include "mongo/db/index/index_access_method.h"
 #include "mongo/db/index/index_descriptor.h"
-#include "mongo/db/index_builder.h"
 #include "mongo/db/introspect.h"
 #include "mongo/db/jsobj.h"
 #include "mongo/db/json.h"
@@ -81,13 +79,11 @@
 #include "mongo/db/query/internal_plans.h"
 #include "mongo/db/query/query_planner.h"
 #include "mongo/db/read_concern.h"
-#include "mongo/db/repair_database.h"
 #include "mongo/db/repl/optime.h"
 #include "mongo/db/repl/read_concern_args.h"
 #include "mongo/db/repl/repl_client_info.h"
 #include "mongo/db/repl/repl_settings.h"
 #include "mongo/db/repl/replication_coordinator.h"
-#include "mongo/db/server_parameters.h"
 #include "mongo/db/stats/storage_stats.h"
 #include "mongo/db/storage/storage_engine_init.h"
 #include "mongo/db/write_concern.h"
@@ -147,8 +143,8 @@ public:
              repl::ReplicationCoordinator::modeNone) &&
             (dbname == NamespaceString::kLocalDb)) {
             uasserted(ErrorCodes::IllegalOperation,
-                      str::stream() << "Cannot drop '" << dbname
-                                    << "' database while replication is active");
+                      str::stream()
+                          << "Cannot drop '" << dbname << "' database while replication is active");
         }
         BSONElement e = cmdObj.firstElement();
         int p = (int)e.number();
@@ -169,29 +165,26 @@ public:
 
 } cmdDropDatabase;
 
+static const char* repairRemovedMessage =
+    "This command has been removed. If you would like to compact your data, use the 'compact' "
+    "command. If you would like to rebuild indexes, use the 'reIndex' command. If you need to "
+    "recover data, please see the documentation for repairing your database offline: "
+    "http://dochub.mongodb.org/core/repair";
+
 class CmdRepairDatabase : public ErrmsgCommandDeprecated {
 public:
     AllowedOnSecondary secondaryAllowed(ServiceContext*) const override {
         return AllowedOnSecondary::kAlways;
     }
     virtual bool maintenanceMode() const {
-        return true;
-    }
-    std::string help() const override {
-        return "repair database.  also compacts. note: slow.";
-    }
-
-
-    virtual bool supportsWriteConcern(const BSONObj& cmd) const override {
         return false;
     }
 
-    virtual void addRequiredPrivileges(const std::string& dbname,
-                                       const BSONObj& cmdObj,
-                                       std::vector<Privilege>* out) const {
-        ActionSet actions;
-        actions.addAction(ActionType::repairDatabase);
-        out->push_back(Privilege(ResourcePattern::forDatabaseName(dbname), actions));
+    std::string help() const override {
+        return repairRemovedMessage;
+    }
+    virtual bool supportsWriteConcern(const BSONObj& cmd) const override {
+        return false;
     }
 
     CmdRepairDatabase() : ErrmsgCommandDeprecated("repairDatabase") {}
@@ -201,69 +194,9 @@ public:
                    const BSONObj& cmdObj,
                    string& errmsg,
                    BSONObjBuilder& result) {
-        BSONElement e = cmdObj.firstElement();
-        if (e.numberInt() != 1) {
-            errmsg = "bad option";
-            return false;
-        }
 
-        // Closing a database requires a global lock.
-        Lock::GlobalWrite lk(opCtx);
-        auto db = DatabaseHolder::getDatabaseHolder().get(opCtx, dbname);
-        if (db) {
-            if (db->isDropPending(opCtx)) {
-                uasserted(ErrorCodes::DatabaseDropPending,
-                          str::stream() << "Cannot repair database " << dbname
-                                        << " since it is pending being dropped.");
-            }
-        } else {
-            // If the name doesn't make an exact match, check for a case insensitive match.
-            std::set<std::string> otherCasing =
-                DatabaseHolder::getDatabaseHolder().getNamesWithConflictingCasing(dbname);
-            if (otherCasing.empty()) {
-                // Database doesn't exist. Treat this as a success (historical behavior).
-                return true;
-            }
-
-            // Database exists with a differing case. Treat this as an error. Report the casing
-            // conflict.
-            errmsg = str::stream() << "Database exists with a different case. Given: `" << dbname
-                                   << "` Found: `" << *otherCasing.begin() << "`";
-            return false;
-        }
-
-        // TODO (Kal): OldClientContext legacy, needs to be removed
-        {
-            CurOp::get(opCtx)->ensureStarted();
-            stdx::lock_guard<Client> lk(*opCtx->getClient());
-            CurOp::get(opCtx)->setNS_inlock(dbname);
-        }
-
-        log() << "repairDatabase " << dbname;
-        BackgroundOperation::assertNoBgOpInProgForDb(dbname);
-
-        e = cmdObj.getField("preserveClonedFilesOnFailure");
-        bool preserveClonedFilesOnFailure = e.isBoolean() && e.boolean();
-        e = cmdObj.getField("backupOriginalFiles");
-        bool backupOriginalFiles = e.isBoolean() && e.boolean();
-
-        {
-            // Conceal UUIDCatalog changes for the duration of repairDatabase so that calls to
-            // UUIDCatalog::lookupNSSByUUID do not cause spurious NamespaceNotFound errors while
-            // repairDatabase makes updates.
-            ConcealUUIDCatalogChangesBlock cucc(opCtx);
-
-            StorageEngine* engine = getGlobalServiceContext()->getStorageEngine();
-            repl::UnreplicatedWritesBlock uwb(opCtx);
-            Status status = repairDatabase(
-                opCtx, engine, dbname, preserveClonedFilesOnFailure, backupOriginalFiles);
-
-            // Open database before returning
-            DatabaseHolder::getDatabaseHolder().openDb(opCtx, dbname);
-            uassertStatusOK(status);
-        }
-
-        return true;
+        uasserted(ErrorCodes::CommandNotFound, repairRemovedMessage);
+        return false;
     }
 } cmdRepairDatabase;
 
@@ -305,11 +238,22 @@ public:
             return false;
         }
 
-        if ((repl::ReplicationCoordinator::get(opCtx)->getReplicationMode() !=
-             repl::ReplicationCoordinator::modeNone) &&
-            nsToDrop.isOplog()) {
-            errmsg = "can't drop live oplog while replicating";
-            return false;
+        if (nsToDrop.isOplog()) {
+            if (repl::ReplicationCoordinator::get(opCtx)->isReplEnabled()) {
+                errmsg = "can't drop live oplog while replicating";
+                return false;
+            }
+
+            auto storageEngine = opCtx->getServiceContext()->getStorageEngine();
+            invariant(storageEngine);
+            if (storageEngine->supportsRecoveryTimestamp()) {
+                // We use the method supportsRecoveryTimestamp() to detect whether we are using
+                // the WiredTiger storage engine, which is currently only storage engine that
+                // supports the replSetResizeOplog command.
+                errmsg =
+                    "can't drop oplog on storage engines that support replSetResizeOplog command";
+                return false;
+            }
         }
 
         uassertStatusOK(
@@ -327,22 +271,41 @@ public:
 class CmdCreate : public BasicCommand {
 public:
     CmdCreate() : BasicCommand("create") {}
+
     AllowedOnSecondary secondaryAllowed(ServiceContext*) const override {
         return AllowedOnSecondary::kNever;
     }
+
     virtual bool adminOnly() const {
         return false;
     }
 
-
     virtual bool supportsWriteConcern(const BSONObj& cmd) const override {
         return true;
     }
 
     std::string help() const override {
-        return "create a collection explicitly\n"
-               "{ create: <ns>[, capped: <bool>, size: <collSizeInBytes>, max: <nDocs>] }";
+        return str::stream()
+            << "explicitly creates a collection or view\n"
+            << "{\n"
+            << "  create: <string: collection or view name> [,\n"
+            << "  capped: <bool: capped collection>,\n"
+            << "  autoIndexId: <bool: automatic creation of _id index>,\n"
+            << "  idIndex: <document: _id index specification>,\n"
+            << "  size: <int: size in bytes of the capped collection>,\n"
+            << "  max: <int: max number of documents in the capped collection>,\n"
+            << "  storageEngine: <document: storage engine configuration>,\n"
+            << "  validator: <document: validation rules>,\n"
+            << "  validationLevel: <string: validation level>,\n"
+            << "  validationAction: <string: validation action>,\n"
+            << "  indexOptionDefaults: <document: default configuration for indexes>,\n"
+            << "  viewOn: <string: name of source collection or view>,\n"
+            << "  pipeline: <array<object>: aggregation pipeline stage>,\n"
+            << "  collation: <document: default collation for the collection or view>,\n"
+            << "  writeConcern: <document: write concern expression for the operation>]\n"
+            << "}";
     }
+
     virtual Status checkAuthForCommand(Client* client,
                                        const std::string& dbname,
                                        const BSONObj& cmdObj) const {
@@ -354,34 +317,51 @@ public:
                      const string& dbname,
                      const BSONObj& cmdObj,
                      BSONObjBuilder& result) {
-        const NamespaceString ns(CommandHelpers::parseNsCollectionRequired(dbname, cmdObj));
+        IDLParserErrorContext ctx("create");
+        CreateCommand cmd = CreateCommand::parse(ctx, cmdObj);
 
-        if (cmdObj.hasField("autoIndexId")) {
+        const NamespaceString ns = cmd.getNamespace();
+
+        if (cmd.getAutoIndexId()) {
             const char* deprecationWarning =
                 "the autoIndexId option is deprecated and will be removed in a future release";
             warning() << deprecationWarning;
             result.append("note", deprecationWarning);
         }
 
+        // Ensure that the 'size' field is present if 'capped' is set to true.
+        if (cmd.getCapped()) {
+            uassert(ErrorCodes::InvalidOptions,
+                    str::stream() << "the 'size' field is required when 'capped' is true",
+                    cmd.getSize());
+        }
+
+        // If the 'size' or 'max' fields are present, then 'capped' must be set to true.
+        if (cmd.getSize() || cmd.getMax()) {
+            uassert(ErrorCodes::InvalidOptions,
+                    str::stream() << "the 'capped' field needs to be true when either the 'size'"
+                                  << " or 'max' fields are present",
+                    cmd.getCapped());
+        }
+
+        // The 'temp' field is only allowed to be used internally and isn't available to clients.
+        if (cmd.getTemp()) {
+            uassert(ErrorCodes::InvalidOptions,
+                    str::stream() << "the 'temp' field is an invalid option",
+                    opCtx->getClient()->isInDirectClient());
+        }
+
         // Validate _id index spec and fill in missing fields.
-        if (auto idIndexElem = cmdObj["idIndex"]) {
-            if (cmdObj["viewOn"]) {
-                uasserted(ErrorCodes::InvalidOptions,
-                          str::stream() << "'idIndex' is not allowed with 'viewOn': "
-                                        << idIndexElem);
-            }
-            if (cmdObj["autoIndexId"]) {
-                uasserted(ErrorCodes::InvalidOptions,
-                          str::stream() << "'idIndex' is not allowed with 'autoIndexId': "
-                                        << idIndexElem);
-            }
+        if (cmd.getIdIndex()) {
+            auto idIndexSpec = *cmd.getIdIndex();
 
-            if (idIndexElem.type() != BSONType::Object) {
-                uasserted(ErrorCodes::TypeMismatch,
-                          str::stream() << "'idIndex' has to be a document: " << idIndexElem);
-            }
+            uassert(ErrorCodes::InvalidOptions,
+                    str::stream() << "'idIndex' is not allowed with 'viewOn': " << idIndexSpec,
+                    !cmd.getViewOn());
 
-            auto idIndexSpec = idIndexElem.Obj();
+            uassert(ErrorCodes::InvalidOptions,
+                    str::stream() << "'idIndex' is not allowed with 'autoIndexId': " << idIndexSpec,
+                    !cmd.getAutoIndexId());
 
             // Perform index spec validation.
             idIndexSpec = uassertStatusOK(index_key_validate::validateIndexSpec(
@@ -390,19 +370,16 @@ public:
 
             // Validate or fill in _id index collation.
             std::unique_ptr<CollatorInterface> defaultCollator;
-            if (auto collationElem = cmdObj["collation"]) {
-                if (collationElem.type() != BSONType::Object) {
-                    uasserted(ErrorCodes::TypeMismatch,
-                              str::stream() << "'collation' has to be a document: "
-                                            << collationElem);
-                }
+            if (cmd.getCollation()) {
                 auto collatorStatus = CollatorFactoryInterface::get(opCtx->getServiceContext())
-                                          ->makeFromBSON(collationElem.Obj());
+                                          ->makeFromBSON(*cmd.getCollation());
                 uassertStatusOK(collatorStatus.getStatus());
                 defaultCollator = std::move(collatorStatus.getValue());
             }
+
             idIndexSpec = uassertStatusOK(index_key_validate::validateIndexSpecCollation(
                 opCtx, idIndexSpec, defaultCollator.get()));
+
             std::unique_ptr<CollatorInterface> idIndexCollator;
             if (auto collationElem = idIndexSpec["collation"]) {
                 auto collatorStatus = CollatorFactoryInterface::get(opCtx->getServiceContext())
@@ -513,7 +490,7 @@ public:
                 keyPattern = Helpers::inferKeyPattern(min);
             }
 
-            IndexDescriptor* idx =
+            const IndexDescriptor* idx =
                 collection->getIndexCatalog()->findShardKeyPrefixedIndex(opCtx,
                                                                          keyPattern,
                                                                          true);  // requireSingleKey
@@ -561,7 +538,7 @@ public:
             }
         }
 
-        if (PlanExecutor::FAILURE == state || PlanExecutor::DEAD == state) {
+        if (PlanExecutor::FAILURE == state) {
             warning() << "Internal error while reading " << ns;
             uassertStatusOK(WorkingSetCommon::getMemberObjectStatus(obj).withContext(
                 "Executor error while reading during dataSize command"));
@@ -618,7 +595,7 @@ public:
 
         result.append("ns", nss.ns());
         Status status = appendCollectionStorageStats(opCtx, nss, jsobj, &result);
-        if (!status.isOK()) {
+        if (!status.isOK() && status.code() != ErrorCodes::NamespaceNotFound) {
             errmsg = status.reason();
             return false;
         }
@@ -640,7 +617,7 @@ public:
     }
     std::string help() const override {
         return "Sets collection options.\n"
-               "Example: { collMod: 'foo', usePowerOf2Sizes:true }\n"
+               "Example: { collMod: 'foo', viewOn: 'bar'} "
                "Example: { collMod: 'foo', index: {keyPattern: {a: 1}, expireAfterSeconds: 600} "
                "Example: { collMod: 'foo', index: {name: 'bar', expireAfterSeconds: 600} }\n";
     }
@@ -736,6 +713,7 @@ public:
             result.appendNumber("numExtents", 0);
             result.appendNumber("indexes", 0);
             result.appendNumber("indexSize", 0);
+            result.appendNumber("scaleFactor", scale);
             result.appendNumber("fileSize", 0);
             if (!getGlobalServiceContext()->getStorageEngine()->isEphemeral()) {
                 result.appendNumber("fsUsedSize", 0);
