@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -48,6 +47,7 @@
 #include "mongo/db/namespace_string.h"
 #include "mongo/db/query/explain.h"
 #include "mongo/db/query/plan_ranker.h"
+#include "mongo/util/hex.h"
 #include "mongo/util/log.h"
 
 namespace {
@@ -91,9 +91,9 @@ MONGO_INITIALIZER_WITH_PREREQUISITES(SetupPlanCacheCommands, MONGO_NO_PREREQUISI
     // PlanCacheCommand constructors refer to static ActionType instances.
     // Registering commands in a mongo static initializer ensures that
     // the ActionType construction will be completed first.
-    new PlanCacheListQueryShapes();
+    new PlanCacheListQueryShapesDeprecated();
     new PlanCacheClear();
-    new PlanCacheListPlans();
+    new PlanCacheListPlansDeprecated();
 
     return Status::OK();
 }
@@ -104,8 +104,8 @@ namespace mongo {
 
 using std::string;
 using std::stringstream;
-using std::vector;
 using std::unique_ptr;
+using std::vector;
 
 PlanCacheCommand::PlanCacheCommand(const string& name,
                                    const string& helpText,
@@ -220,15 +220,21 @@ StatusWith<unique_ptr<CanonicalQuery>> PlanCacheCommand::canonicalize(OperationC
     return std::move(statusWithCQ.getValue());
 }
 
-PlanCacheListQueryShapes::PlanCacheListQueryShapes()
+PlanCacheListQueryShapesDeprecated::PlanCacheListQueryShapesDeprecated()
     : PlanCacheCommand("planCacheListQueryShapes",
-                       "Displays all query shapes in a collection.",
+                       "Deprecated. Prefer the $planCacheStats aggregation pipeline stage.",
                        ActionType::planCacheRead) {}
 
-Status PlanCacheListQueryShapes::runPlanCacheCommand(OperationContext* opCtx,
-                                                     const string& ns,
-                                                     const BSONObj& cmdObj,
-                                                     BSONObjBuilder* bob) {
+Status PlanCacheListQueryShapesDeprecated::runPlanCacheCommand(OperationContext* opCtx,
+                                                               const string& ns,
+                                                               const BSONObj& cmdObj,
+                                                               BSONObjBuilder* bob) {
+    if (_sampler.tick()) {
+        warning()
+            << "The planCacheListQueryShapes command is deprecated. Prefer the $planCacheStats "
+               "aggregation pipeline stage.";
+    }
+
     // This is a read lock. The query cache is owned by the collection.
     AutoGetCollectionForReadCommand ctx(opCtx, NamespaceString(ns));
 
@@ -244,15 +250,14 @@ Status PlanCacheListQueryShapes::runPlanCacheCommand(OperationContext* opCtx,
 }
 
 // static
-Status PlanCacheListQueryShapes::list(const PlanCache& planCache, BSONObjBuilder* bob) {
+Status PlanCacheListQueryShapesDeprecated::list(const PlanCache& planCache, BSONObjBuilder* bob) {
     invariant(bob);
 
     // Fetch all cached solutions from plan cache.
-    vector<PlanCacheEntry*> solutions = planCache.getAllEntries();
+    auto entries = planCache.getAllEntries();
 
     BSONArrayBuilder arrayBuilder(bob->subarrayStart("shapes"));
-    for (vector<PlanCacheEntry*>::const_iterator i = solutions.begin(); i != solutions.end(); i++) {
-        PlanCacheEntry* entry = *i;
+    for (auto&& entry : entries) {
         invariant(entry);
 
         BSONObjBuilder shapeBuilder(arrayBuilder.subobjStart());
@@ -262,10 +267,8 @@ Status PlanCacheListQueryShapes::list(const PlanCache& planCache, BSONObjBuilder
         if (!entry->collation.isEmpty()) {
             shapeBuilder.append("collation", entry->collation);
         }
+        shapeBuilder.append("queryHash", unsignedIntToFixedLengthHex(entry->queryHash));
         shapeBuilder.doneFast();
-
-        // Release resources for cached solution after extracting query shape.
-        delete entry;
     }
     arrayBuilder.doneFast();
 
@@ -312,8 +315,9 @@ Status PlanCacheClear::clear(OperationContext* opCtx,
 
         unique_ptr<CanonicalQuery> cq = std::move(statusWithCQ.getValue());
 
-        if (!planCache->contains(*cq)) {
-            // Log if asked to clear non-existent query shape.
+        Status result = planCache->remove(*cq);
+        if (!result.isOK()) {
+            invariant(result.code() == ErrorCodes::NoSuchKey);
             LOG(1) << ns << ": query shape doesn't exist in PlanCache - "
                    << redact(cq->getQueryObj()) << "(sort: " << cq->getQueryRequest().getSort()
                    << "; projection: " << cq->getQueryRequest().getProj()
@@ -321,11 +325,6 @@ Status PlanCacheClear::clear(OperationContext* opCtx,
             return Status::OK();
         }
 
-        Status result = planCache->remove(*cq);
-        if (!result.isOK()) {
-            return result;
-        }
-
         LOG(1) << ns << ": removed plan cache entry - " << redact(cq->getQueryObj())
                << "(sort: " << cq->getQueryRequest().getSort()
                << "; projection: " << cq->getQueryRequest().getProj()
@@ -349,56 +348,46 @@ Status PlanCacheClear::clear(OperationContext* opCtx,
     return Status::OK();
 }
 
-PlanCacheListPlans::PlanCacheListPlans()
+PlanCacheListPlansDeprecated::PlanCacheListPlansDeprecated()
     : PlanCacheCommand("planCacheListPlans",
-                       "Displays the cached plans for a query shape.",
+                       "Deprecated. Prefer the $planCacheStats aggregation pipeline stage.",
                        ActionType::planCacheRead) {}
 
-Status PlanCacheListPlans::runPlanCacheCommand(OperationContext* opCtx,
-                                               const std::string& ns,
-                                               const BSONObj& cmdObj,
-                                               BSONObjBuilder* bob) {
+Status PlanCacheListPlansDeprecated::runPlanCacheCommand(OperationContext* opCtx,
+                                                         const std::string& ns,
+                                                         const BSONObj& cmdObj,
+                                                         BSONObjBuilder* bob) {
+    if (_sampler.tick()) {
+        warning() << "The planCacheListPlans command is deprecated. Prefer the $planCacheStats "
+                     "aggregation pipeline stage.";
+    }
+
     AutoGetCollectionForReadCommand ctx(opCtx, NamespaceString(ns));
 
     PlanCache* planCache;
-    Status status = getPlanCache(opCtx, ctx.getCollection(), ns, &planCache);
-    if (!status.isOK()) {
-        // No collection - return empty plans array.
-        BSONArrayBuilder plansBuilder(bob->subarrayStart("plans"));
-        plansBuilder.doneFast();
-        return Status::OK();
-    }
+    uassertStatusOK(getPlanCache(opCtx, ctx.getCollection(), ns, &planCache));
     return list(opCtx, *planCache, ns, cmdObj, bob);
 }
 
-// static
-Status PlanCacheListPlans::list(OperationContext* opCtx,
-                                const PlanCache& planCache,
-                                const std::string& ns,
-                                const BSONObj& cmdObj,
-                                BSONObjBuilder* bob) {
-    auto statusWithCQ = canonicalize(opCtx, ns, cmdObj);
-    if (!statusWithCQ.isOK()) {
-        return statusWithCQ.getStatus();
-    }
-    unique_ptr<CanonicalQuery> cq = std::move(statusWithCQ.getValue());
-
-    if (!planCache.contains(*cq)) {
+namespace {
+Status listPlansOriginalFormat(std::unique_ptr<CanonicalQuery> cq,
+                               const PlanCache& planCache,
+                               BSONObjBuilder* bob) {
+    auto lookupResult = planCache.getEntry(*cq);
+    if (lookupResult == ErrorCodes::NoSuchKey) {
         // Return empty plans in results if query shape does not
         // exist in plan cache.
         BSONArrayBuilder plansBuilder(bob->subarrayStart("plans"));
         plansBuilder.doneFast();
         return Status::OK();
+    } else if (!lookupResult.isOK()) {
+        return lookupResult.getStatus();
     }
 
-    PlanCacheEntry* entryRaw;
-    Status result = planCache.getEntry(*cq, &entryRaw);
-    if (!result.isOK()) {
-        return result;
-    }
-    unique_ptr<PlanCacheEntry> entry(entryRaw);
+    auto entry = std::move(lookupResult.getValue());
 
     BSONArrayBuilder plansBuilder(bob->subarrayStart("plans"));
+
     size_t numPlans = entry->plannerData.size();
     invariant(numPlans == entry->decision->stats.size());
     invariant(numPlans == entry->decision->scores.size());
@@ -430,7 +419,7 @@ Status PlanCacheListPlans::list(OperationContext* opCtx,
             BSONArrayBuilder scoresBob(feedbackBob.subarrayStart("scores"));
             for (size_t i = 0; i < entry->feedback.size(); ++i) {
                 BSONObjBuilder scoreBob(scoresBob.subobjStart());
-                scoreBob.append("score", entry->feedback[i]->score);
+                scoreBob.append("score", entry->feedback[i]);
             }
             scoresBob.doneFast();
         }
@@ -443,7 +432,34 @@ Status PlanCacheListPlans::list(OperationContext* opCtx,
 
     // Append the time the entry was inserted into the plan cache.
     bob->append("timeOfCreation", entry->timeOfCreation);
+    bob->append("queryHash", unsignedIntToFixedLengthHex(entry->queryHash));
+    bob->append("planCacheKey", unsignedIntToFixedLengthHex(entry->planCacheKey));
+    // Append whether or not the entry is active.
+    bob->append("isActive", entry->isActive);
+    bob->append("works", static_cast<long long>(entry->works));
+    return Status::OK();
+}
+}  // namespace
 
+// static
+Status PlanCacheListPlansDeprecated::list(OperationContext* opCtx,
+                                          const PlanCache& planCache,
+                                          const std::string& ns,
+                                          const BSONObj& cmdObj,
+                                          BSONObjBuilder* bob) {
+    auto statusWithCQ = canonicalize(opCtx, ns, cmdObj);
+    if (!statusWithCQ.isOK()) {
+        return statusWithCQ.getStatus();
+    }
+
+    if (!internalQueryCacheListPlansNewOutput.load())
+        return listPlansOriginalFormat(std::move(statusWithCQ.getValue()), planCache, bob);
+
+    unique_ptr<CanonicalQuery> cq = std::move(statusWithCQ.getValue());
+    auto entry = uassertStatusOK(planCache.getEntry(*cq));
+
+    // internalQueryCacheDisableInactiveEntries is True and we should use the new output format.
+    Explain::planCacheEntryToBSON(*entry, bob);
     return Status::OK();
 }
 
