@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -33,6 +32,7 @@
 #include <climits>  // For UINT_MAX
 #include <vector>
 
+#include "mongo/db/concurrency/flow_control_ticketholder.h"
 #include "mongo/db/concurrency/lock_manager.h"
 #include "mongo/db/concurrency/lock_stats.h"
 #include "mongo/db/operation_context.h"
@@ -47,7 +47,8 @@ namespace mongo {
  * Lock/unlock methods must always be called from a single thread.
  */
 class Locker {
-    MONGO_DISALLOW_COPYING(Locker);
+    Locker(const Locker&) = delete;
+    Locker& operator=(const Locker&) = delete;
 
     friend class UninterruptibleLockGuard;
 
@@ -153,20 +154,23 @@ public:
      * @param mode Mode in which the global lock should be acquired. Also indicates the intent
      *              of the operation.
      *
-     * @return LOCK_OK, if the global lock (and the flush lock, for the MMAP V1 engine) were
-     *          acquired within the specified time bound. Otherwise, the respective failure
-     *          code and neither lock will be acquired.
+     * It may throw an exception if it is interrupted.
      */
-    virtual LockResult lockGlobal(OperationContext* opCtx, LockMode mode) = 0;
-    virtual LockResult lockGlobal(LockMode mode) = 0;
+    virtual void lockGlobal(OperationContext* opCtx, LockMode mode) = 0;
+    virtual void lockGlobal(LockMode mode) = 0;
 
     /**
      * Requests the global lock to be acquired in the specified mode.
      *
-     * See the comments for lockBegin/Complete for more information on the semantics.
-     * The deadline indicates the absolute time point when this lock acquisition will time out, if
-     * not yet granted. The lockGlobalBegin
-     * method has a deadline for use with the TicketHolder, if there is one.
+     * See the comments for lockBegin/Complete for more information on the semantics. The deadline
+     * indicates the absolute time point when this lock acquisition will time out, if not yet
+     * granted. The lockGlobalBegin method has a deadline for use with the TicketHolder, if there is
+     * one.
+     *
+     * Returns LOCK_OK if the global lock is successfully acquired,
+     *      or LOCK_WAITING if the global lock is currently held by someone else.
+     *
+     * The ticket acquisition phase can be interrupted or time out, thus throwing an exception.
      */
     virtual LockResult lockGlobalBegin(OperationContext* opCtx, LockMode mode, Date_t deadline) = 0;
     virtual LockResult lockGlobalBegin(LockMode mode, Date_t deadline) = 0;
@@ -174,15 +178,11 @@ public:
     /**
      * Calling lockGlobalComplete without an OperationContext does not allow the lock acquisition
      * to be interrupted.
+     *
+     * It may throw an exception if it is interrupted.
      */
-    virtual LockResult lockGlobalComplete(OperationContext* opCtx, Date_t deadline) = 0;
-    virtual LockResult lockGlobalComplete(Date_t deadline) = 0;
-
-    /**
-     * This method is used only in the MMAP V1 storage engine, otherwise it is a no-op. See the
-     * comments in the implementation for more details on how MMAP V1 journaling works.
-     */
-    virtual void lockMMAPV1Flush() = 0;
+    virtual void lockGlobalComplete(OperationContext* opCtx, Date_t deadline) = 0;
+    virtual void lockGlobalComplete(Date_t deadline) = 0;
 
     /**
      * Decrements the reference count on the global lock.  If the reference count on the
@@ -198,19 +198,34 @@ public:
     virtual bool unlockGlobal() = 0;
 
     /**
-     * This is only necessary for the MMAP V1 engine and in particular, the fsyncLock command
-     * which needs to first acquire the global lock in X-mode for truncating the journal and
-     * then downgrade to S before it blocks.
+     * Requests the RSTL to be acquired in the requested mode (typically mode X) . This should only
+     * be called inside ReplicationStateTransitionLockGuard.
      *
-     * The downgrade is necessary in order to be nice and not block readers while under
-     * fsyncLock.
+     * See the comments for lockBegin/Complete for more information on the semantics.
      */
-    virtual void downgradeGlobalXtoSForMMAPV1() = 0;
+    virtual LockResult lockRSTLBegin(OperationContext* opCtx, LockMode mode) = 0;
+
+    /**
+     * Waits for the completion of acquiring the RSTL. This should only be called inside
+     * ReplicationStateTransitionLockGuard.
+     *
+     * It may throw an exception if it is interrupted.
+     */
+    virtual void lockRSTLComplete(OperationContext* opCtx, LockMode mode, Date_t deadline) = 0;
+
+    /**
+     * Unlocks the RSTL when the transaction becomes prepared. This is used to bypass two-phase
+     * locking and unlock the RSTL immediately, rather than at the end of the WUOW.
+     *
+     * @return true if the RSTL is unlocked; false if we fail to unlock the RSTL or if it was
+     * already unlocked.
+     */
+    virtual bool unlockRSTLforPrepare() = 0;
 
     /**
      * beginWriteUnitOfWork/endWriteUnitOfWork are called at the start and end of WriteUnitOfWorks.
-     * They can be used to implement two-phase locking. Each call to begin should be matched with an
-     * eventual call to end.
+     * They can be used to implement two-phase locking. Each call to begin or restore should be
+     * matched with an eventual call to end or release.
      *
      * endWriteUnitOfWork, if not called in a nested WUOW, will release all two-phase locking held
      * lock resources.
@@ -220,6 +235,29 @@ public:
 
     virtual bool inAWriteUnitOfWork() const = 0;
 
+    /**
+     * Returns whether we have ever taken a global lock in X or IX mode in this operation.
+     * Should only be called on the thread owning the locker.
+     */
+    virtual bool wasGlobalLockTakenForWrite() const = 0;
+
+    /**
+     * Returns whether we have ever taken a global lock in S, X, or IX mode in this operation.
+     */
+    virtual bool wasGlobalLockTakenInModeConflictingWithWrites() const = 0;
+
+    /**
+     * Returns whether we have ever taken a global lock in this operation.
+     * Should only be called on the thread owning the locker.
+     */
+    virtual bool wasGlobalLockTaken() const = 0;
+
+    /**
+     * Sets the mode bit in _globalLockMode. Once a mode bit is set, we won't clear it. Also sets
+     * _wasGlobalLockTakenInModeConflictingWithWrites to true if the mode is S, X, or IX.
+     */
+    virtual void setGlobalLockTakenInMode(LockMode mode) = 0;
+
     /**
      * Acquires lock on the specified resource in the specified mode and returns the outcome
      * of the operation. See the details for LockResult for more information on what the
@@ -230,35 +268,29 @@ public:
      * corresponding call to unlock.
      *
      * If setLockTimeoutMillis has been called, then a lock request with a Date_t::max() deadline
-     * may throw a LockTimeout error. See setMaxLockTimeout() above for details.
+     * may throw a LockTimeout exception. See setMaxLockTimeout() above for details.
      *
      * @param opCtx If provided, will be used to interrupt a LOCK_WAITING state.
      * @param resId Id of the resource to be locked.
      * @param mode Mode in which the resource should be locked. Lock upgrades are allowed.
-     * @param deadline How long to wait for the lock to be granted, before
-     *              returning LOCK_TIMEOUT. This parameter defaults to an infinite deadline.
-     *              If Milliseconds(0) is passed, the request will return immediately, if
-     *              the request could not be granted right away.
-     * @param checkDeadlock Whether to enable deadlock detection for this acquisition. This
-     *              parameter is put in place until we can handle deadlocks at all places,
-     *              which acquire locks.
+     * @param deadline How long to wait for the lock to be granted.
+     *                 This parameter defaults to an infinite deadline.
+     *                 If Milliseconds(0) is passed, the function will return immediately if the
+     *                 request could be granted right away, or throws a LockTimeout exception
+     *                 otherwise.
      *
-     * @return All LockResults except for LOCK_WAITING, because it blocks.
+     * It may throw an exception if it is interrupted.
      */
-    virtual LockResult lock(OperationContext* opCtx,
-                            ResourceId resId,
-                            LockMode mode,
-                            Date_t deadline = Date_t::max(),
-                            bool checkDeadlock = false) = 0;
+    virtual void lock(OperationContext* opCtx,
+                      ResourceId resId,
+                      LockMode mode,
+                      Date_t deadline = Date_t::max()) = 0;
 
     /**
      * Calling lock without an OperationContext does not allow LOCK_WAITING states to be
      * interrupted.
      */
-    virtual LockResult lock(ResourceId resId,
-                            LockMode mode,
-                            Date_t deadline = Date_t::max(),
-                            bool checkDeadlock = false) = 0;
+    virtual void lock(ResourceId resId, LockMode mode, Date_t deadline = Date_t::max()) = 0;
 
     /**
      * Downgrades the specified resource's lock mode without changing the reference count.
@@ -288,7 +320,7 @@ public:
     // hierarchy is properly locked and because of this they are very expensive to call.
     // Do not use them in performance critical code paths.
     virtual bool isDbLockedForMode(StringData dbName, LockMode mode) const = 0;
-    virtual bool isCollectionLockedForMode(StringData ns, LockMode mode) const = 0;
+    virtual bool isCollectionLockedForMode(const NamespaceString& nss, LockMode mode) const = 0;
 
     /**
      * Returns the resource that this locker is waiting/blocked on (if any). If the locker is
@@ -353,11 +385,23 @@ public:
         // The global lock is handled differently from all other locks.
         LockMode globalMode;
 
-        // The non-global non-flush locks held, sorted by granularity.  That is, locks[i] is
+        // The non-global locks held, sorted by granularity.  That is, locks[i] is
         // coarser or as coarse as locks[i + 1].
         std::vector<OneLock> locks;
     };
 
+    /**
+     * WUOWLockSnapshot captures all resources that have pending unlocks when releasing the write
+     * unit of work. If a lock has more than one pending unlock, it appears more than once here.
+     */
+    struct WUOWLockSnapshot {
+        // Nested WUOW can be released and restored all together.
+        int wuowNestingLevel = 0;
+
+        // The order of locks doesn't matter in this vector.
+        std::vector<OneLock> unlockPendingLocks;
+    };
+
     /**
      * Retrieves all locks held by this transaction, other than RESOURCE_MUTEX locks, and what mode
      * they're held in.
@@ -384,6 +428,24 @@ public:
     virtual void restoreLockState(OperationContext* opCtx, const LockSnapshot& stateToRestore) = 0;
     virtual void restoreLockState(const LockSnapshot& stateToRestore) = 0;
 
+    /**
+     * releaseWriteUnitOfWorkAndUnlock opts out of two-phase locking and yields the locks after a
+     * WUOW has been released. restoreWriteUnitOfWorkAndLock reacquires the locks and resumes the
+     * two-phase locking behavior of WUOW.
+     */
+    virtual bool releaseWriteUnitOfWorkAndUnlock(LockSnapshot* stateOut) = 0;
+    virtual void restoreWriteUnitOfWorkAndLock(OperationContext* opCtx,
+                                               const LockSnapshot& stateToRestore) = 0;
+
+
+    /**
+     * releaseWriteUnitOfWork opts out of two-phase locking of the current locks held but keeps
+     * holding these locks.
+     * restoreWriteUnitOfWork resumes the two-phase locking behavior of WUOW.
+     */
+    virtual void releaseWriteUnitOfWork(WUOWLockSnapshot* stateOut) = 0;
+    virtual void restoreWriteUnitOfWork(const WUOWLockSnapshot& stateToRestore) = 0;
+
     /**
      * Releases the ticket associated with the Locker. This allows locks to be held without
      * contributing to reader/writer throttling.
@@ -411,6 +473,10 @@ public:
     virtual bool isLocked() const = 0;
     virtual bool isWriteLocked() const = 0;
     virtual bool isReadLocked() const = 0;
+
+    virtual bool isRSTLExclusive() const = 0;
+    virtual bool isRSTLLocked() const = 0;
+
     virtual bool isGlobalLockedRecursively() = 0;
 
     /**
@@ -434,7 +500,7 @@ public:
 
     /**
      * This will opt out of the ticket mechanism. This should be used sparingly for special purpose
-     * threads, such as FTDC and committing or aborting transactions.
+     * threads, such as FTDC and committing or aborting prepared transactions.
      */
     void skipAcquireTicket() {
         // Should not hold or wait for the ticket.
@@ -445,6 +511,21 @@ public:
     bool shouldAcquireTicket() const {
         return _shouldAcquireTicket;
     }
+
+    /**
+     * Acquire a flow control admission ticket into the system. Flow control is used as a
+     * backpressure mechanism to limit replication majority point lag.
+     */
+    virtual void getFlowControlTicket(OperationContext* opCtx, LockMode lockMode) {}
+
+    /**
+     * If tracked by an implementation, returns statistics on effort spent acquiring a flow control
+     * ticket.
+     */
+    virtual FlowControlTicketholder::CurOp getFlowControlStats() const {
+        return FlowControlTicketholder::CurOp();
+    }
+
     /**
      * This function is for unit testing only.
      */
@@ -452,14 +533,21 @@ public:
         return _numResourcesToUnlockAtEndUnitOfWork;
     }
 
+    std::string getDebugInfo() const {
+        return _debugInfo;
+    }
+
+    void setDebugInfo(const std::string& info) {
+        _debugInfo = info;
+    }
+
 protected:
     Locker() {}
 
     /**
      * The number of callers that are guarding from lock interruptions.
-     * When 0, all lock acquisitions are interruptible. When positive, no lock acquisitions
-     * are interruptible. This is only true for database and global locks. Collection locks are
-     * never interruptible.
+     * When 0, all lock acquisitions are interruptible. When positive, no lock acquisitions are
+     * interruptible or can time out.
      */
     int _uninterruptibleLocksRequested = 0;
 
@@ -472,6 +560,7 @@ protected:
 private:
     bool _shouldConflictWithSecondaryBatchApplication = true;
     bool _shouldAcquireTicket = true;
+    std::string _debugInfo;  // Extra info about this locker for debugging purpose
 };
 
 /**
@@ -508,10 +597,13 @@ private:
 };
 
 /**
- * RAII-style class to opt out of replication's use of ParallelBatchWriterMode.
+ * RAII-style class to opt out of replication's use of the ParallelBatchWriterMode lock.
  */
 class ShouldNotConflictWithSecondaryBatchApplicationBlock {
-    MONGO_DISALLOW_COPYING(ShouldNotConflictWithSecondaryBatchApplicationBlock);
+    ShouldNotConflictWithSecondaryBatchApplicationBlock(
+        const ShouldNotConflictWithSecondaryBatchApplicationBlock&) = delete;
+    ShouldNotConflictWithSecondaryBatchApplicationBlock& operator=(
+        const ShouldNotConflictWithSecondaryBatchApplicationBlock&) = delete;
 
 public:
     explicit ShouldNotConflictWithSecondaryBatchApplicationBlock(Locker* lockState)
