@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -30,30 +29,32 @@
 
 #pragma once
 
-#include <list>
 #include <memory>
+#include <queue>
 
-#include "mongo/db/exec/plan_stage.h"
+#include "mongo/db/exec/requires_all_indices_stage.h"
 #include "mongo/db/exec/working_set.h"
 #include "mongo/db/jsobj.h"
 #include "mongo/db/query/canonical_query.h"
 #include "mongo/db/query/query_planner_params.h"
 #include "mongo/db/query/query_solution.h"
 #include "mongo/db/record_id.h"
-#include "mongo/db/storage/record_fetcher.h"
 
 namespace mongo {
 
 class PlanYieldPolicy;
 
 /**
- * This stage outputs its mainChild, and possibly its backup child
- * and also updates the cache.
- *
- * Preconditions: Valid RecordId.
+ * Runs a trial period in order to evaluate the cost of a cached plan. If the cost is unexpectedly
+ * high, the plan cache entry is deactivated and we use multi-planning to select an entirely new
+ * winning plan. This process is called "replanning".
  *
+ * This stage requires all indices to stay intact during the trial period so that replanning can
+ * occur with the set of indices in 'params'. As a future improvement, we could instead refresh the
+ * list of indices in 'params' prior to replanning, and thus avoid inheriting from
+ * RequiresAllIndicesStage.
  */
-class CachedPlanStage final : public PlanStage {
+class CachedPlanStage final : public RequiresAllIndicesStage {
 public:
     CachedPlanStage(OperationContext* opCtx,
                     Collection* collection,
@@ -67,8 +68,6 @@ public:
 
     StageState doWork(WorkingSetID* out) final;
 
-    void doInvalidate(OperationContext* opCtx, const RecordId& dl, InvalidationType type) final;
-
     StageType stageType() const final {
         return STAGE_CACHED_PLAN;
     }
@@ -105,7 +104,7 @@ private:
      * We fallback to a new plan if updatePlanCache() tells us that the performance was worse
      * than anticipated during the trial period.
      *
-     * We only write the result of re-planning to the plan cache if 'shouldCache' is true.
+     * We only modify the plan cache if 'shouldCache' is true.
      */
     Status replan(PlanYieldPolicy* yieldPolicy, bool shouldCache);
 
@@ -118,9 +117,6 @@ private:
      */
     Status tryYield(PlanYieldPolicy* yieldPolicy);
 
-    // Not owned. Must be non-null.
-    Collection* _collection;
-
     // Not owned.
     WorkingSet* _ws;
 
@@ -138,13 +134,7 @@ private:
     std::unique_ptr<QuerySolution> _replannedQs;
 
     // Any results produced during trial period execution are kept here.
-    std::list<WorkingSetID> _results;
-
-    // When a stage requests a yield for document fetch, it gives us back a RecordFetcher*
-    // to use to pull the record into memory. We take ownership of the RecordFetcher here,
-    // deleting it after we've had a chance to do the fetch. For timing-based yields, we
-    // just pass a NULL fetcher.
-    std::unique_ptr<RecordFetcher> _fetcher;
+    std::queue<WorkingSetID> _results;
 
     // Stats
     CachedPlanStats _specificStats;
