@@ -1,6 +1,3 @@
-// fts_query_impl.cpp
-
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -38,15 +35,12 @@
 #include "mongo/db/fts/fts_spec.h"
 #include "mongo/db/fts/fts_tokenizer.h"
 #include "mongo/stdx/memory.h"
-#include "mongo/util/mongoutils/str.h"
-#include "mongo/util/stringutils.h"
+#include "mongo/util/str.h"
 
 namespace mongo {
 
 namespace fts {
 
-using namespace mongoutils;
-
 using std::set;
 using std::string;
 using std::stringstream;
@@ -209,5 +203,5 @@ BSONObj FTSQueryImpl::toBSON() const {
     bob.append("negatedPhrases", getNegatedPhr());
     return bob.obj();
 }
-}
-}
+}  // namespace fts
+}  // namespace mongo
