@@ -1,23 +1,24 @@
 /**
- *    Copyright (C) 2012 10gen Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -40,17 +41,14 @@
 #include "mongo/db/jsobj.h"
 #include "mongo/stdx/memory.h"
 #include "mongo/util/log.h"
-#include "mongo/util/mongoutils/str.h"
+#include "mongo/util/str.h"
 #include "mongo/util/transitional_tools_do_not_use/vector_spooling.h"
 #include "third_party/s2/s2polygonbuilder.h"
 
-#define BAD_VALUE(error) Status(ErrorCodes::BadValue, ::mongoutils::str::stream() << error)
+#define BAD_VALUE(error) Status(ErrorCodes::BadValue, str::stream() << error)
 
 namespace mongo {
 
-using std::unique_ptr;
-using std::stringstream;
-
 namespace dps = ::mongo::dotted_path_support;
 
 // This field must be present, and...
@@ -115,7 +113,7 @@ static Status coordToPoint(double lng, double lat, S2Point* out) {
     S2LatLng ll = S2LatLng::FromDegrees(lat, lng).Normalized();
     // This shouldn't happen since we should only have valid lng/lats.
     if (!ll.is_valid()) {
-        stringstream ss;
+        std::stringstream ss;
         ss << "coords invalid after normalization, lng = " << lng << " lat = " << lat << endl;
         uasserted(17125, ss.str());
     }
@@ -233,8 +231,7 @@ static Status parseGeoJSONPolygonCoordinates(const BSONElement& elem,
                 "Secondary loops not contained by first exterior loop - "
                 "secondary loops must be holes: "
                 << coordinateElt.toString(false)
-                << " first loop: "
-                << elem.Obj().firstElement().toString(false));
+                << " first loop: " << elem.Obj().firstElement().toString(false));
         }
     }
 
@@ -324,7 +321,7 @@ static Status parseBigSimplePolygonCoordinates(const BSONElement& elem, BigSimpl
         return BAD_VALUE("Loop must have at least 3 different vertices: " << elem.toString(false));
     }
 
-    unique_ptr<S2Loop> loop(new S2Loop(exteriorVertices));
+    std::unique_ptr<S2Loop> loop(new S2Loop(exteriorVertices));
     // Check whether this loop is valid.
     if (!loop->IsValid(&err)) {
         return BAD_VALUE("Loop is not valid: " << elem.toString(false) << " " << err);
@@ -775,16 +772,16 @@ GeoParser::GeoSpecifier GeoParser::parseGeoSpecifier(const BSONElement& type) {
     if (!type.isABSONObj()) {
         return GeoParser::UNKNOWN;
     }
-    const char* fieldName = type.fieldName();
-    if (mongoutils::str::equals(fieldName, "$box")) {
+    StringData fieldName = type.fieldNameStringData();
+    if (fieldName == "$box") {
         return GeoParser::BOX;
-    } else if (mongoutils::str::equals(fieldName, "$center")) {
+    } else if (fieldName == "$center") {
         return GeoParser::CENTER;
-    } else if (mongoutils::str::equals(fieldName, "$polygon")) {
+    } else if (fieldName == "$polygon") {
         return GeoParser::POLYGON;
-    } else if (mongoutils::str::equals(fieldName, "$centerSphere")) {
+    } else if (fieldName == "$centerSphere") {
         return GeoParser::CENTER_SPHERE;
-    } else if (mongoutils::str::equals(fieldName, "$geometry")) {
+    } else if (fieldName == "$geometry") {
         return GeoParser::GEOMETRY;
     }
     return GeoParser::UNKNOWN;
