@@ -56,7 +56,7 @@ ThreadPool::Options makeDefaultThreadPoolOptions() {
     ThreadPool::Options options;
     options.poolName = "IndexBuildsCoordinatorMongod";
     options.minThreads = 0;
-    options.maxThreads = 10;
+    options.maxThreads = 3;
 
     // Ensure all threads have a client.
     options.onCreateThread = [](const std::string& threadName) {
@@ -73,6 +73,11 @@ IndexBuildsCoordinatorMongod::IndexBuildsCoordinatorMongod()
     _threadPool.startup();
 }
 
+IndexBuildsCoordinatorMongod::IndexBuildsCoordinatorMongod(ThreadPool::Options options)
+    : _threadPool(std::move(options)) {
+    _threadPool.startup();
+}
+
 void IndexBuildsCoordinatorMongod::shutdown() {
     // Stop new scheduling.
     _threadPool.shutdown();
