@@ -822,11 +822,11 @@ TEST(SplitMatchExpression, AndWithSplittableChildrenIsSplittable) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
 
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{a: {$eq: 1}}"));
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{b: {$eq: 1}}"));
@@ -844,11 +844,11 @@ TEST(SplitMatchExpression, NorWithIndependentChildrenIsSplittable) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
 
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{$nor: [{a: {$eq: 1}}]}"));
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{$nor: [{b: {$eq: 1}}]}"));
@@ -866,7 +866,7 @@ TEST(SplitMatchExpression, NotWithIndependentChildIsSplittable) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
 
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{x: {$not: {$gt: 4}}}"));
     ASSERT_FALSE(splitExpr.second);
@@ -884,7 +884,7 @@ TEST(SplitMatchExpression, OrWithOnlyIndependentChildrenIsNotSplittable) {
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder bob;
-    splitExpr.second->serialize(&bob);
+    splitExpr.second->serialize(&bob, true);
 
     ASSERT_FALSE(splitExpr.first);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$or: [{a: {$eq: 1}}, {b: {$eq: 1}}]}"));
@@ -905,11 +905,11 @@ TEST(SplitMatchExpression, ComplexMatchExpressionSplitsCorrectly) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
 
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{$or: [{'a.b': {$eq: 3}}, {'a.b.c': {$eq: 4}}]}"));
     ASSERT_BSONOBJ_EQ(secondBob.obj(),
@@ -930,11 +930,11 @@ TEST(SplitMatchExpression, ShouldNotExtractPrefixOfDottedPathAsIndependent) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
 
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{'a.c': {$eq: 1}}"));
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{$and: [{a: {$eq: 1}}, {'a.b': {$eq: 1}}]}"));
@@ -952,7 +952,7 @@ TEST(SplitMatchExpression, ShouldMoveIndependentLeafPredicateAcrossRename) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{b: {$eq: 1}}"));
 
     ASSERT_FALSE(splitExpr.second.get());
@@ -970,7 +970,7 @@ TEST(SplitMatchExpression, ShouldMoveIndependentAndPredicateAcrossRename) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{$and: [{c: {$eq: 1}}, {b: {$eq: 2}}]}"));
 
     ASSERT_FALSE(splitExpr.second.get());
@@ -988,12 +988,12 @@ TEST(SplitMatchExpression, ShouldSplitPartiallyDependentAndPredicateAcrossRename
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{c: {$eq: 1}}"));
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{b: {$eq: 2}}"));
 }
 
@@ -1009,12 +1009,12 @@ TEST(SplitMatchExpression, ShouldSplitPartiallyDependentComplexPredicateMultiple
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{$or: [{d: {$eq: 2}}, {e: {$eq: 3}}]}"));
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{a: {$eq: 1}}"));
 }
 
@@ -1031,12 +1031,12 @@ TEST(SplitMatchExpression,
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{$or: [{x: {$eq: 2}}, {y: {$eq: 3}}]}"));
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{a: {$eq: 1}}"));
 }
 
@@ -1054,7 +1054,7 @@ TEST(SplitMatchExpression, ShouldNotMoveElemMatchObjectAcrossRename) {
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{a: {$elemMatch: {b: {$eq: 3}}}}"));
 }
 
@@ -1072,7 +1072,7 @@ TEST(SplitMatchExpression, ShouldNotMoveElemMatchValueAcrossRename) {
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{a: {$elemMatch: {$eq: 3}}}"));
 }
 
@@ -1088,7 +1088,7 @@ TEST(SplitMatchExpression, ShouldMoveTypeAcrossRename) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{c: {$type: [16]}}"));
 
     ASSERT_FALSE(splitExpr.second.get());
@@ -1108,7 +1108,7 @@ TEST(SplitMatchExpression, ShouldNotMoveSizeAcrossRename) {
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{a: {$size: 3}}"));
 }
 
@@ -1126,7 +1126,7 @@ TEST(SplitMatchExpression, ShouldNotMoveMinItemsAcrossRename) {
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{a: {$_internalSchemaMinItems: 3}}"));
 }
 
@@ -1144,7 +1144,7 @@ TEST(SplitMatchExpression, ShouldNotMoveMaxItemsAcrossRename) {
 
     ASSERT_TRUE(splitExpr.second.get());
     BSONObjBuilder secondBob;
-    splitExpr.second->serialize(&secondBob);
+    splitExpr.second->serialize(&secondBob, true);
     ASSERT_BSONOBJ_EQ(secondBob.obj(), fromjson("{a: {$_internalSchemaMaxItems: 3}}"));
 }
 
@@ -1160,7 +1160,7 @@ TEST(SplitMatchExpression, ShouldMoveMinLengthAcrossRename) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{c: {$_internalSchemaMinLength: 3}}"));
 
     ASSERT_FALSE(splitExpr.second.get());
@@ -1178,7 +1178,7 @@ TEST(SplitMatchExpression, ShouldMoveMaxLengthAcrossRename) {
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{c: {$_internalSchemaMaxLength: 3}}"));
 
     ASSERT_FALSE(splitExpr.second.get());
@@ -1197,7 +1197,7 @@ TEST(SplitMatchExpression, ShouldMoveIndependentPredicateWhenThereAreMultipleRen
 
     ASSERT_TRUE(splitExpr.first.get());
     BSONObjBuilder firstBob;
-    splitExpr.first->serialize(&firstBob);
+    splitExpr.first->serialize(&firstBob, true);
     ASSERT_BSONOBJ_EQ(firstBob.obj(), fromjson("{x: {$eq: 3}}"));
 
     ASSERT_FALSE(splitExpr.second.get());
