@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -41,7 +40,7 @@
 
 namespace pcrecpp {
 class RE;
-}  // namespace pcrecpp;
+}  // namespace pcrecpp
 
 namespace mongo {
 
@@ -105,7 +104,7 @@ public:
 
     virtual ~ComparisonMatchExpressionBase() = default;
 
-    virtual void debugString(StringBuilder& debug, int level = 0) const;
+    virtual void debugString(StringBuilder& debug, int indentationLevel = 0) const;
 
     BSONObj getSerializedRightHandSide() const final;
 
@@ -120,6 +119,14 @@ public:
         return _rhs;
     }
 
+    /**
+     * Replaces the RHS element of this expression. The caller is responsible for ensuring that the
+     * BSONObj backing 'elem' outlives this MatchExpression.
+     */
+    void setData(BSONElement elem) {
+        _rhs = elem;
+    }
+
     const CollatorInterface* getCollator() const {
         return _collator;
     }
@@ -283,7 +290,6 @@ public:
 
 class RegexMatchExpression : public LeafMatchExpression {
 public:
-    static constexpr size_t kMaxPatternSize = 32764;
     static const std::set<char> kValidRegexFlags;
 
     RegexMatchExpression(StringData path, const BSONElement& e);
@@ -302,7 +308,7 @@ public:
 
     bool matchesSingleElement(const BSONElement&, MatchDetails* details = nullptr) const final;
 
-    virtual void debugString(StringBuilder& debug, int level) const;
+    virtual void debugString(StringBuilder& debug, int indentationLevel) const;
 
     BSONObj getSerializedRightHandSide() const final;
 
@@ -346,7 +352,7 @@ public:
 
     bool matchesSingleElement(const BSONElement&, MatchDetails* details = nullptr) const final;
 
-    virtual void debugString(StringBuilder& debug, int level) const;
+    virtual void debugString(StringBuilder& debug, int indentationLevel) const;
 
     BSONObj getSerializedRightHandSide() const final;
 
@@ -382,7 +388,7 @@ public:
 
     bool matchesSingleElement(const BSONElement&, MatchDetails* details = nullptr) const final;
 
-    virtual void debugString(StringBuilder& debug, int level) const;
+    virtual void debugString(StringBuilder& debug, int indentationLevel) const;
 
     BSONObj getSerializedRightHandSide() const final;
 
@@ -405,7 +411,7 @@ public:
 
     bool matchesSingleElement(const BSONElement&, MatchDetails* details = nullptr) const final;
 
-    virtual void debugString(StringBuilder& debug, int level) const;
+    virtual void debugString(StringBuilder& debug, int indentationLevel) const;
 
     BSONObj getSerializedRightHandSide() const final;
 
@@ -420,10 +426,12 @@ public:
 
     Status addRegex(std::unique_ptr<RegexMatchExpression> expr);
 
-    const BSONEltFlatSet& getEqualities() const {
+    const std::vector<BSONElement>& getEqualities() const {
         return _equalitySet;
     }
 
+    bool contains(const BSONElement& e) const;
+
     const std::vector<std::unique_ptr<RegexMatchExpression>>& getRegexes() const {
         return _regexes;
     }
@@ -459,15 +467,16 @@ private:
     // '_equalitySet' in case '_collator' changes after elements have been added.
     //
     // We keep the equalities in sorted order according to the current BSON element comparator. This
-    // list of equalities will be used to construct a boost::flat_set, which maintains the set of
-    // elements in sorted order within a contiguous region of memory. Sorting and then constructing
-    // a flat_set is O(n log n), whereas the boost::flat_set constructor is O(n ^ 2) due to
-    // https://svn.boost.org/trac10/ticket/13140.
+    // enables a fast-path to avoid re-sorting if the expression is serialized and re-parsed.
     std::vector<BSONElement> _originalEqualityVector;
 
-    // Set of equality elements associated with this expression. '_eltCmp' is used as a comparator
-    // for this set.
-    BSONEltFlatSet _equalitySet;
+    // Deduped set of equality elements associated with this expression. Kept in sorted order to
+    // support std::binary_search. Because we need to sort the elements anyway for things like index
+    // bounds building, using binary search avoids the overhead of inserting into a hash table which
+    // doesn't pay for itself in the common case where lookups are done a few times if ever.
+    // TODO It may be worth dynamically creating a hashset after matchesSingleElement() has been
+    // called "many" times.
+    std::vector<BSONElement> _equalitySet;
 
     // Container of regex elements this object owns.
     std::vector<std::unique_ptr<RegexMatchExpression>> _regexes;
@@ -494,7 +503,7 @@ public:
 
     bool matchesSingleElement(const BSONElement&, MatchDetails* details = nullptr) const final;
 
-    virtual void debugString(StringBuilder& debug, int level) const;
+    virtual void debugString(StringBuilder& debug, int indentationLevel) const;
 
     BSONObj getSerializedRightHandSide() const final;
 
