@@ -347,7 +347,7 @@ TEST(ExpressionOptimizeTest, AndWithAlwaysFalseChildOptimizesToAlwaysFalse) {
     std::unique_ptr<MatchExpression> matchExpression(parseMatchExpression(obj));
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$alwaysFalse: 1}"));
 }
 
@@ -356,7 +356,7 @@ TEST(ExpressionOptimizeTest, AndRemovesAlwaysTrueChildren) {
     std::unique_ptr<MatchExpression> matchExpression(parseMatchExpression(obj));
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{a: {$eq: 1}}"));
 }
 
@@ -367,7 +367,7 @@ TEST(ExpressionOptimizeTest, AndWithSingleChildAlwaysTrueOptimizesToEmptyAnd) {
     // TODO SERVER-34759 We want this to optimize to an AlwaysTrueMatchExpression.
     ASSERT_TRUE(dynamic_cast<AndMatchExpression*>(optimizedMatchExpression.get()));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{}"));
 }
 
@@ -378,7 +378,7 @@ TEST(ExpressionOptimizeTest, AndWithEachChildAlwaysTrueOptimizesToEmptyAnd) {
     // TODO SERVER-34759 We want this to optimize to an AlwaysTrueMatchExpression.
     ASSERT_TRUE(dynamic_cast<AndMatchExpression*>(optimizedMatchExpression.get()));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{}"));
 }
 
@@ -387,7 +387,7 @@ TEST(ExpressionOptimizeTest, NestedAndWithAlwaysFalseOptimizesToAlwaysFalse) {
     std::unique_ptr<MatchExpression> matchExpression(parseMatchExpression(obj));
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$alwaysFalse: 1}"));
 }
 
@@ -396,7 +396,7 @@ TEST(ExpressionOptimizeTest, OrWithAlwaysTrueOptimizesToAlwaysTrue) {
     std::unique_ptr<MatchExpression> matchExpression(parseMatchExpression(obj));
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$alwaysTrue: 1}"));
 }
 
@@ -405,7 +405,7 @@ TEST(ExpressionOptimizeTest, OrRemovesAlwaysFalseChildren) {
     std::unique_ptr<MatchExpression> matchExpression(parseMatchExpression(obj));
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{a: {$eq: 1}}"));
 }
 
@@ -416,7 +416,7 @@ TEST(ExpressionOptimizeTest, OrPromotesSingleAlwaysFalseAfterOptimize) {
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     ASSERT_TRUE(dynamic_cast<AlwaysFalseMatchExpression*>(optimizedMatchExpression.get()));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$alwaysFalse: 1}"));
 }
 
@@ -426,7 +426,7 @@ TEST(ExpressionOptimizeTest, OrPromotesSingleAlwaysFalse) {
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     ASSERT_TRUE(dynamic_cast<AlwaysFalseMatchExpression*>(optimizedMatchExpression.get()));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$alwaysFalse: 1}"));
 }
 
@@ -436,7 +436,7 @@ TEST(ExpressionOptimizeTest, OrPromotesMultipleAlwaysFalse) {
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     ASSERT_TRUE(dynamic_cast<AlwaysFalseMatchExpression*>(optimizedMatchExpression.get()));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$alwaysFalse: 1}"));
 }
 
@@ -445,7 +445,7 @@ TEST(ExpressionOptimizeTest, NestedOrWithAlwaysTrueOptimizesToAlwaysTrue) {
     std::unique_ptr<MatchExpression> matchExpression(parseMatchExpression(obj));
     auto optimizedMatchExpression = MatchExpression::optimize(std::move(matchExpression));
     BSONObjBuilder bob;
-    optimizedMatchExpression->serialize(&bob);
+    optimizedMatchExpression->serialize(&bob, true);
     ASSERT_BSONOBJ_EQ(bob.obj(), fromjson("{$alwaysTrue: 1}"));
 }
 
