@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -32,7 +31,6 @@
 
 #include <string>
 
-#include "mongo/base/disallow_copying.h"
 #include "mongo/bson/simple_bsonobj_comparator.h"
 #include "mongo/db/catalog/collection.h"
 #include "mongo/db/catalog/collection_options.h"
@@ -44,7 +42,6 @@ namespace mongo {
 
 struct InsertStatement;
 class OperationContext;
-struct OplogSlot;
 
 namespace repl {
 class OpTime;
@@ -54,31 +51,13 @@ class OpTime;
  * Holds document update information used in logging.
  */
 struct OplogUpdateEntryArgs {
-    enum class StoreDocOption { None, PreImage, PostImage };
+    CollectionUpdateArgs updateArgs;
 
-    // Name of the collection in which document is being updated.
     NamespaceString nss;
+    CollectionUUID uuid;
 
-    OptionalCollectionUUID uuid;
-
-    StmtId stmtId = kUninitializedStmtId;
-
-    // The document before modifiers were applied.
-    boost::optional<BSONObj> preImageDoc;
-
-    // Fully updated document with damages (update modifiers) applied.
-    BSONObj updatedDoc;
-
-    // Document containing update modifiers -- e.g. $set and $unset
-    BSONObj update;
-
-    // Document containing the _id field of the doc being updated.
-    BSONObj criteria;
-
-    // True if this update comes from a chunk migration.
-    bool fromMigrate = false;
-
-    StoreDocOption storeDocOption = StoreDocOption::None;
+    OplogUpdateEntryArgs(CollectionUpdateArgs updateArgs, NamespaceString nss, CollectionUUID uuid)
+        : updateArgs(std::move(updateArgs)), nss(std::move(nss)), uuid(std::move(uuid)) {}
 };
 
 struct TTLCollModInfo {
@@ -98,12 +77,44 @@ struct TTLCollModInfo {
  */
 class OpObserver {
 public:
+    enum class CollectionDropType {
+        // The collection is being dropped immediately, in one step.
+        kOnePhase,
+
+        // The collection is being dropped in two phases, by renaming to a drop pending collection
+        // which is registered to be reaped later.
+        kTwoPhase,
+    };
+
     virtual ~OpObserver() = default;
+
     virtual void onCreateIndex(OperationContext* opCtx,
                                const NamespaceString& nss,
-                               OptionalCollectionUUID uuid,
+                               CollectionUUID uuid,
                                BSONObj indexDoc,
                                bool fromMigrate) = 0;
+
+    virtual void onStartIndexBuild(OperationContext* opCtx,
+                                   const NamespaceString& nss,
+                                   CollectionUUID collUUID,
+                                   const UUID& indexBuildUUID,
+                                   const std::vector<BSONObj>& indexes,
+                                   bool fromMigrate) = 0;
+
+    virtual void onCommitIndexBuild(OperationContext* opCtx,
+                                    const NamespaceString& nss,
+                                    CollectionUUID collUUID,
+                                    const UUID& indexBuildUUID,
+                                    const std::vector<BSONObj>& indexes,
+                                    bool fromMigrate) = 0;
+
+    virtual void onAbortIndexBuild(OperationContext* opCtx,
+                                   const NamespaceString& nss,
+                                   CollectionUUID collUUID,
+                                   const UUID& indexBuildUUID,
+                                   const std::vector<BSONObj>& indexes,
+                                   bool fromMigrate) = 0;
+
     virtual void onInserts(OperationContext* opCtx,
                            const NamespaceString& nss,
                            OptionalCollectionUUID uuid,
@@ -196,10 +207,14 @@ public:
      * This function logs an oplog entry when a 'drop' command on a collection is executed.
      * Returns the optime of the oplog entry successfully written to the oplog.
      * Returns a null optime if an oplog entry was not written for this operation.
+     *
+     * 'dropType' describes whether the collection drop is one-phase or two-phase.
      */
     virtual repl::OpTime onDropCollection(OperationContext* opCtx,
                                           const NamespaceString& collectionName,
-                                          OptionalCollectionUUID uuid) = 0;
+                                          OptionalCollectionUUID uuid,
+                                          std::uint64_t numRecords,
+                                          CollectionDropType dropType) = 0;
 
     /**
      * This function logs an oplog entry when an index is dropped. The namespace of the index,
@@ -229,6 +244,7 @@ public:
                                              const NamespaceString& toCollection,
                                              OptionalCollectionUUID uuid,
                                              OptionalCollectionUUID dropTargetUUID,
+                                             std::uint64_t numRecords,
                                              bool stayTemp) = 0;
     /**
      * This function performs all op observer handling for a 'renameCollection' command except for
@@ -252,6 +268,7 @@ public:
                                     const NamespaceString& toCollection,
                                     OptionalCollectionUUID uuid,
                                     OptionalCollectionUUID dropTargetUUID,
+                                    std::uint64_t numRecords,
                                     bool stayTemp) = 0;
 
     virtual void onApplyOps(OperationContext* opCtx,
@@ -260,26 +277,55 @@ public:
     virtual void onEmptyCapped(OperationContext* opCtx,
                                const NamespaceString& collectionName,
                                OptionalCollectionUUID uuid) = 0;
+
     /**
-     * The onTransactionCommit method is called on the commit of an atomic transaction, before the
-     * RecoveryUnit onCommit() is called.  It must not be called when no transaction is active.
+     * The onUnpreparedTransactionCommit method is called on the commit of an unprepared
+     * transaction, before the RecoveryUnit onCommit() is called.  It must not be called when no
+     * transaction is active.
+     *
+     * The 'statements' are the list of CRUD operations to be applied in this transaction.
      */
-    virtual void onTransactionCommit(OperationContext* opCtx) = 0;
+    virtual void onUnpreparedTransactionCommit(
+        OperationContext* opCtx, const std::vector<repl::ReplOperation>& statements) = 0;
+    /**
+     * The onPreparedTransactionCommit method is called on the commit of a prepared transaction,
+     * after the RecoveryUnit onCommit() is called.  It must not be called when no transaction is
+     * active.
+     *
+     * The 'commitOplogEntryOpTime' is passed in to be used as the OpTime of the oplog entry. The
+     * 'commitTimestamp' is the timestamp at which the multi-document transaction was committed.
+     *
+     * The 'statements' are the list of CRUD operations to be applied in this transaction.
+     */
+    virtual void onPreparedTransactionCommit(
+        OperationContext* opCtx,
+        OplogSlot commitOplogEntryOpTime,
+        Timestamp commitTimestamp,
+        const std::vector<repl::ReplOperation>& statements) noexcept = 0;
 
     /**
      * The onTransactionPrepare method is called when an atomic transaction is prepared. It must be
-     * called when a transaction is active. It generates an OpTime and sets the prepare timestamp on
-     * the recovery unit.
-     * TODO: This is an incomplete implementation and should only be used for testing. It does not
-     * write the prepare oplog entry, only generates an OpTime.
+     * called when a transaction is active.
+     *
+     * 'reservedSlots' is a list of oplog slots reserved for the oplog entries in a transaction. The
+     * last reserved slot represents the prepareOpTime used for the prepare oplog entry.
+     *
+     * The 'statements' are the list of CRUD operations to be applied in this transaction.
      */
-    virtual void onTransactionPrepare(OperationContext* opCtx) = 0;
+    virtual void onTransactionPrepare(OperationContext* opCtx,
+                                      const std::vector<OplogSlot>& reservedSlots,
+                                      std::vector<repl::ReplOperation>& statements) = 0;
 
     /**
      * The onTransactionAbort method is called when an atomic transaction aborts, before the
-     * RecoveryUnit onRollback() is called.  It must not be called when no transaction is active.
+     * RecoveryUnit onRollback() is called. It must not be called when the transaction to abort is
+     * active.
+     *
+     * If the transaction was prepared, then 'abortOplogEntryOpTime' is passed in to be used as the
+     * OpTime of the oplog entry.
      */
-    virtual void onTransactionAbort(OperationContext* opCtx) = 0;
+    virtual void onTransactionAbort(OperationContext* opCtx,
+                                    boost::optional<OplogSlot> abortOplogEntryOpTime) = 0;
 
     /**
      * A structure to hold information about a replication rollback suitable to be passed along to
