@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -57,7 +56,7 @@ class NamespaceString;
  * stage which will produce a document like the following:
  * {facetA: [<all input documents except the first one>], facetB: [<the first document>]}.
  */
-class DocumentSourceFacet final : public DocumentSource, public NeedsMergerDocumentSource {
+class DocumentSourceFacet final : public DocumentSource {
 public:
     struct FacetPipeline {
         FacetPipeline(std::string name, std::unique_ptr<Pipeline, PipelineDeleter> pipeline)
@@ -82,6 +81,17 @@ public:
 
         stdx::unordered_set<NamespaceString> getInvolvedNamespaces() const final;
 
+        bool allowShardedForeignCollection(NamespaceString nss) const final;
+
+        bool allowedToPassthroughFromMongos() const {
+            // If any of the sub-pipelines doesn't allow pass through, then return false.
+            return std::all_of(_liteParsedPipelines.cbegin(),
+                               _liteParsedPipelines.cend(),
+                               [](const auto& subPipeline) {
+                                   return subPipeline.allowedToPassthroughFromMongos();
+                               });
+        }
+
     private:
         const std::vector<LiteParsedPipeline> _liteParsedPipelines;
         const PrivilegeVector _requiredPrivileges;
@@ -107,7 +117,7 @@ public:
     /**
      * Takes a union of all sub-pipelines, and adds them to 'deps'.
      */
-    GetDepsReturn getDependencies(DepsTracker* deps) const final;
+    DepsTracker::State getDependencies(DepsTracker* deps) const final;
 
     const char* getSourceName() const final {
         return "$facet";
@@ -124,22 +134,25 @@ public:
      * TODO SERVER-24154: Should be smarter about splitting so that parts of the sub-pipelines can
      * potentially be run in parallel on multiple shards.
      */
-    boost::intrusive_ptr<DocumentSource> getShardSource() final {
-        return nullptr;
-    }
-    std::list<boost::intrusive_ptr<DocumentSource>> getMergeSources() final {
-        return {this};
+    boost::optional<DistributedPlanLogic> distributedPlanLogic() final {
+        // {shardsStage, mergingStage, sortPattern}
+        return DistributedPlanLogic{nullptr, this, boost::none};
     }
 
     const std::vector<FacetPipeline>& getFacetPipelines() const {
         return _facets;
     }
 
+    auto& getFacetPipelines() {
+        return _facets;
+    }
+
     // The following are overridden just to forward calls to sub-pipelines.
-    void addInvolvedCollections(std::vector<NamespaceString>* collections) const final;
+    void addInvolvedCollections(stdx::unordered_set<NamespaceString>* involvedNssSet) const final;
     void detachFromOperationContext() final;
     void reattachToOperationContext(OperationContext* opCtx) final;
     StageConstraints constraints(Pipeline::SplitState pipeState) const final;
+    bool usedDisk() final;
 
 protected:
     void doDispose() final;
