@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -83,17 +82,7 @@ public:
         return kStageName;
     }
 
-    Pipeline::SourceContainer::iterator doOptimizeAt(Pipeline::SourceContainer::iterator itr,
-                                                     Pipeline::SourceContainer* container) final {
-        // Because this stage needs to serialize its original specification to send to the shards in
-        // a sharded cluster, we must override and prevent the $match-$match combining optimization
-        // we inherit from DocumentSourceMatch. For more details, see SERVER-37200.
-        return std::next(itr);
-    }
-
-    Value serialize(boost::optional<ExplainOptions::Verbosity> explain = boost::none) const final {
-        return Value(Document{{getSourceName(), _spec.toBSON()}});
-    }
+    Value serialize(boost::optional<ExplainOptions::Verbosity> explain = boost::none) const final;
 
     StageConstraints constraints(Pipeline::SplitState pipeState) const final {
         return {StreamType::kStreaming,
@@ -101,7 +90,8 @@ public:
                 HostTypeRequirement::kNone,
                 DiskUseRequirement::kNoDiskUse,
                 FacetRequirement::kNotAllowed,
-                TransactionRequirement::kNotAllowed};
+                TransactionRequirement::kNotAllowed,
+                LookupRequirement::kAllowed};
     }
 
     static boost::intrusive_ptr<DocumentSource> createFromBson(
@@ -110,10 +100,12 @@ public:
 private:
     DocumentSourceListSessions(const BSONObj& query,
                                const boost::intrusive_ptr<ExpressionContext>& pExpCtx,
-                               const ListSessionsSpec& spec)
-        : DocumentSourceMatch(query, pExpCtx), _spec(spec) {}
+                               const bool allUsers,
+                               const boost::optional<std::vector<mongo::ListSessionsUser>>& users)
+        : DocumentSourceMatch(query, pExpCtx), _allUsers(allUsers), _users(users) {}
 
-    const ListSessionsSpec _spec;
+    bool _allUsers;
+    boost::optional<std::vector<mongo::ListSessionsUser>> _users;
 };
 
 }  // namespace mongo
