@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -44,14 +43,9 @@ Value assertFieldHasType(const Document& fullDoc, StringData fieldName, BSONType
     auto val = fullDoc[fieldName];
     uassert(40578,
             str::stream() << "failed to look up post image after change: expected \"" << fieldName
-                          << "\" field to have type "
-                          << typeName(expectedType)
-                          << ", instead found type "
-                          << typeName(val.getType())
-                          << ": "
-                          << val.toString()
-                          << ", full object: "
-                          << fullDoc.toString(),
+                          << "\" field to have type " << typeName(expectedType)
+                          << ", instead found type " << typeName(val.getType()) << ": "
+                          << val.toString() << ", full object: " << fullDoc.toString(),
             val.getType() == expectedType);
     return val;
 }
@@ -89,8 +83,7 @@ NamespaceString DocumentSourceLookupChangePostImage::assertValidNamespace(
     // lookup into any namespace.
     uassert(40579,
             str::stream() << "unexpected namespace during post image lookup: " << nss.ns()
-                          << ", expected "
-                          << pExpCtx->ns.ns(),
+                          << ", expected " << pExpCtx->ns.ns(),
             nss == pExpCtx->ns ||
                 (pExpCtx->isClusterAggregation() || pExpCtx->isDBAggregation(nss.db())));
 
@@ -113,12 +106,21 @@ Value DocumentSourceLookupChangePostImage::lookupPostImage(const Document& updat
     const auto readConcern = pExpCtx->inMongos
         ? boost::optional<BSONObj>(BSON("level"
                                         << "majority"
-                                        << "afterClusterTime"
-                                        << resumeToken.getData().clusterTime))
+                                        << "afterClusterTime" << resumeToken.getData().clusterTime))
         : boost::none;
+
+
+    // Update lookup queries sent from mongoS to shards are allowed to use speculative majority
+    // reads.
+    const auto allowSpeculativeMajorityRead = pExpCtx->inMongos;
     invariant(resumeToken.getData().uuid);
-    auto lookedUpDoc = pExpCtx->mongoProcessInterface->lookupSingleDocument(
-        pExpCtx, nss, *resumeToken.getData().uuid, documentKey, readConcern);
+    auto lookedUpDoc =
+        pExpCtx->mongoProcessInterface->lookupSingleDocument(pExpCtx,
+                                                             nss,
+                                                             *resumeToken.getData().uuid,
+                                                             documentKey,
+                                                             readConcern,
+                                                             allowSpeculativeMajorityRead);
 
     // Check whether the lookup returned any documents. Even if the lookup itself succeeded, it may
     // not have returned any results if the document was deleted in the time since the update op.
