@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -53,8 +52,17 @@ namespace parsed_aggregation_projection {
  */
 class ParsedAddFields : public ParsedAggregationProjection {
 public:
+    /**
+     * TODO SERVER-25510: The ParsedAggregationProjection _id and array-recursion policies are not
+     * applicable to the $addFields "projection" stage. We make them non-configurable here.
+     */
     ParsedAddFields(const boost::intrusive_ptr<ExpressionContext>& expCtx)
-        : ParsedAggregationProjection(expCtx), _root(new InclusionNode()) {}
+        : ParsedAggregationProjection(
+              expCtx,
+              {ProjectionPolicies::DefaultIdPolicy::kIncludeId,
+               ProjectionPolicies::ArrayRecursionPolicy::kRecurseNestedArrays,
+               ProjectionPolicies::ComputedFieldsPolicy::kAllowComputedFields}),
+          _root(new InclusionNode(_policies)) {}
 
     /**
      * Creates the data needed to perform an AddFields.
@@ -68,15 +76,18 @@ public:
         return TransformerType::kComputedProjection;
     }
 
+    const InclusionNode& getRoot() const {
+        return *_root;
+    }
+
     /**
      * Parses the addFields specification given by 'spec', populating internal data structures.
      */
     void parse(const BSONObj& spec) final;
 
-    Document serializeStageOptions(boost::optional<ExplainOptions::Verbosity> explain) const final {
-        MutableDocument output;
-        _root->serialize(&output, explain);
-        return output.freeze();
+    Document serializeTransformation(
+        boost::optional<ExplainOptions::Verbosity> explain) const final {
+        return _root->serialize(explain);
     }
 
     /**
@@ -86,15 +97,15 @@ public:
         _root->optimize();
     }
 
-    DocumentSource::GetDepsReturn addDependencies(DepsTracker* deps) const final {
-        _root->addDependencies(deps);
-        return DocumentSource::SEE_NEXT;
+    DepsTracker::State addDependencies(DepsTracker* deps) const final {
+        _root->reportDependencies(deps);
+        return DepsTracker::State::SEE_NEXT;
     }
 
     DocumentSource::GetModPathsReturn getModifiedPaths() const final {
         std::set<std::string> computedPaths;
         StringMap<std::string> renamedPaths;
-        _root->addComputedPaths(&computedPaths, &renamedPaths);
+        _root->reportComputedPaths(&computedPaths, &renamedPaths);
         return {DocumentSource::GetModPathsReturn::Type::kFiniteSet,
                 std::move(computedPaths),
                 std::move(renamedPaths)};
