@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -43,13 +42,12 @@
 #include "mongo/db/pipeline/parsed_inclusion_projection.h"
 #include "mongo/stdx/unordered_set.h"
 #include "mongo/util/assert_util.h"
-#include "mongo/util/mongoutils/str.h"
+#include "mongo/util/str.h"
 
 namespace mongo {
 namespace parsed_aggregation_projection {
 
-using TransformerType =
-    DocumentSourceSingleDocumentTransformation::TransformerInterface::TransformerType;
+using TransformerType = TransformerInterface::TransformerType;
 
 using expression::isPathPrefixOf;
 
@@ -88,11 +86,7 @@ void ProjectionSpecValidator::ensurePathDoesNotConflictOrThrow(const std::string
     uassert(40176,
             str::stream() << "specification contains two conflicting paths. "
                              "Cannot specify both '"
-                          << path
-                          << "' and '"
-                          << *conflictingPath
-                          << "': "
-                          << _rawObj.toString(),
+                          << path << "' and '" << *conflictingPath << "': " << _rawObj.toString(),
             !conflictingPath);
 }
 
@@ -131,10 +125,8 @@ void ProjectionSpecValidator::parseNestedObject(const BSONObj& thisLevelSpec,
                 uasserted(40181,
                           str::stream() << "an expression specification must contain exactly "
                                            "one field, the name of the expression. Found "
-                                        << thisLevelSpec.nFields()
-                                        << " fields in "
-                                        << thisLevelSpec.toString()
-                                        << ", while parsing object "
+                                        << thisLevelSpec.nFields() << " fields in "
+                                        << thisLevelSpec.toString() << ", while parsing object "
                                         << _rawObj.toString());
             }
             ensurePathDoesNotConflictOrThrow(prefix.fullPath());
@@ -143,8 +135,7 @@ void ProjectionSpecValidator::parseNestedObject(const BSONObj& thisLevelSpec,
         if (fieldName.find('.') != std::string::npos) {
             uasserted(40183,
                       str::stream() << "cannot use dotted field name '" << fieldName
-                                    << "' in a sub object: "
-                                    << _rawObj.toString());
+                                    << "' in a sub object: " << _rawObj.toString());
         }
         parseElement(elem, FieldPath::getFullyQualifiedPath(prefix.fullPath(), fieldName));
     }
@@ -152,6 +143,15 @@ void ProjectionSpecValidator::parseNestedObject(const BSONObj& thisLevelSpec,
 
 namespace {
 
+using ProjectionPolicies = ParsedAggregationProjection::ProjectionPolicies;
+using ComputedFieldsPolicy = ProjectionPolicies::ComputedFieldsPolicy;
+
+std::string makeBannedComputedFieldsErrorMessage(BSONObj projSpec) {
+    return str::stream() << "Bad projection specification, cannot use computed fields when parsing "
+                            "a spec in kBanComputedFields mode: "
+                         << projSpec.toString();
+}
+
 /**
  * This class is responsible for determining what type of $project stage it specifies.
  */
@@ -160,27 +160,18 @@ public:
     /**
      * Parses 'spec' to determine whether it is an inclusion or exclusion projection. 'Computed'
      * fields (ones which are defined by an expression or a literal) are treated as inclusion
-     * projections for in this context of the$project stage.
+     * projections for in this context of the $project stage.
      */
-    static TransformerType parse(const BSONObj& spec) {
-        ProjectTypeParser parser(spec);
+    static TransformerType parse(const BSONObj& spec, ProjectionPolicies policies) {
+        ProjectTypeParser parser(spec, policies);
         parser.parse();
         invariant(parser._parsedType);
         return *(parser._parsedType);
     }
 
 private:
-    ProjectTypeParser(const BSONObj& spec) : _rawObj(spec) {}
-
-    /**
-     * Parses a single BSONElement, with 'fieldName' representing the path used for projection
-     * inclusion or exclusion. This code was broken out into a separate function as a workaround for
-     * SERVER-33125.
-     */
-    void parseElementWithFieldName(BSONElement elem, StringData fieldName) {
-        FieldPath elemPath(fieldName);
-        parseElement(elem, elemPath);
-    }
+    ProjectTypeParser(const BSONObj& spec, ProjectionPolicies policies)
+        : _rawObj(spec), _policies(policies) {}
 
     /**
      * Traverses '_rawObj' to determine the type of projection, populating '_parsedType' in the
@@ -189,7 +180,7 @@ private:
     void parse() {
         size_t nFields = 0;
         for (auto&& elem : _rawObj) {
-            parseElementWithFieldName(elem, elem.fieldName());
+            parseElement(elem, FieldPath(elem.fieldName()));
             nFields++;
         }
 
@@ -204,8 +195,7 @@ private:
 
         // Default to inclusion if nothing (except maybe '_id') is explicitly included or excluded.
         if (!_parsedType) {
-            _parsedType = DocumentSourceSingleDocumentTransformation::TransformerInterface::
-                TransformerType::kInclusionProjection;
+            _parsedType = TransformerInterface::TransformerType::kInclusionProjection;
         }
     }
 
@@ -215,49 +205,68 @@ private:
      * Delegates to parseSubObject() if 'elem' is an object. Otherwise updates '_parsedType' if
      * appropriate.
      *
-     * Throws a AssertionException if this element represents a mix of projection types.
+     * Throws a AssertionException if this element represents a mix of projection types. If we are
+     * parsing in ComputedFieldsPolicy::kBanComputedFields mode, an inclusion projection
+     * which contains computed fields will also be rejected.
      */
     void parseElement(const BSONElement& elem, const FieldPath& pathToElem) {
         if (elem.type() == BSONType::Object) {
             return parseNestedObject(elem.Obj(), pathToElem);
         }
 
-        if ((elem.isBoolean() || elem.isNumber()) && !elem.trueValue()) {
-            // A top-level exclusion of "_id" is allowed in either an inclusion projection or an
-            // exclusion projection, so doesn't affect '_parsedType'.
-            if (pathToElem.fullPath() != "_id") {
-                uassert(40178,
-                        str::stream() << "Bad projection specification, cannot exclude fields "
-                                         "other than '_id' in an inclusion projection: "
+        // If this element is not a boolean or numeric value, then it is a literal value. These are
+        // illegal if we are in kBanComputedFields parse mode.
+        uassert(ErrorCodes::FailedToParse,
+                makeBannedComputedFieldsErrorMessage(_rawObj),
+                elem.isBoolean() || elem.isNumber() ||
+                    _policies.computedFieldsPolicy != ComputedFieldsPolicy::kBanComputedFields);
+
+        if (pathToElem.fullPath() == "_id") {
+            // If the _id field is a computed value, then this must be an inclusion projection. If
+            // it is numeric or boolean, then this does not determine the projection type, due to
+            // the fact that inclusions may explicitly exclude _id and exclusions may include _id.
+            if (!elem.isBoolean() && !elem.isNumber()) {
+                uassert(ErrorCodes::FailedToParse,
+                        str::stream() << "Bad projection specification, '_id' may not be a "
+                                         "computed field in an exclusion projection: "
                                       << _rawObj.toString(),
                         !_parsedType ||
-                            (*_parsedType ==
-                             DocumentSourceSingleDocumentTransformation::TransformerInterface::
-                                 TransformerType::kExclusionProjection));
-                _parsedType = DocumentSourceSingleDocumentTransformation::TransformerInterface::
-                    TransformerType::kExclusionProjection;
+                            _parsedType ==
+                                TransformerInterface::TransformerType::kInclusionProjection);
+                _parsedType = TransformerInterface::TransformerType::kInclusionProjection;
             }
+        } else if ((elem.isBoolean() || elem.isNumber()) && !elem.trueValue()) {
+            // If this is an excluded field other than '_id', ensure that the projection type has
+            // not already been set to kInclusionProjection.
+            uassert(
+                40178,
+                str::stream() << "Bad projection specification, cannot exclude fields "
+                                 "other than '_id' in an inclusion projection: "
+                              << _rawObj.toString(),
+                !_parsedType ||
+                    (*_parsedType == TransformerInterface::TransformerType::kExclusionProjection));
+            _parsedType = TransformerInterface::TransformerType::kExclusionProjection;
         } else {
             // A boolean true, a truthy numeric value, or any expression can only be used with an
             // inclusion projection. Note that literal values like "string" or null are also treated
             // as expressions.
-            uassert(40179,
-                    str::stream() << "Bad projection specification, cannot include fields or "
-                                     "add computed fields during an exclusion projection: "
-                                  << _rawObj.toString(),
-                    !_parsedType ||
-                        (*_parsedType ==
-                         DocumentSourceSingleDocumentTransformation::TransformerInterface::
-                             TransformerType::kInclusionProjection));
-            _parsedType = DocumentSourceSingleDocumentTransformation::TransformerInterface::
-                TransformerType::kInclusionProjection;
+            uassert(
+                40179,
+                str::stream() << "Bad projection specification, cannot include fields or "
+                                 "add computed fields during an exclusion projection: "
+                              << _rawObj.toString(),
+                !_parsedType ||
+                    (*_parsedType == TransformerInterface::TransformerType::kInclusionProjection));
+            _parsedType = TransformerInterface::TransformerType::kInclusionProjection;
         }
     }
 
     /**
      * Traverses 'thisLevelSpec', parsing each element in turn.
      *
-     * Throws a AssertionException if 'thisLevelSpec' represents an invalid mix of projections.
+     * Throws a AssertionException if 'thisLevelSpec' represents an invalid mix of projections. If
+     * we are parsing in ComputedFieldsPolicy::kBanComputedFields mode, an inclusion
+     * projection which contains computed fields will also be rejected.
      */
     void parseNestedObject(const BSONObj& thisLevelSpec, const FieldPath& prefix) {
 
@@ -266,17 +275,18 @@ private:
             if (fieldName[0] == '$') {
                 // This object is an expression specification like {$add: [...]}. It will be parsed
                 // into an Expression later, but for now, just track that the prefix has been
-                // specified and skip it.
+                // specified, validate that computed projections are legal, and skip it.
+                uassert(ErrorCodes::FailedToParse,
+                        makeBannedComputedFieldsErrorMessage(_rawObj),
+                        _policies.computedFieldsPolicy != ComputedFieldsPolicy::kBanComputedFields);
                 uassert(40182,
                         str::stream() << "Bad projection specification, cannot include fields or "
                                          "add computed fields during an exclusion projection: "
                                       << _rawObj.toString(),
                         !_parsedType ||
                             _parsedType ==
-                                DocumentSourceSingleDocumentTransformation::TransformerInterface::
-                                    TransformerType::kInclusionProjection);
-                _parsedType = DocumentSourceSingleDocumentTransformation::TransformerInterface::
-                    TransformerType::kInclusionProjection;
+                                TransformerInterface::TransformerType::kInclusionProjection);
+                _parsedType = TransformerInterface::TransformerType::kInclusionProjection;
                 continue;
             }
             parseElement(elem, FieldPath::getFullyQualifiedPath(prefix.fullPath(), fieldName));
@@ -288,19 +298,24 @@ private:
 
     // This will be populated during parse().
     boost::optional<TransformerType> _parsedType;
+
+    // Policies associated with the projection which determine its runtime behaviour.
+    ProjectionPolicies _policies;
 };
 
 }  // namespace
 
 std::unique_ptr<ParsedAggregationProjection> ParsedAggregationProjection::create(
-    const boost::intrusive_ptr<ExpressionContext>& expCtx, const BSONObj& spec) {
+    const boost::intrusive_ptr<ExpressionContext>& expCtx,
+    const BSONObj& spec,
+    ProjectionPolicies policies) {
     // Check that the specification was valid. Status returned is unspecific because validate()
     // is used by the $addFields stage as well as $project.
     // If there was an error, uassert with a $project-specific message.
     ProjectionSpecValidator::uassertValid(spec, "$project");
 
     // Check for any conflicting specifications, and determine the type of the projection.
-    auto projectionType = ProjectTypeParser::parse(spec);
+    auto projectionType = ProjectTypeParser::parse(spec, policies);
     // kComputed is a projection type reserved for $addFields, and should never be detected by the
     // ProjectTypeParser.
     invariant(projectionType != TransformerType::kComputedProjection);
@@ -308,13 +323,14 @@ std::unique_ptr<ParsedAggregationProjection> ParsedAggregationProjection::create
     // We can't use make_unique() here, since the branches have different types.
     std::unique_ptr<ParsedAggregationProjection> parsedProject(
         projectionType == TransformerType::kInclusionProjection
-            ? static_cast<ParsedAggregationProjection*>(new ParsedInclusionProjection(expCtx))
-            : static_cast<ParsedAggregationProjection*>(new ParsedExclusionProjection(expCtx)));
+            ? static_cast<ParsedAggregationProjection*>(
+                  new ParsedInclusionProjection(expCtx, policies))
+            : static_cast<ParsedAggregationProjection*>(
+                  new ParsedExclusionProjection(expCtx, policies)));
 
     // Actually parse the specification.
     parsedProject->parse(spec);
     return parsedProject;
 }
-
 }  // namespace parsed_aggregation_projection
 }  // namespace mongo
