@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -33,19 +32,13 @@
 #include "mongo/base/status_with.h"
 
 namespace mongo {
-class Database;
 class OperationContext;
 
 /**
-* Return an error status if the wrong mongod version was used for these datafiles. The boolean
-* represents whether there are non-local databases.
-*/
-StatusWith<bool> repairDatabasesAndCheckVersion(OperationContext* opCtx);
-
-/**
- * If we are in a replset, every replicated collection must have an _id index.  As we scan each
- * database, we also gather a list of drop-pending collection namespaces for the
- * DropPendingCollectionReaper to clean up eventually.
+ * Return whether there are non-local databases. If there was an error becauses the wrong mongod
+ * version was used for these datafiles, a DBException with status ErrorCodes::MustDowngrade is
+ * thrown.
  */
-void checkForIdIndexesAndDropPendingCollections(OperationContext* opCtx, Database* db);
-}
+bool repairDatabasesAndCheckVersion(OperationContext* opCtx);
+
+}  // namespace mongo
