@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -38,7 +37,7 @@
 #include <iterator>
 
 #include "mongo/bson/bsonobjbuilder.h"
-#include "mongo/db/query/query_knobs.h"
+#include "mongo/db/ops/write_ops.h"
 #include "mongo/db/repl/oplog_entry.h"
 #include "mongo/db/repl/sync_tail.h"
 #include "mongo/util/assert_util.h"
@@ -50,7 +49,7 @@ namespace repl {
 namespace {
 
 // Must not create too large an object.
-const auto kInsertGroupMaxBatchSize = insertVectorMaxBytes;
+const auto kInsertGroupMaxBatchSize = write_ops::insertVectorMaxBytes;
 
 // Limit number of ops in a single group.
 constexpr auto kInsertGroupMaxBatchCount = 64;
@@ -63,7 +62,7 @@ void ApplierHelpers::stableSortByNamespace(MultiApplier::OperationPtrs* oplogEnt
         return;
     }
     auto nssComparator = [](const OplogEntry* l, const OplogEntry* r) {
-        return l->getNamespace() < r->getNamespace();
+        return l->getNss() < r->getNss();
     };
     std::stable_sort(oplogEntryPointers->begin(), oplogEntryPointers->end(), nssComparator);
 }
@@ -99,9 +98,9 @@ StatusWith<InsertGroup::ConstIterator> InsertGroup::groupAndApplyInserts(ConstIt
     std::vector<BSONObj> toInsert;
 
     // Make sure to include the first op in the batch size.
-    auto batchSize = entry.getObject().objsize();
+    size_t batchSize = entry.getObject().objsize();
     auto batchCount = OperationPtrs::size_type(1);
-    auto batchNamespace = entry.getNamespace();
+    auto batchNamespace = entry.getNss();
 
     /**
      * Search for the op that delimits this insert batch, and save its position
@@ -119,7 +118,7 @@ StatusWith<InsertGroup::ConstIterator> InsertGroup::groupAndApplyInserts(ConstIt
      */
     auto endOfGroupableOpsIterator =
         std::find_if(it + 1, _end, [&](const OplogEntry* nextEntry) -> bool {
-            auto opNamespace = nextEntry->getNamespace();
+            auto opNamespace = nextEntry->getNss();
             batchSize += nextEntry->getObject().objsize();
             batchCount += 1;
 
@@ -183,31 +182,34 @@ StatusWith<InsertGroup::ConstIterator> InsertGroup::groupAndApplyInserts(ConstIt
 
     // Generate an op object of all elements except for "ts", "t", and "o", since we
     // need to make those fields arrays of all the ts's, t's, and o's.
-    groupedInsertBuilder.appendElementsUnique(entry.raw);
+    groupedInsertBuilder.appendElementsUnique(entry.getRaw());
 
     auto groupedInsertObj = groupedInsertBuilder.done();
     try {
         // Apply the group of inserts.
-        uassertStatusOK(SyncTail::syncApply(_opCtx, groupedInsertObj, _mode));
+        uassertStatusOK(SyncTail::syncApply(_opCtx, groupedInsertObj, _mode, boost::none));
         // It succeeded, advance the oplogEntriesIterator to the end of the
         // group of inserts.
         return endOfGroupableOpsIterator - 1;
     } catch (...) {
         // The group insert failed, log an error and fall through to the
         // application of an individual op.
-        auto status = mongo::exceptionToStatus();
-        error() << "Error applying inserts in bulk " << causedBy(redact(status)) << ": "
-                << redact(groupedInsertObj)
-                << ". Trying first insert as a lone insert: " << redact(entry.raw);
+        auto status = exceptionToStatus().withContext(
+            str::stream() << "Error applying inserts in bulk: " << redact(groupedInsertObj)
+                          << ". Trying first insert as a lone insert: " << redact(entry.getRaw()));
+
+        // It's not an error during initial sync to encounter DuplicateKey errors.
+        if (Mode::kInitialSync == _mode && ErrorCodes::DuplicateKey == status) {
+            LOG(2) << status;
+        } else {
+            error() << status;
+        }
 
         // Avoid quadratic run time from failed insert by not retrying until we
         // are beyond this group of ops.
         _doNotGroupBeforePoint = endOfGroupableOpsIterator - 1;
 
-        return status.withContext(str::stream() << "Error applying inserts in bulk: "
-                                                << redact(groupedInsertObj)
-                                                << ". Trying first insert as a lone insert: "
-                                                << redact(entry.raw));
+        return status;
     }
 
     MONGO_UNREACHABLE;
