@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -34,10 +33,8 @@
 
 #include "mongo/db/repl/check_quorum_for_config_change.h"
 
-#include "mongo/base/disallow_copying.h"
 #include "mongo/base/status.h"
 #include "mongo/db/repl/repl_set_config.h"
-#include "mongo/db/repl/repl_set_heartbeat_args.h"
 #include "mongo/db/repl/repl_set_heartbeat_args_v1.h"
 #include "mongo/db/repl/repl_set_heartbeat_response.h"
 #include "mongo/db/repl/scatter_gather_algorithm.h"
@@ -45,7 +42,7 @@
 #include "mongo/db/server_options.h"
 #include "mongo/rpc/metadata/repl_set_metadata.h"
 #include "mongo/util/log.h"
-#include "mongo/util/mongoutils/str.h"
+#include "mongo/util/str.h"
 
 namespace mongo {
 namespace repl {
@@ -87,30 +84,18 @@ std::vector<RemoteCommandRequest> QuorumChecker::getRequests() const {
     }
 
     BSONObj hbRequest;
-    if (_term == OpTime::kUninitializedTerm) {
-        ReplSetHeartbeatArgs hbArgs;
-        hbArgs.setSetName(_rsConfig->getReplSetName());
-        hbArgs.setProtocolVersion(1);
-        hbArgs.setConfigVersion(_rsConfig->getConfigVersion());
-        hbArgs.setHeartbeatVersion(1);
-        hbArgs.setCheckEmpty(isInitialConfig);
-        hbArgs.setSenderHost(myConfig.getHostAndPort());
-        hbArgs.setSenderId(myConfig.getId());
-        hbRequest = hbArgs.toBSON();
-
-    } else {
-        ReplSetHeartbeatArgsV1 hbArgs;
-        hbArgs.setSetName(_rsConfig->getReplSetName());
-        hbArgs.setConfigVersion(_rsConfig->getConfigVersion());
-        hbArgs.setHeartbeatVersion(1);
-        if (isInitialConfig) {
-            hbArgs.setCheckEmpty();
-        }
-        hbArgs.setSenderHost(myConfig.getHostAndPort());
-        hbArgs.setSenderId(myConfig.getId());
-        hbArgs.setTerm(_term);
-        hbRequest = hbArgs.toBSON();
+    invariant(_term != OpTime::kUninitializedTerm);
+    ReplSetHeartbeatArgsV1 hbArgs;
+    hbArgs.setSetName(_rsConfig->getReplSetName());
+    hbArgs.setConfigVersion(_rsConfig->getConfigVersion());
+    hbArgs.setHeartbeatVersion(1);
+    if (isInitialConfig) {
+        hbArgs.setCheckEmpty();
     }
+    hbArgs.setSenderHost(myConfig.getHostAndPort());
+    hbArgs.setSenderId(myConfig.getId().getData());
+    hbArgs.setTerm(_term);
+    hbRequest = hbArgs.toBSON();
 
     // Send a bunch of heartbeat requests.
     // Schedule an operation when a "sufficient" number of them have completed, and use that
@@ -210,11 +195,11 @@ void QuorumChecker::_tabulateHeartbeatResponse(const RemoteCommandRequest& reque
 
     BSONObj resBSON = response.data;
     ReplSetHeartbeatResponse hbResp;
-    Status hbStatus = hbResp.initialize(resBSON, 0);
+    Status hbStatus = hbResp.initialize(resBSON, 0, /*requireWallTime*/ false);
 
     if (hbStatus.code() == ErrorCodes::InconsistentReplicaSetNames) {
-        std::string message = str::stream() << "Our set name did not match that of "
-                                            << request.target.toString();
+        std::string message = str::stream()
+            << "Our set name did not match that of " << request.target.toString();
         _vetoStatus = Status(ErrorCodes::NewReplicaSetConfigurationIncompatible, message);
         warning() << message;
         return;
@@ -241,7 +226,7 @@ void QuorumChecker::_tabulateHeartbeatResponse(const RemoteCommandRequest& reque
 
     if (_rsConfig->hasReplicaSetId()) {
         StatusWith<rpc::ReplSetMetadata> replMetadata =
-            rpc::ReplSetMetadata::readFromMetadata(response.metadata);
+            rpc::ReplSetMetadata::readFromMetadata(response.data, /*requireWallTime*/ false);
         if (replMetadata.isOK() && replMetadata.getValue().getReplicaSetId().isSet() &&
             _rsConfig->getReplicaSetId() != replMetadata.getValue().getReplicaSetId()) {
             std::string message = str::stream()
@@ -253,15 +238,6 @@ void QuorumChecker::_tabulateHeartbeatResponse(const RemoteCommandRequest& reque
         }
     }
 
-    const bool isInitialConfig = _rsConfig->getConfigVersion() == 1;
-    if (isInitialConfig && hbResp.hasData()) {
-        std::string message = str::stream() << "'" << request.target.toString()
-                                            << "' has data already, cannot initiate set.";
-        _vetoStatus = Status(ErrorCodes::CannotInitializeNodeWithData, message);
-        warning() << message;
-        return;
-    }
-
     for (int i = 0; i < _rsConfig->getNumMembers(); ++i) {
         const MemberConfig& memberConfig = _rsConfig->getMemberAt(i);
         if (memberConfig.getHostAndPort() != request.target) {
@@ -304,9 +280,10 @@ bool QuorumChecker::hasReceivedSufficientResponses() const {
 Status checkQuorumGeneral(executor::TaskExecutor* executor,
                           const ReplSetConfig& rsConfig,
                           const int myIndex,
-                          long long term) {
+                          long long term,
+                          std::string logMessage) {
     auto checker = std::make_shared<QuorumChecker>(&rsConfig, myIndex, term);
-    ScatterGatherRunner runner(checker, executor);
+    ScatterGatherRunner runner(checker, executor, std::move(logMessage));
     Status status = runner.run();
     if (!status.isOK()) {
         return status;
@@ -320,7 +297,7 @@ Status checkQuorumForInitiate(executor::TaskExecutor* executor,
                               const int myIndex,
                               long long term) {
     invariant(rsConfig.getConfigVersion() == 1);
-    return checkQuorumGeneral(executor, rsConfig, myIndex, term);
+    return checkQuorumGeneral(executor, rsConfig, myIndex, term, "initiate quorum check");
 }
 
 Status checkQuorumForReconfig(executor::TaskExecutor* executor,
@@ -328,7 +305,7 @@ Status checkQuorumForReconfig(executor::TaskExecutor* executor,
                               const int myIndex,
                               long long term) {
     invariant(rsConfig.getConfigVersion() > 1);
-    return checkQuorumGeneral(executor, rsConfig, myIndex, term);
+    return checkQuorumGeneral(executor, rsConfig, myIndex, term, "reconfig quorum check");
 }
 
 }  // namespace repl
