@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -35,6 +34,7 @@
 #include "mongo/db/db_raii.h"
 #include "mongo/db/dbdirectclient.h"
 #include "mongo/db/operation_context.h"
+#include "mongo/db/repl/drop_pending_collection_reaper.h"
 #include "mongo/db/repl/mock_repl_coord_server_fixture.h"
 #include "mongo/db/repl/oplog.h"
 #include "mongo/db/repl/oplog_entry.h"
@@ -86,14 +86,10 @@ void MockReplCoordServerFixture::setUp() {
 
     repl::setOplogCollectionName(service);
     repl::acquireOplogCollectionForLogging(opCtx());
-}
 
-void MockReplCoordServerFixture::tearDown() {
-    // ServiceContextMongoDTest::tearDown() will try to create it's own opCtx, and it's not
-    // allowed to have 2 present per client, so destroy this one.
-    _opCtx.reset();
-
-    ServiceContextMongoDTest::tearDown();
+    repl::DropPendingCollectionReaper::set(
+        service,
+        stdx::make_unique<repl::DropPendingCollectionReaper>(repl::StorageInterface::get(service)));
 }
 
 void MockReplCoordServerFixture::insertOplogEntry(const repl::OplogEntry& entry) {
@@ -104,7 +100,6 @@ void MockReplCoordServerFixture::insertOplogEntry(const repl::OplogEntry& entry)
     auto status = coll->insertDocument(opCtx(),
                                        InsertStatement(entry.toBSON()),
                                        &CurOp::get(opCtx())->debug(),
-                                       /* enforceQuota */ false,
                                        /* fromMigrate */ false);
     ASSERT_OK(status);
 }
