@@ -62,14 +62,18 @@ void OplogBufferBlockingQueue::shutdown(OperationContext* opCtx) {
 }
 
 void OplogBufferBlockingQueue::pushEvenIfFull(OperationContext*, const Value& value) {
+    invariant(!_drainMode);
     _queue.pushEvenIfFull(value);
+    _notEmptyCv.notify_one();
     if (_counters) {
         _counters->increment(value);
     }
 }
 
 void OplogBufferBlockingQueue::push(OperationContext*, const Value& value) {
+    invariant(!_drainMode);
     _queue.push(value);
+    _notEmptyCv.notify_one();
     if (_counters) {
         _counters->increment(value);
     }
@@ -78,7 +82,9 @@ void OplogBufferBlockingQueue::push(OperationContext*, const Value& value) {
 void OplogBufferBlockingQueue::pushAllNonBlocking(OperationContext*,
                                                   Batch::const_iterator begin,
                                                   Batch::const_iterator end) {
+    invariant(!_drainMode);
     _queue.pushAllNonBlocking(begin, end);
+    _notEmptyCv.notify_one();
     if (_counters) {
         for (auto i = begin; i != end; ++i) {
             _counters->increment(*i);
@@ -125,7 +131,10 @@ bool OplogBufferBlockingQueue::tryPop(OperationContext*, Value* value) {
 
 bool OplogBufferBlockingQueue::waitForData(Seconds waitDuration) {
     Value ignored;
-    return _queue.blockingPeek(ignored, static_cast<int>(durationCount<Seconds>(waitDuration)));
+    stdx::unique_lock<Latch> lk(_notEmptyMutex);
+    _notEmptyCv.wait_for(
+        lk, waitDuration.toSystemDuration(), [&] { return _drainMode || _queue.peek(ignored); });
+    return _queue.peek(ignored);
 }
 
 bool OplogBufferBlockingQueue::peek(OperationContext*, Value* value) {
@@ -137,5 +146,16 @@ boost::optional<OplogBuffer::Value> OplogBufferBlockingQueue::lastObjectPushed(
     return _queue.lastObjectPushed();
 }
 
+void OplogBufferBlockingQueue::enterDrainMode() {
+    stdx::lock_guard<Latch> lk(_notEmptyMutex);
+    _drainMode = true;
+    _notEmptyCv.notify_one();
+}
+
+void OplogBufferBlockingQueue::exitDrainMode() {
+    stdx::lock_guard<Latch> lk(_notEmptyMutex);
+    _drainMode = false;
+}
+
 }  // namespace repl
 }  // namespace mongo
