@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -32,7 +31,6 @@
 
 #include "mongo/db/repl/task_runner_test_fixture.h"
 
-#include "mongo/db/auth/authorization_manager.h"
 #include "mongo/db/repl/task_runner.h"
 #include "mongo/stdx/functional.h"
 #include "mongo/stdx/memory.h"
@@ -64,6 +62,7 @@ void TaskRunnerTest::destroyTaskRunner() {
 void TaskRunnerTest::setUp() {
     ThreadPool::Options options;
     options.poolName = "TaskRunnerTest";
+    options.onCreateThread = [](const std::string& name) { Client::initThread(name); };
     _threadPool = stdx::make_unique<ThreadPool>(options);
     _threadPool->startup();
 
