@@ -83,26 +83,17 @@ Status _applyOperationsForTransaction(OperationContext* opCtx,
  * Helper that will read the entire sequence of oplog entries for the transaction and apply each of
  * them.
  *
- * Currently used for oplog application of a commitTransaction oplog entry during recovery, rollback
- * and initial sync.
+ * Currently used for oplog application of a commitTransaction oplog entry during recovery and
+ * rollback.
  */
 Status _applyTransactionFromOplogChain(OperationContext* opCtx,
                                        const OplogEntry& entry,
                                        repl::OplogApplication::Mode mode,
                                        Timestamp commitTimestamp,
                                        Timestamp durableTimestamp) {
-    invariant(mode == repl::OplogApplication::Mode::kRecovering ||
-              mode == repl::OplogApplication::Mode::kInitialSync);
+    invariant(mode == repl::OplogApplication::Mode::kRecovering);
 
-    repl::MultiApplier::Operations ops;
-    {
-        // Traverse the oplog chain with its own snapshot and read timestamp.
-        ReadSourceScope readSourceScope(opCtx);
-
-        // Get the corresponding prepare applyOps oplog entry.
-        const auto prepareOplogEntry = getPreviousOplogEntry(opCtx, entry);
-        ops = readTransactionOperationsFromOplogChain(opCtx, prepareOplogEntry, {}, boost::none);
-    }
+    auto ops = readTransactionOperationsFromOplogChain(opCtx, entry, {});
 
     const auto dbName = entry.getNss().db().toString();
     Status status = Status::OK();
@@ -151,107 +142,129 @@ const repl::OplogEntry getPreviousOplogEntry(OperationContext* opCtx,
 Status applyCommitTransaction(OperationContext* opCtx,
                               const OplogEntry& entry,
                               repl::OplogApplication::Mode mode) {
-    // Return error if run via applyOps command.
-    uassert(50987,
-            "commitTransaction is only used internally by secondaries.",
-            mode != repl::OplogApplication::Mode::kApplyOpsCmd);
-
     IDLParserErrorContext ctx("commitTransaction");
     auto commitOplogEntryOpTime = entry.getOpTime();
     auto commitCommand = CommitTransactionOplogObject::parse(ctx, entry.getObject());
     invariant(commitCommand.getCommitTimestamp());
 
-    if (mode == repl::OplogApplication::Mode::kRecovering) {
-        return _applyTransactionFromOplogChain(opCtx,
-                                               entry,
-                                               mode,
-                                               *commitCommand.getCommitTimestamp(),
-                                               commitOplogEntryOpTime.getTimestamp());
+    switch (mode) {
+        case repl::OplogApplication::Mode::kRecovering: {
+            return _applyTransactionFromOplogChain(opCtx,
+                                                   entry,
+                                                   mode,
+                                                   *commitCommand.getCommitTimestamp(),
+                                                   commitOplogEntryOpTime.getTimestamp());
+        }
+        case repl::OplogApplication::Mode::kInitialSync: {
+            // Initial sync should never apply 'commitTransaction' since it unpacks committed
+            // transactions onto various applier threads.
+            MONGO_UNREACHABLE;
+        }
+        case repl::OplogApplication::Mode::kApplyOpsCmd: {
+            // Return error if run via applyOps command.
+            uasserted(50987, "commitTransaction is only used internally by secondaries.");
+        }
+        case repl::OplogApplication::Mode::kSecondary: {
+            // Transaction operations are in its own batch, so we can modify their opCtx.
+            invariant(entry.getSessionId());
+            invariant(entry.getTxnNumber());
+            opCtx->setLogicalSessionId(*entry.getSessionId());
+            opCtx->setTxnNumber(*entry.getTxnNumber());
+            opCtx->setInMultiDocumentTransaction();
+
+            // The write on transaction table may be applied concurrently, so refreshing state
+            // from disk may read that write, causing starting a new transaction on an existing
+            // txnNumber. Thus, we start a new transaction without refreshing state from disk.
+            MongoDOperationContextSessionWithoutRefresh sessionCheckout(opCtx);
+
+            auto transaction = TransactionParticipant::get(opCtx);
+            invariant(transaction);
+            transaction.unstashTransactionResources(opCtx, "commitTransaction");
+            transaction.commitPreparedTransaction(
+                opCtx, *commitCommand.getCommitTimestamp(), commitOplogEntryOpTime);
+            return Status::OK();
+        }
     }
-
-    invariant(mode == repl::OplogApplication::Mode::kSecondary);
-
-    // Transaction operations are in its own batch, so we can modify their opCtx.
-    invariant(entry.getSessionId());
-    invariant(entry.getTxnNumber());
-    opCtx->setLogicalSessionId(*entry.getSessionId());
-    opCtx->setTxnNumber(*entry.getTxnNumber());
-    opCtx->setInMultiDocumentTransaction();
-
-    // The write on transaction table may be applied concurrently, so refreshing state
-    // from disk may read that write, causing starting a new transaction on an existing
-    // txnNumber. Thus, we start a new transaction without refreshing state from disk.
-    MongoDOperationContextSessionWithoutRefresh sessionCheckout(opCtx);
-
-    auto transaction = TransactionParticipant::get(opCtx);
-    invariant(transaction);
-    transaction.unstashTransactionResources(opCtx, "commitTransaction");
-    transaction.commitPreparedTransaction(
-        opCtx, *commitCommand.getCommitTimestamp(), commitOplogEntryOpTime);
-    return Status::OK();
+    MONGO_UNREACHABLE;
 }
 
 Status applyAbortTransaction(OperationContext* opCtx,
                              const OplogEntry& entry,
                              repl::OplogApplication::Mode mode) {
-    // Return error if run via applyOps command.
-    uassert(50972,
-            "abortTransaction is only used internally by secondaries.",
-            mode != repl::OplogApplication::Mode::kApplyOpsCmd);
+    switch (mode) {
+        case repl::OplogApplication::Mode::kRecovering: {
+            // We don't put transactions into the prepare state until the end of recovery,
+            // so there is no transaction to abort.
+            return Status::OK();
+        }
+        case repl::OplogApplication::Mode::kInitialSync: {
+            // We don't put transactions into the prepare state until the end of initial sync,
+            // so there is no transaction to abort.
+            return Status::OK();
+        }
+        case repl::OplogApplication::Mode::kApplyOpsCmd: {
+            // Return error if run via applyOps command.
+            uasserted(50972, "abortTransaction is only used internally by secondaries.");
+        }
+        case repl::OplogApplication::Mode::kSecondary: {
+            // Transaction operations are in its own batch, so we can modify their opCtx.
+            invariant(entry.getSessionId());
+            invariant(entry.getTxnNumber());
+            opCtx->setLogicalSessionId(*entry.getSessionId());
+            opCtx->setTxnNumber(*entry.getTxnNumber());
+            opCtx->setInMultiDocumentTransaction();
 
-    // We don't put transactions into the prepare state until the end of recovery and initial sync,
-    // so there is no transaction to abort.
-    if (mode == repl::OplogApplication::Mode::kRecovering ||
-        mode == repl::OplogApplication::Mode::kInitialSync) {
-        return Status::OK();
+            // The write on transaction table may be applied concurrently, so refreshing state
+            // from disk may read that write, causing starting a new transaction on an existing
+            // txnNumber. Thus, we start a new transaction without refreshing state from disk.
+            MongoDOperationContextSessionWithoutRefresh sessionCheckout(opCtx);
+
+            auto transaction = TransactionParticipant::get(opCtx);
+            transaction.unstashTransactionResources(opCtx, "abortTransaction");
+            transaction.abortTransaction(opCtx);
+            return Status::OK();
+        }
     }
-
-    invariant(mode == repl::OplogApplication::Mode::kSecondary);
-
-    // Transaction operations are in its own batch, so we can modify their opCtx.
-    invariant(entry.getSessionId());
-    invariant(entry.getTxnNumber());
-    opCtx->setLogicalSessionId(*entry.getSessionId());
-    opCtx->setTxnNumber(*entry.getTxnNumber());
-    opCtx->setInMultiDocumentTransaction();
-
-    // The write on transaction table may be applied concurrently, so refreshing state
-    // from disk may read that write, causing starting a new transaction on an existing
-    // txnNumber. Thus, we start a new transaction without refreshing state from disk.
-    MongoDOperationContextSessionWithoutRefresh sessionCheckout(opCtx);
-
-    auto transaction = TransactionParticipant::get(opCtx);
-    transaction.unstashTransactionResources(opCtx, "abortTransaction");
-    transaction.abortTransaction(opCtx);
-    return Status::OK();
+    MONGO_UNREACHABLE;
 }
 
 repl::MultiApplier::Operations readTransactionOperationsFromOplogChain(
     OperationContext* opCtx,
-    const OplogEntry& commitOrPrepare,
-    const std::vector<OplogEntry*>& cachedOps,
-    boost::optional<Timestamp> commitOplogEntryTS) {
-    repl::MultiApplier::Operations ops;
+    const OplogEntry& lastEntryInTxn,
+    const std::vector<OplogEntry*>& cachedOps) noexcept {
+    // Traverse the oplog chain with its own snapshot and read timestamp.
+    ReadSourceScope readSourceScope(opCtx);
 
-    // Get the previous oplog entry.
-    auto currentOpTime = commitOrPrepare.getOpTime();
+    repl::MultiApplier::Operations ops;
 
     // The cachedOps are the ops for this transaction that are from the same oplog application batch
     // as the commit or prepare, those which have not necessarily been written to the oplog.  These
     // ops are in order of increasing timestamp.
+    const auto oldestEntryInBatch = cachedOps.empty() ? lastEntryInTxn : *cachedOps.front();
 
-    // The lastEntryOpTime is the OpTime of the last (latest OpTime) entry for this transaction
+    // The lastEntryWrittenToOplogOpTime is the OpTime of the latest entry for this transaction
     // which is expected to be present in the oplog.  It is the entry before the first cachedOp,
     // unless there are no cachedOps in which case it is the entry before the commit or prepare.
-    const auto lastEntryOpTime = (cachedOps.empty() ? commitOrPrepare : *cachedOps.front())
-                                     .getPrevWriteOpTimeInTransaction();
-    invariant(lastEntryOpTime < currentOpTime);
+    const auto lastEntryWrittenToOplogOpTime = oldestEntryInBatch.getPrevWriteOpTimeInTransaction();
+    invariant(lastEntryWrittenToOplogOpTime < lastEntryInTxn.getOpTime());
 
-    TransactionHistoryIterator iter(lastEntryOpTime.get());
-    // Empty commits are not allowed, but empty prepares are.
-    invariant(commitOrPrepare.getCommandType() != OplogEntry::CommandType::kCommitTransaction ||
-              !cachedOps.empty() || iter.hasNext());
-    auto commitOrPrepareObj = commitOrPrepare.toBSON();
+    TransactionHistoryIterator iter(lastEntryWrittenToOplogOpTime.get());
+
+    // If we started with a prepared commit, we want to forget about that operation and move onto
+    // the prepare.
+    auto prepareOrUnpreparedCommit = lastEntryInTxn;
+    if (lastEntryInTxn.isPreparedCommit()) {
+        // A prepared-commit must be in its own batch and thus have no cached ops.
+        invariant(cachedOps.empty());
+        invariant(iter.hasNext());
+        prepareOrUnpreparedCommit = iter.nextFatalOnErrors(opCtx);
+    }
+    invariant(prepareOrUnpreparedCommit.getCommandType() == OplogEntry::CommandType::kApplyOps);
+
+    // The non-DurableReplOperation fields of the extracted transaction operations will match those
+    // of the lastEntryInTxn. For a prepared commit, this will include the commit oplog entry's
+    // 'ts' field, which is what we want.
+    auto lastEntryInTxnObj = lastEntryInTxn.toBSON();
 
     // First retrieve and transform the ops from the oplog, which will be retrieved in reverse
     // order.
@@ -259,8 +272,8 @@ repl::MultiApplier::Operations readTransactionOperationsFromOplogChain(
         const auto& operationEntry = iter.nextFatalOnErrors(opCtx);
         invariant(operationEntry.isPartialTransaction());
         auto prevOpsEnd = ops.size();
-        repl::ApplyOps::extractOperationsTo(
-            operationEntry, commitOrPrepareObj, &ops, commitOplogEntryTS);
+        repl::ApplyOps::extractOperationsTo(operationEntry, lastEntryInTxnObj, &ops);
+
         // Because BSONArrays do not have fast way of determining size without iterating through
         // them, and we also have no way of knowing how many oplog entries are in a transaction
         // without iterating, reversing each applyOps and then reversing the whole array is
@@ -275,15 +288,11 @@ repl::MultiApplier::Operations readTransactionOperationsFromOplogChain(
     for (auto* cachedOp : cachedOps) {
         const auto& operationEntry = *cachedOp;
         invariant(operationEntry.isPartialTransaction());
-        repl::ApplyOps::extractOperationsTo(
-            operationEntry, commitOrPrepareObj, &ops, commitOplogEntryTS);
+        repl::ApplyOps::extractOperationsTo(operationEntry, lastEntryInTxnObj, &ops);
     }
 
-    // Reconstruct the operations from the commit or prepare oplog entry.
-    if (commitOrPrepare.getCommandType() == OplogEntry::CommandType::kApplyOps) {
-        repl::ApplyOps::extractOperationsTo(
-            commitOrPrepare, commitOrPrepareObj, &ops, commitOplogEntryTS);
-    }
+    // Reconstruct the operations from the prepare or unprepared commit oplog entry.
+    repl::ApplyOps::extractOperationsTo(prepareOrUnpreparedCommit, lastEntryInTxnObj, &ops);
     return ops;
 }
 
@@ -294,18 +303,15 @@ namespace {
  */
 Status _applyPrepareTransaction(OperationContext* opCtx,
                                 const OplogEntry& entry,
-                                repl::OplogApplication::Mode oplogApplicationMode) {
+                                repl::OplogApplication::Mode mode) {
 
     // The operations here are reconstructed at their prepare time.  However, that time will
     // be ignored because there is an outer write unit of work during their application.
     // The prepare time of the transaction is set explicitly below.
-    auto ops = [&] {
-        ReadSourceScope readSourceScope(opCtx);
-        return readTransactionOperationsFromOplogChain(opCtx, entry, {}, boost::none);
-    }();
+    auto ops = readTransactionOperationsFromOplogChain(opCtx, entry, {});
 
-    if (oplogApplicationMode == repl::OplogApplication::Mode::kRecovering ||
-        oplogApplicationMode == repl::OplogApplication::Mode::kInitialSync) {
+    if (mode == repl::OplogApplication::Mode::kRecovering ||
+        mode == repl::OplogApplication::Mode::kInitialSync) {
         // We might replay a prepared transaction behind oldest timestamp.  Note that since this is
         // scoped to the storage transaction, and readTransactionOperationsFromOplogChain implicitly
         // abandons the storage transaction when it releases the global lock, this must be done
@@ -346,11 +352,11 @@ Status _applyPrepareTransaction(OperationContext* opCtx,
 
     // Set this in case the application of any ops need to use the prepare timestamp of this
     // transaction. It should be cleared automatically when the transaction finishes.
-    if (oplogApplicationMode == repl::OplogApplication::Mode::kRecovering) {
+    if (mode == repl::OplogApplication::Mode::kRecovering) {
         transaction.setPrepareOpTimeForRecovery(opCtx, entry.getOpTime());
     }
 
-    auto status = _applyOperationsForTransaction(opCtx, ops, oplogApplicationMode);
+    auto status = _applyOperationsForTransaction(opCtx, ops, mode);
     fassert(31137, status);
 
     if (MONGO_FAIL_POINT(applyOpsHangBeforePreparingTransaction)) {
@@ -366,54 +372,70 @@ Status _applyPrepareTransaction(OperationContext* opCtx,
 }
 
 /**
- * Apply a prepared transaction during recovery.
+ * Apply a prepared transaction when we are reconstructing prepared transactions.
  */
-Status applyRecoveredPrepareTransaction(OperationContext* opCtx,
-                                        const OplogEntry& entry,
-                                        repl::OplogApplication::Mode mode) {
-    // Snapshot transactions never conflict with the PBWM lock.
-    invariant(!opCtx->lockState()->shouldConflictWithSecondaryBatchApplication());
+void _reconstructPreparedTransaction(OperationContext* opCtx,
+                                     const OplogEntry& prepareEntry,
+                                     repl::OplogApplication::Mode mode) {
+    repl::UnreplicatedWritesBlock uwb(opCtx);
+
+    // Snapshot transaction can never conflict with the PBWM lock.
+    opCtx->lockState()->setShouldConflictWithSecondaryBatchApplication(false);
+
+    // When querying indexes, we return the record matching the key if it exists, or an
+    // adjacent document. This means that it is possible for us to hit a prepare conflict if
+    // we query for an incomplete key and an adjacent key is prepared.
+    // We ignore prepare conflicts on recovering nodes because they may encounter prepare
+    // conflicts that did not occur on the primary.
+    opCtx->recoveryUnit()->setPrepareConflictBehavior(
+        PrepareConflictBehavior::kIgnoreConflictsAllowWrites);
+
     // We might replay a prepared transaction behind oldest timestamp.
     opCtx->recoveryUnit()->setRoundUpPreparedTimestamps(true);
-    return _applyPrepareTransaction(opCtx, entry, mode);
+
+    // Checks out the session, applies the operations and prepares the transaction.
+    uassertStatusOK(_applyPrepareTransaction(opCtx, prepareEntry, mode));
 }
 }  // namespace
 
 /**
- * Make sure that if we are in replication recovery or initial sync, we don't apply the prepare
- * transaction oplog entry until we either see a commit transaction oplog entry or are at the very
- * end of recovery/initial sync. Otherwise, only apply the prepare transaction oplog entry if we are
- * a secondary.
+ * Make sure that if we are in replication recovery, we don't apply the prepare transaction oplog
+ * entry until we either see a commit transaction oplog entry or are at the very end of recovery.
+ * Otherwise, only apply the prepare transaction oplog entry if we are a secondary. We shouldn't get
+ * here for initial sync and applyOps should error.
  */
 Status applyPrepareTransaction(OperationContext* opCtx,
                                const OplogEntry& entry,
-                               repl::OplogApplication::Mode oplogApplicationMode) {
-    // Don't apply the operations from the prepared transaction until either we see a commit
-    // transaction oplog entry during recovery or are at the end of recovery.
-    if (oplogApplicationMode == repl::OplogApplication::Mode::kRecovering) {
-        if (!serverGlobalParams.enableMajorityReadConcern) {
-            error() << "Cannot replay a prepared transaction when 'enableMajorityReadConcern' is "
+                               repl::OplogApplication::Mode mode) {
+    switch (mode) {
+        case repl::OplogApplication::Mode::kRecovering: {
+            if (!serverGlobalParams.enableMajorityReadConcern) {
+                error()
+                    << "Cannot replay a prepared transaction when 'enableMajorityReadConcern' is "
                        "set to false. Restart the server with --enableMajorityReadConcern=true "
                        "to complete recovery.";
+                fassertFailed(51146);
+            }
+
+            // Don't apply the operations from the prepared transaction until either we see a commit
+            // transaction oplog entry during recovery or are at the end of recovery.
+            return Status::OK();
+        }
+        case repl::OplogApplication::Mode::kInitialSync: {
+            // Initial sync should never apply 'prepareTransaction' since it unpacks committed
+            // transactions onto various applier threads at commit time.
+            MONGO_UNREACHABLE;
+        }
+        case repl::OplogApplication::Mode::kApplyOpsCmd: {
+            // Return error if run via applyOps command.
+            uasserted(51145,
+                      "prepare applyOps oplog entry is only used internally by secondaries.");
+        }
+        case repl::OplogApplication::Mode::kSecondary: {
+            return _applyPrepareTransaction(opCtx, entry, repl::OplogApplication::Mode::kSecondary);
         }
-        fassert(51146, serverGlobalParams.enableMajorityReadConcern);
-        return Status::OK();
     }
-
-    // Don't apply the operations from the prepared transaction until either we see a commit
-    // transaction oplog entry during the oplog application phase of initial sync or are at the end
-    // of initial sync.
-    if (oplogApplicationMode == repl::OplogApplication::Mode::kInitialSync) {
-        return Status::OK();
-    }
-
-    // Return error if run via applyOps command.
-    uassert(51145,
-            "prepare applyOps oplog entry is only used internally by secondaries.",
-            oplogApplicationMode != repl::OplogApplication::Mode::kApplyOpsCmd);
-
-    invariant(oplogApplicationMode == repl::OplogApplication::Mode::kSecondary);
-    return _applyPrepareTransaction(opCtx, entry, oplogApplicationMode);
+    MONGO_UNREACHABLE;
 }
 
 void reconstructPreparedTransactions(OperationContext* opCtx, repl::OplogApplication::Mode mode) {
@@ -454,22 +476,7 @@ void reconstructPreparedTransactions(OperationContext* opCtx, repl::OplogApplica
                 opCtx->getServiceContext()->makeClient("reconstruct-prepared-transactions");
             AlternativeClientRegion acr(newClient);
             const auto newOpCtx = cc().makeOperationContext();
-            repl::UnreplicatedWritesBlock uwb(newOpCtx.get());
-
-            // Snapshot transaction can never conflict with the PBWM lock.
-            newOpCtx->lockState()->setShouldConflictWithSecondaryBatchApplication(false);
-
-            // When querying indexes, we return the record matching the key if it exists, or an
-            // adjacent document. This means that it is possible for us to hit a prepare conflict if
-            // we query for an incomplete key and an adjacent key is prepared.
-            // We ignore prepare conflicts on recovering nodes because they may encounter prepare
-            // conflicts that did not occur on the primary.
-            newOpCtx->recoveryUnit()->setPrepareConflictBehavior(
-                PrepareConflictBehavior::kIgnoreConflictsAllowWrites);
-
-            // Checks out the session, applies the operations and prepares the transaction.
-            uassertStatusOK(
-                applyRecoveredPrepareTransaction(newOpCtx.get(), prepareOplogEntry, mode));
+            _reconstructPreparedTransaction(newOpCtx.get(), prepareOplogEntry, mode);
         }
     }
 }
