@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -36,7 +35,6 @@
 #include <string>
 
 #include "mongo/db/auth/action_type.h"
-#include "mongo/db/auth/authorization_manager.h"
 #include "mongo/db/auth/authorization_session.h"
 #include "mongo/db/auth/privilege.h"
 #include "mongo/db/catalog_raii.h"
@@ -81,20 +79,19 @@ CleanupResult cleanupOrphanedData(OperationContext* opCtx,
     {
         AutoGetCollection autoColl(opCtx, ns, MODE_IX);
         auto* const css = CollectionShardingRuntime::get(opCtx, ns);
-
-        auto metadata = css->getMetadata(opCtx);
+        const auto metadata = css->getCurrentMetadata();
         if (!metadata->isSharded()) {
-            log() << "skipping orphaned data cleanup for " << ns.toString()
-                  << ", collection is not sharded";
+            LOG(0) << "skipping orphaned data cleanup for " << ns.ns()
+                   << ", collection is not sharded";
             return CleanupResult_Done;
         }
 
         BSONObj keyPattern = metadata->getKeyPattern();
         if (!startingFromKey.isEmpty()) {
             if (!metadata->isValidKey(startingFromKey)) {
-                *errMsg = str::stream() << "could not cleanup orphaned data, start key "
-                                        << startingFromKey << " does not match shard key pattern "
-                                        << keyPattern;
+                *errMsg = str::stream()
+                    << "could not cleanup orphaned data, start key " << startingFromKey
+                    << " does not match shard key pattern " << keyPattern;
 
                 log() << *errMsg;
                 return CleanupResult_Error;
