@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -34,7 +33,6 @@
 
 #include "mongo/db/auth/action_set.h"
 #include "mongo/db/auth/action_type.h"
-#include "mongo/db/auth/authorization_manager.h"
 #include "mongo/db/auth/authorization_session.h"
 #include "mongo/db/auth/privilege.h"
 #include "mongo/db/catalog_raii.h"
@@ -121,8 +119,7 @@ public:
                     uasserted(ErrorCodes::NamespaceNotFound,
                               str::stream()
                                   << "Can't issue _flushDatabaseCacheUpdates on the database "
-                                  << _dbName()
-                                  << " because it does not exist on this shard.");
+                                  << _dbName() << " because it does not exist on this shard.");
                 }
 
                 // If the primary is in the critical section, secondaries must wait for the commit
@@ -130,10 +127,11 @@ public:
                 // inclusive of the commit (and new writes to the committed chunk) that hasn't yet
                 // propagated back to this shard. This ensures the read your own writes causal
                 // consistency guarantee.
-                auto criticalSectionSignal =
-                    DatabaseShardingState::get(autoDb.getDb())
-                        .getCriticalSectionSignal(ShardingMigrationCriticalSection::kRead);
-                if (criticalSectionSignal) {
+                auto& dss = DatabaseShardingState::get(autoDb.getDb());
+                auto dssLock = DatabaseShardingState::DSSLock::lockShared(opCtx, &dss);
+
+                if (auto criticalSectionSignal = dss.getCriticalSectionSignal(
+                        ShardingMigrationCriticalSection::kRead, dssLock)) {
                     oss.setMigrationCriticalSectionSignal(criticalSectionSignal);
                 }
             }
