@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -32,7 +31,6 @@
 
 #include <boost/optional.hpp>
 
-#include "mongo/base/disallow_copying.h"
 #include "mongo/db/namespace_string.h"
 #include "mongo/s/chunk_version.h"
 #include "mongo/s/database_version_gen.h"
@@ -52,7 +50,8 @@ class OperationContext;
  * Note: This only supports storing the version for a single namespace.
  */
 class OperationShardingState {
-    MONGO_DISALLOW_COPYING(OperationShardingState);
+    OperationShardingState(const OperationShardingState&) = delete;
+    OperationShardingState& operator=(const OperationShardingState&) = delete;
 
 public:
     OperationShardingState();
@@ -63,6 +62,13 @@ public:
      */
     static OperationShardingState& get(OperationContext* opCtx);
 
+    /**
+     * Returns true if the the current operation was sent by the caller with shard version
+     * information attached, meaning that it must perform shard version checking and orphan
+     * filtering.
+     */
+    static bool isOperationVersioned(OperationContext* opCtx);
+
     /**
      * Requests on a sharded collection that are broadcast without a shardVersion should not cause
      * the collection to be created on a shard that does not know about the collection already,
