@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -31,11 +30,10 @@
 
 #include "mongo/platform/basic.h"
 
-#include "mongo/db/storage/wiredtiger/wiredtiger_parameters.h"
-
+#include "mongo/db/storage/wiredtiger/wiredtiger_parameters_gen.h"
 #include "mongo/logger/parse_log_component_settings.h"
 #include "mongo/util/log.h"
-#include "mongo/util/mongoutils/str.h"
+#include "mongo/util/str.h"
 
 namespace mongo {
 
@@ -56,11 +54,10 @@ Status applyMaxCacheOverflowSizeGBParameter(WiredTigerMaxCacheOverflowSizeGBPara
 
     invariant(param._data.second);
     int ret = param._data.second->reconfigure(
-        std::string(str::stream() << "cache_overflow=(file_max=" << valueMB << "M)").c_str());
+        fmt::format("cache_overflow=(file_max={}M)", valueMB).c_str());
     if (ret != 0) {
-        string result =
-            (str::stream() << "WiredTiger reconfiguration failed with error code (" << ret << "): "
-                           << wiredtiger_strerror(ret));
+        string result = (str::stream() << "WiredTiger reconfiguration failed with error code ("
+                                       << ret << "): " << wiredtiger_strerror(ret));
         error() << result;
 
         return Status(ErrorCodes::BadValue, result);
@@ -72,31 +69,10 @@ Status applyMaxCacheOverflowSizeGBParameter(WiredTigerMaxCacheOverflowSizeGBPara
 
 }  // namespace
 
-WiredTigerEngineRuntimeConfigParameter::WiredTigerEngineRuntimeConfigParameter(
-    WiredTigerKVEngine* engine)
-    : ServerParameter(
-          ServerParameterSet::getGlobal(), "wiredTigerEngineRuntimeConfig", false, true),
-      _engine(engine) {}
-
-
 void WiredTigerEngineRuntimeConfigParameter::append(OperationContext* opCtx,
                                                     BSONObjBuilder& b,
                                                     const std::string& name) {
-    b << name << _currentValue;
-}
-
-Status WiredTigerEngineRuntimeConfigParameter::set(const BSONElement& newValueElement) {
-    try {
-        return setFromString(newValueElement.String());
-    } catch (const AssertionException& msg) {
-        return Status(
-            ErrorCodes::BadValue,
-            mongoutils::str::stream()
-                << "Invalid value for wiredTigerEngineRuntimeConfig via setParameter command: "
-                << newValueElement
-                << ", exception: "
-                << msg.what());
-    }
+    b << name << _data.first;
 }
 
 Status WiredTigerEngineRuntimeConfigParameter::setFromString(const std::string& str) {
@@ -111,28 +87,20 @@ Status WiredTigerEngineRuntimeConfigParameter::setFromString(const std::string&
 
     log() << "Reconfiguring WiredTiger storage engine with config string: \"" << str << "\"";
 
-    int ret = _engine->reconfigure(str.c_str());
+    invariant(_data.second);
+    int ret = _data.second->reconfigure(str.c_str());
     if (ret != 0) {
-        string result =
-            (mongoutils::str::stream() << "WiredTiger reconfiguration failed with error code ("
-                                       << ret
-                                       << "): "
-                                       << wiredtiger_strerror(ret));
+        string result = (str::stream() << "WiredTiger reconfiguration failed with error code ("
+                                       << ret << "): " << wiredtiger_strerror(ret));
         error() << result;
 
         return Status(ErrorCodes::BadValue, result);
     }
 
-    _currentValue = str;
+    _data.first = str;
     return Status::OK();
 }
 
-WiredTigerMaxCacheOverflowSizeGBParameter::WiredTigerMaxCacheOverflowSizeGBParameter(
-    WiredTigerKVEngine* engine, double value)
-    : ServerParameter(
-          ServerParameterSet::getGlobal(), "wiredTigerMaxCacheOverflowSizeGB", false, true),
-      _data(value, engine) {}
-
 void WiredTigerMaxCacheOverflowSizeGBParameter::append(OperationContext* opCtx,
                                                        BSONObjBuilder& b,
                                                        const std::string& name) {
