@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -65,9 +64,9 @@
 namespace mongo {
 namespace {
 
-using std::unique_ptr;
 using std::string;
 using std::stringstream;
+using std::unique_ptr;
 
 class WiredTigerHarnessHelper final : public RecordStoreHarnessHelper {
 public:
@@ -98,9 +97,9 @@ public:
 
     virtual std::unique_ptr<RecordStore> newNonCappedRecordStore(const std::string& ns) {
         WiredTigerRecoveryUnit* ru =
-            dynamic_cast<WiredTigerRecoveryUnit*>(_engine.newRecoveryUnit());
+            checked_cast<WiredTigerRecoveryUnit*>(_engine.newRecoveryUnit());
         OperationContextNoop opCtx(ru);
-        string uri = "table:" + ns;
+        string uri = WiredTigerKVEngine::kTableUriPrefix + ns;
 
         const bool prefixed = false;
         StatusWith<std::string> result = WiredTigerRecordStore::generateCreateString(
@@ -117,7 +116,7 @@ public:
 
         WiredTigerRecordStore::Params params;
         params.ns = ns;
-        params.uri = uri;
+        params.ident = ns;
         params.engineName = kWiredTigerEngineName;
         params.isCapped = false;
         params.isEphemeral = false;
@@ -125,6 +124,7 @@ public:
         params.cappedMaxDocs = -1;
         params.cappedCallback = nullptr;
         params.sizeStorer = nullptr;
+        params.tracksSizeAdjustments = true;
 
         auto ret = stdx::make_unique<StandardWiredTigerRecordStore>(&_engine, &opCtx, params);
         ret->postConstructorInit(&opCtx);
@@ -142,7 +142,8 @@ public:
         WiredTigerRecoveryUnit* ru =
             dynamic_cast<WiredTigerRecoveryUnit*>(_engine.newRecoveryUnit());
         OperationContextNoop opCtx(ru);
-        string uri = "table:a.b";
+        string ident = "a.b";
+        string uri = WiredTigerKVEngine::kTableUriPrefix + "a.b";
 
         CollectionOptions options;
         options.capped = true;
@@ -162,7 +163,7 @@ public:
 
         WiredTigerRecordStore::Params params;
         params.ns = ns;
-        params.uri = uri;
+        params.ident = ident;
         params.engineName = kWiredTigerEngineName;
         params.isCapped = true;
         params.isEphemeral = false;
@@ -170,6 +171,7 @@ public:
         params.cappedMaxDocs = cappedMaxDocs;
         params.cappedCallback = nullptr;
         params.sizeStorer = nullptr;
+        params.tracksSizeAdjustments = true;
 
         auto ret = stdx::make_unique<StandardWiredTigerRecordStore>(&_engine, &opCtx, params);
         ret->postConstructorInit(&opCtx);
@@ -216,9 +218,10 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
     unique_ptr<WiredTigerHarnessHelper> harnessHelper(new WiredTigerHarnessHelper());
     unique_ptr<RecordStore> rs(harnessHelper->newNonCappedRecordStore());
 
+    string ident = rs->getIdent();
     string uri = checked_cast<WiredTigerRecordStore*>(rs.get())->getURI();
 
-    string indexUri = "table:myindex";
+    string indexUri = WiredTigerKVEngine::kTableUriPrefix + "myindex";
     const bool enableWtLogging = false;
     WiredTigerSizeStorer ss(harnessHelper->conn(), indexUri, enableWtLogging);
     checked_cast<WiredTigerRecordStore*>(rs.get())->setSizeStorer(&ss);
@@ -230,8 +233,7 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         {
             WriteUnitOfWork uow(opCtx.get());
             for (int i = 0; i < N; i++) {
-                StatusWith<RecordId> res =
-                    rs->insertRecord(opCtx.get(), "a", 2, Timestamp(), false);
+                StatusWith<RecordId> res = rs->insertRecord(opCtx.get(), "a", 2, Timestamp());
                 ASSERT_OK(res.getStatus());
             }
             uow.commit();
@@ -254,7 +256,7 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
         WiredTigerRecordStore::Params params;
         params.ns = "a.b"_sd;
-        params.uri = uri;
+        params.ident = ident;
         params.engineName = kWiredTigerEngineName;
         params.isCapped = false;
         params.isEphemeral = false;
@@ -262,6 +264,7 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         params.cappedMaxDocs = -1;
         params.cappedCallback = nullptr;
         params.sizeStorer = &ss;
+        params.tracksSizeAdjustments = true;
 
         auto ret = new StandardWiredTigerRecordStore(nullptr, opCtx.get(), params);
         ret->postConstructorInit(opCtx.get());
@@ -298,53 +301,22 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
     rs.reset(nullptr);  // this has to be deleted before ss
 }
 
-class GoodValidateAdaptor : public ValidateAdaptor {
-public:
-    virtual Status validate(const RecordId& recordId, const RecordData& record, size_t* dataSize) {
-        *dataSize = static_cast<size_t>(record.size());
-        return Status::OK();
-    }
-};
-
-class BadValidateAdaptor : public ValidateAdaptor {
-public:
-    virtual Status validate(const RecordId& recordId, const RecordData& record, size_t* dataSize) {
-        *dataSize = static_cast<size_t>(record.size());
-        return Status(ErrorCodes::UnknownError, "");
-    }
-};
-
-class SizeStorerValidateTest : public mongo::unittest::Test {
+class SizeStorerUpdateTest : public mongo::unittest::Test {
 private:
     virtual void setUp() {
         harnessHelper.reset(new WiredTigerHarnessHelper());
         const bool enableWtLogging = false;
         sizeStorer.reset(
-            new WiredTigerSizeStorer(harnessHelper->conn(), "table:sizeStorer", enableWtLogging));
+            new WiredTigerSizeStorer(harnessHelper->conn(),
+                                     WiredTigerKVEngine::kTableUriPrefix + "sizeStorer",
+                                     enableWtLogging));
         rs = harnessHelper->newNonCappedRecordStore();
         WiredTigerRecordStore* wtrs = checked_cast<WiredTigerRecordStore*>(rs.get());
         wtrs->setSizeStorer(sizeStorer.get());
+        ident = wtrs->getIdent();
         uri = wtrs->getURI();
-
-        expectedNumRecords = 100;
-        expectedDataSize = expectedNumRecords * 2;
-        {
-            ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-            WriteUnitOfWork uow(opCtx.get());
-            for (int i = 0; i < expectedNumRecords; i++) {
-                ASSERT_OK(rs->insertRecord(opCtx.get(), "a", 2, Timestamp(), false).getStatus());
-            }
-            uow.commit();
-        }
-        auto info = sizeStorer->load(uri);
-        info->numRecords.store(0);
-        info->dataSize.store(0);
-        sizeStorer->store(uri, info);
     }
     virtual void tearDown() {
-        expectedNumRecords = 0;
-        expectedDataSize = 0;
-
         rs.reset(nullptr);
         sizeStorer->flush(false);
         sizeStorer.reset(nullptr);
@@ -363,91 +335,17 @@ protected:
     std::unique_ptr<WiredTigerHarnessHelper> harnessHelper;
     std::unique_ptr<WiredTigerSizeStorer> sizeStorer;
     std::unique_ptr<RecordStore> rs;
+    std::string ident;
     std::string uri;
-
-    long long expectedNumRecords;
-    long long expectedDataSize;
 };
 
 // Basic validation - size storer data is updated.
-TEST_F(SizeStorerValidateTest, Basic) {
+TEST_F(SizeStorerUpdateTest, Basic) {
     ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-    GoodValidateAdaptor adaptor;
-    ValidateResults results;
-    BSONObjBuilder output;
-    ASSERT_OK(rs->validate(opCtx.get(), kValidateIndex, &adaptor, &results, &output));
-    BSONObj obj = output.obj();
-    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
-    ASSERT_EQUALS(expectedNumRecords, getNumRecords());
-    ASSERT_EQUALS(expectedDataSize, getDataSize());
-}
-
-// Full validation - size storer data is updated.
-TEST_F(SizeStorerValidateTest, FullWithGoodAdaptor) {
-    ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-    GoodValidateAdaptor adaptor;
-    ValidateResults results;
-    BSONObjBuilder output;
-    ASSERT_OK(rs->validate(opCtx.get(), kValidateFull, &adaptor, &results, &output));
-    BSONObj obj = output.obj();
-    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
-    ASSERT_EQUALS(expectedNumRecords, getNumRecords());
-    ASSERT_EQUALS(expectedDataSize, getDataSize());
-}
-
-// Full validation with a validation adaptor that fails - size storer data is not updated.
-TEST_F(SizeStorerValidateTest, FullWithBadAdapter) {
-    ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-    BadValidateAdaptor adaptor;
-    ValidateResults results;
-    BSONObjBuilder output;
-    ASSERT_OK(rs->validate(opCtx.get(), kValidateFull, &adaptor, &results, &output));
-    BSONObj obj = output.obj();
-    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
-    ASSERT_EQUALS(0, getNumRecords());
-    ASSERT_EQUALS(0, getDataSize());
-}
-
-// Load bad _numRecords and _dataSize values at record store creation.
-TEST_F(SizeStorerValidateTest, InvalidSizeStorerAtCreation) {
-    rs.reset(NULL);
-
-    ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-    auto info = sizeStorer->load(uri);
-    info->numRecords.store(expectedNumRecords * 2);
-    info->dataSize.store(expectedDataSize * 2);
-    sizeStorer->store(uri, info);
-
-    WiredTigerRecordStore::Params params;
-    params.ns = "a.b"_sd;
-    params.uri = uri;
-    params.engineName = kWiredTigerEngineName;
-    params.isCapped = false;
-    params.isEphemeral = false;
-    params.cappedMaxSize = -1;
-    params.cappedMaxDocs = -1;
-    params.cappedCallback = nullptr;
-    params.sizeStorer = sizeStorer.get();
-
-    auto ret = new StandardWiredTigerRecordStore(nullptr, opCtx.get(), params);
-    ret->postConstructorInit(opCtx.get());
-    rs.reset(ret);
-
-    ASSERT_EQUALS(expectedNumRecords * 2, rs->numRecords(NULL));
-    ASSERT_EQUALS(expectedDataSize * 2, rs->dataSize(NULL));
-
-    // Full validation should fix record and size counters.
-    GoodValidateAdaptor adaptor;
-    ValidateResults results;
-    BSONObjBuilder output;
-    ASSERT_OK(rs->validate(opCtx.get(), kValidateFull, &adaptor, &results, &output));
-    BSONObj obj = output.obj();
-    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
-    ASSERT_EQUALS(expectedNumRecords, getNumRecords());
-    ASSERT_EQUALS(expectedDataSize, getDataSize());
-
-    ASSERT_EQUALS(expectedNumRecords, rs->numRecords(NULL));
-    ASSERT_EQUALS(expectedDataSize, rs->dataSize(NULL));
+    long long val = 5;
+    rs->updateStatsAfterRepair(opCtx.get(), val, val);
+    ASSERT_EQUALS(getNumRecords(), val);
+    ASSERT_EQUALS(getDataSize(), val);
 }
 
 }  // namespace
