@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -35,6 +34,7 @@
 #include <numeric>
 
 #include "mongo/base/simple_string_data_comparator.h"
+#include "mongo/bson/bsonobjbuilder.h"
 #include "mongo/bson/mutable/algorithm.h"
 #include "mongo/db/matcher/expression_parser.h"
 #include "mongo/db/update/update_internal_node.h"
@@ -82,6 +82,16 @@ Status checkSortClause(const BSONObj& sortObject) {
     return Status::OK();
 }
 
+/**
+ * std::abs(LLONG_MIN) results in undefined behavior on 2's complement systems because the
+ * absolute value of LLONG_MIN cannot be represented in a 'long long'.
+ *
+ * If the input is LLONG_MIN, will return std::abs(LLONG_MIN + 1).
+ */
+long long safeApproximateAbs(long long val) {
+    return val == std::numeric_limits<decltype(val)>::min() ? std::abs(val + 1) : std::abs(val);
+}
+
 }  // namespace
 
 Status PushNode::init(BSONElement modExpr, const boost::intrusive_ptr<ExpressionContext>& expCtx) {
@@ -130,7 +140,7 @@ Status PushNode::init(BSONElement modExpr, const boost::intrusive_ptr<Expression
         auto sliceIt = clausesFound.find(kSliceClauseName);
         if (sliceIt != clausesFound.end()) {
             auto sliceClause = sliceIt->second;
-            auto parsedSliceValue = MatchExpressionParser::parseIntegerElementToLong(sliceClause);
+            auto parsedSliceValue = sliceClause.parseIntegerElementToLong();
             if (parsedSliceValue.isOK()) {
                 _slice = parsedSliceValue.getValue();
             } else {
@@ -173,8 +183,7 @@ Status PushNode::init(BSONElement modExpr, const boost::intrusive_ptr<Expression
         auto positionIt = clausesFound.find(kPositionClauseName);
         if (positionIt != clausesFound.end()) {
             auto positionClause = positionIt->second;
-            auto parsedPositionValue =
-                MatchExpressionParser::parseIntegerElementToLong(positionClause);
+            auto parsedPositionValue = positionClause.parseIntegerElementToLong();
             if (parsedPositionValue.isOK()) {
                 _position = parsedPositionValue.getValue();
             } else {
@@ -192,8 +201,36 @@ Status PushNode::init(BSONElement modExpr, const boost::intrusive_ptr<Expression
     return Status::OK();
 }
 
+BSONObj PushNode::operatorValue() const {
+    BSONObjBuilder bob;
+    {
+        BSONObjBuilder subBuilder(bob.subobjStart(""));
+        {
+            // This serialization function always produces $each regardless of whether the input
+            // contained it.
+            BSONObjBuilder eachBuilder(subBuilder.subarrayStart("$each"));
+            for (const auto value : _valuesToPush)
+                eachBuilder << value;
+        }
+        if (_slice)
+            subBuilder << "$slice" << _slice.get();
+        if (_position)
+            subBuilder << "$position" << _position.get();
+        if (_sort) {
+            // The sort pattern is stored in a dummy enclosing object that we must unwrap.
+            if (_sort->useWholeValue)
+                subBuilder << "$sort" << _sort->sortPattern.firstElement();
+            else
+                subBuilder << "$sort" << _sort->sortPattern;
+        }
+    }
+    return bob.obj();
+}
+
 ModifierNode::ModifyResult PushNode::insertElementsWithPosition(
-    mutablebson::Element* array, long long position, const std::vector<BSONElement>& valuesToPush) {
+    mutablebson::Element* array,
+    boost::optional<long long> position,
+    const std::vector<BSONElement>& valuesToPush) {
     if (valuesToPush.empty()) {
         return ModifyResult::kNoOp;
     }
@@ -211,15 +248,15 @@ ModifierNode::ModifyResult PushNode::insertElementsWithPosition(
     if (arraySize == 0) {
         invariant(array->pushBack(firstElementToInsert));
         result = ModifyResult::kNormalUpdate;
-    } else if (position > arraySize) {
+    } else if (!position || position.get() > arraySize) {
         invariant(array->pushBack(firstElementToInsert));
         result = ModifyResult::kArrayAppendUpdate;
-    } else if (position > 0) {
-        auto insertAfter = getNthChild(*array, position - 1);
+    } else if (position.get() > 0) {
+        auto insertAfter = getNthChild(*array, position.get() - 1);
         invariant(insertAfter.addSiblingRight(firstElementToInsert));
         result = ModifyResult::kNormalUpdate;
-    } else if (position < 0 && -position < arraySize) {
-        auto insertAfter = getNthChild(*array, arraySize - (-position) - 1);
+    } else if (position.get() < 0 && safeApproximateAbs(position.get()) < arraySize) {
+        auto insertAfter = getNthChild(*array, arraySize - safeApproximateAbs(position.get()) - 1);
         invariant(insertAfter.addSiblingRight(firstElementToInsert));
         result = ModifyResult::kNormalUpdate;
     } else {
@@ -227,16 +264,22 @@ ModifierNode::ModifyResult PushNode::insertElementsWithPosition(
         result = ModifyResult::kNormalUpdate;
     }
 
-    // We insert all the rest of the elements after the one we just inserted.
-    std::accumulate(std::next(valuesToPush.begin()),
-                    valuesToPush.end(),
-                    firstElementToInsert,
-                    [&document](auto& insertAfter, auto& valueToInsert) {
-                        auto nextElementToInsert =
-                            document.makeElementWithNewFieldName(StringData(), valueToInsert);
-                        invariant(insertAfter.addSiblingRight(nextElementToInsert));
-                        return nextElementToInsert;
-                    });
+    // We insert all the rest of the elements after the one we just
+    // inserted.
+    //
+    // TODO: The use of std::accumulate here is maybe questionable
+    // given that we are ignoring the return value. MSVC flagged this,
+    // and we worked around by tagging the result as unused.
+    MONGO_COMPILER_VARIABLE_UNUSED auto ignored =
+        std::accumulate(std::next(valuesToPush.begin()),
+                        valuesToPush.end(),
+                        firstElementToInsert,
+                        [&document](auto& insertAfter, auto& valueToInsert) {
+                            auto nextElementToInsert =
+                                document.makeElementWithNewFieldName(StringData(), valueToInsert);
+                            invariant(insertAfter.addSiblingRight(nextElementToInsert));
+                            return nextElementToInsert;
+                        });
 
     return result;
 }
@@ -249,10 +292,8 @@ ModifierNode::ModifyResult PushNode::performPush(mutablebson::Element* element,
         uasserted(ErrorCodes::BadValue,
                   str::stream() << "The field '" << elementPath->dottedField() << "'"
                                 << " must be an array but is of type "
-                                << typeName(element->getType())
-                                << " in document {"
-                                << (idElem.ok() ? idElem.toString() : "no id")
-                                << "}");
+                                << typeName(element->getType()) << " in document {"
+                                << (idElem.ok() ? idElem.toString() : "no id") << "}");
     }
 
     auto result = insertElementsWithPosition(element, _position, _valuesToPush);
@@ -262,20 +303,18 @@ ModifierNode::ModifyResult PushNode::performPush(mutablebson::Element* element,
         sortChildren(*element, *_sort);
     }
 
-    // std::abs(LLONG_MIN) results in undefined behavior on 2's complement systems because the
-    // absolute value of LLONG_MIN cannot be represented in a 'long long'.
-    const auto sliceAbs = _slice == std::numeric_limits<decltype(_slice)>::min()
-        ? std::abs(_slice + 1)
-        : std::abs(_slice);
+    if (_slice) {
+        const auto sliceAbs = safeApproximateAbs(_slice.get());
 
-    while (static_cast<long long>(countChildren(*element)) > sliceAbs) {
-        result = ModifyResult::kNormalUpdate;
-        if (_slice >= 0) {
-            invariant(element->popBack());
-        } else {
-            // A negative value in '_slice' trims the array down to abs(_slice) but removes entries
-            // from the front of the array instead of the back.
-            invariant(element->popFront());
+        while (static_cast<long long>(countChildren(*element)) > sliceAbs) {
+            result = ModifyResult::kNormalUpdate;
+            if (_slice.get() >= 0) {
+                invariant(element->popBack());
+            } else {
+                // A negative value in '_slice' trims the array down to abs(_slice) but removes
+                // entries from the front of the array instead of the back.
+                invariant(element->popFront());
+            }
         }
     }
 
