@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -36,7 +35,7 @@
 #include "mongo/base/string_data.h"
 #include "mongo/bson/util/bson_extract.h"
 #include "mongo/db/field_parser.h"
-#include "mongo/util/mongoutils/str.h"
+#include "mongo/util/str.h"
 
 namespace mongo {
 
@@ -62,20 +61,20 @@ constexpr StringData kWElectionIdFieldName = "wElectionId"_sd;
 
 }  // namespace
 
-const int WriteConcernOptions::kNoTimeout(0);
-const int WriteConcernOptions::kNoWaiting(-1);
+constexpr int WriteConcernOptions::kNoTimeout;
+constexpr int WriteConcernOptions::kNoWaiting;
 
-const StringData WriteConcernOptions::kWriteConcernField = "writeConcern"_sd;
+constexpr StringData WriteConcernOptions::kWriteConcernField;
 const char WriteConcernOptions::kMajority[] = "majority";
 
 const BSONObj WriteConcernOptions::Default = BSONObj();
 const BSONObj WriteConcernOptions::Acknowledged(BSON("w" << W_NORMAL));
 const BSONObj WriteConcernOptions::Unacknowledged(BSON("w" << W_NONE));
 const BSONObj WriteConcernOptions::Majority(BSON("w" << WriteConcernOptions::kMajority));
-const Seconds WriteConcernOptions::kWriteConcernTimeoutSystem{15};
-const Seconds WriteConcernOptions::kWriteConcernTimeoutMigration{60};
-const Seconds WriteConcernOptions::kWriteConcernTimeoutSharding{60};
-const Seconds WriteConcernOptions::kWriteConcernTimeoutUserCommand{60};
+constexpr Seconds WriteConcernOptions::kWriteConcernTimeoutSystem;
+constexpr Seconds WriteConcernOptions::kWriteConcernTimeoutMigration;
+constexpr Seconds WriteConcernOptions::kWriteConcernTimeoutSharding;
+constexpr Seconds WriteConcernOptions::kWriteConcernTimeoutUserCommand;
 
 
 WriteConcernOptions::WriteConcernOptions(int numNodes, SyncMode sync, int timeout)
@@ -160,6 +159,12 @@ Status WriteConcernOptions::parse(const BSONObj& obj) {
     return Status::OK();
 }
 
+WriteConcernOptions WriteConcernOptions::deserializerForIDL(const BSONObj& obj) {
+    WriteConcernOptions writeConcernOptions;
+    uassertStatusOK(writeConcernOptions.parse(obj));
+    return writeConcernOptions;
+}
+
 StatusWith<WriteConcernOptions> WriteConcernOptions::extractWCFromCommand(
     const BSONObj& cmdObj, const WriteConcernOptions& defaultWC) {
     WriteConcernOptions writeConcern = defaultWC;
