@@ -1,7 +1,3 @@
-// #file dbtests.cpp : Runs db unit tests.
-//
-
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -31,16 +27,18 @@
  *    it in the license file.
  */
 
+/**
+ * Runs db unit tests.
+ */
+
 #include "mongo/platform/basic.h"
 
 #include "mongo/dbtests/dbtests.h"
 
 #include "mongo/base/init.h"
 #include "mongo/base/initializer.h"
-#include "mongo/client/dbclientinterface.h"
 #include "mongo/db/auth/authorization_manager.h"
-#include "mongo/db/auth/authorization_manager_global.h"
-#include "mongo/db/catalog/index_create.h"
+#include "mongo/db/catalog/multi_index_block.h"
 #include "mongo/db/commands.h"
 #include "mongo/db/commands/test_commands_enabled.h"
 #include "mongo/db/db_raii.h"
@@ -106,24 +104,63 @@ Status createIndexFromSpec(OperationContext* opCtx, StringData ns, const BSONObj
         invariant(coll);
         wunit.commit();
     }
-    MultiIndexBlock indexer(opCtx, coll);
-    Status status = indexer.init(spec).getStatus();
+    MultiIndexBlock indexer;
+    ON_BLOCK_EXIT([&] { indexer.cleanUpAfterBuild(opCtx, coll); });
+    Status status = indexer.init(opCtx, coll, spec, MultiIndexBlock::kNoopOnInitFn).getStatus();
     if (status == ErrorCodes::IndexAlreadyExists) {
         return Status::OK();
     }
     if (!status.isOK()) {
         return status;
     }
-    status = indexer.insertAllDocumentsInCollection();
+    status = indexer.insertAllDocumentsInCollection(opCtx, coll);
+    if (!status.isOK()) {
+        return status;
+    }
+    status = indexer.checkConstraints(opCtx);
     if (!status.isOK()) {
         return status;
     }
     WriteUnitOfWork wunit(opCtx);
-    indexer.commit();
+    ASSERT_OK(indexer.commit(
+        opCtx, coll, MultiIndexBlock::kNoopOnCreateEachFn, MultiIndexBlock::kNoopOnCommitFn));
     wunit.commit();
     return Status::OK();
 }
 
+WriteContextForTests::WriteContextForTests(OperationContext* opCtx, StringData ns)
+    : _opCtx(opCtx), _nss(ns) {
+    // Lock the database and collection
+    _autoCreateDb.emplace(opCtx, _nss.db(), MODE_IX);
+    _collLock.emplace(opCtx, _nss, MODE_IX);
+
+    const bool doShardVersionCheck = false;
+
+    _clientContext.emplace(opCtx, _nss.ns(), doShardVersionCheck);
+    invariant(_autoCreateDb->getDb() == _clientContext->db());
+
+    // If the collection exists, there is no need to lock into stronger mode
+    if (getCollection())
+        return;
+
+    // If the database was just created, it is already locked in MODE_X so we can skip the relocking
+    // code below
+    if (_autoCreateDb->justCreated()) {
+        dassert(opCtx->lockState()->isDbLockedForMode(_nss.db(), MODE_X));
+        return;
+    }
+
+    // If the collection doesn't exists, put the context in a state where the database is locked in
+    // MODE_X so that the collection can be created
+    _clientContext.reset();
+    _collLock.reset();
+    _autoCreateDb.reset();
+    _autoCreateDb.emplace(opCtx, _nss.db(), MODE_X);
+
+    _clientContext.emplace(opCtx, _nss.ns(), _autoCreateDb->getDb());
+    invariant(_autoCreateDb->getDb() == _clientContext->db());
+}
+
 }  // namespace dbtests
 }  // namespace mongo
 
@@ -135,11 +172,12 @@ int dbtestsMain(int argc, char** argv, char** envp) {
 
     mongo::runGlobalInitializersOrDie(argc, argv, envp);
     serverGlobalParams.featureCompatibility.setVersion(
-        ServerGlobalParams::FeatureCompatibility::Version::kFullyUpgradedTo40);
+        ServerGlobalParams::FeatureCompatibility::Version::kFullyUpgradedTo42);
     repl::ReplSettings replSettings;
     replSettings.setOplogSizeBytes(10 * 1024 * 1024);
     setGlobalServiceContext(ServiceContext::make());
-    ServiceContext* service = getGlobalServiceContext();
+
+    const auto service = getGlobalServiceContext();
     service->setServiceEntryPoint(std::make_unique<ServiceEntryPointMongod>(service));
 
     auto logicalClock = stdx::make_unique<LogicalClock>(service);
@@ -166,7 +204,7 @@ int dbtestsMain(int argc, char** argv, char** envp) {
         service,
         std::unique_ptr<repl::ReplicationCoordinator>(
             new repl::ReplicationCoordinatorMock(service, replSettings)));
-    repl::ReplicationCoordinator::get(getGlobalServiceContext())
+    repl::ReplicationCoordinator::get(service)
         ->setFollowerMode(repl::MemberState::RS_PRIMARY)
         .ignore();
 
@@ -174,7 +212,7 @@ int dbtestsMain(int argc, char** argv, char** envp) {
     repl::DropPendingCollectionReaper::set(
         service, stdx::make_unique<repl::DropPendingCollectionReaper>(storageMock.get()));
 
-    getGlobalAuthorizationManager()->setAuthEnabled(false);
+    AuthorizationManager::get(service)->setAuthEnabled(false);
     ScriptEngine::setup();
     StartupTest::runTests();
     return mongo::dbtests::runDbTests(argc, argv);
