@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -33,7 +32,8 @@
 #include <string>
 #include <vector>
 
-#include "mongo/client/dbclientinterface.h"
+#include "mongo/client/connection_string.h"
+#include "mongo/client/query.h"
 #include "mongo/db/jsobj.h"
 #include "mongo/rpc/unique_message.h"
 #include "mongo/stdx/unordered_map.h"
@@ -148,13 +148,21 @@ public:
      */
     void remove(const std::string& ns, Query query, int flags = 0);
 
+    /**
+     * Assign a UUID to a collection
+     *
+     * @param ns the namespace to be associated with the uuid.
+     * @param uuid the uuid to associate with the namespace.
+     */
+    void assignCollectionUuid(const std::string& ns, const mongo::UUID& uuid);
+
     //
     // DBClientBase methods
     //
     rpc::UniqueReply runCommand(InstanceID id, const OpMsgRequest& request);
 
     mongo::BSONArray query(InstanceID id,
-                           const std::string& ns,
+                           const NamespaceStringOrUUID& nsOrUuid,
                            mongo::Query query = mongo::Query(),
                            int nToReturn = 0,
                            int nToSkip = 0,
@@ -212,6 +220,7 @@ private:
 
     typedef stdx::unordered_map<std::string, std::shared_ptr<CircularBSONIterator>> CmdToReplyObj;
     typedef stdx::unordered_map<std::string, std::vector<BSONObj>> MockDataMgr;
+    typedef stdx::unordered_map<mongo::UUID, std::string, UUID::Hash> UUIDMap;
 
     bool _isRunning;
 
@@ -223,6 +232,7 @@ private:
     //
     CmdToReplyObj _cmdMap;
     MockDataMgr _dataMgr;
+    UUIDMap _uuidToNs;
 
     //
     // Op Counters
