@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -32,7 +31,6 @@
 
 #include <system_error>
 
-#include "mongo/base/disallow_copying.h"
 #include "mongo/stdx/functional.h"
 #include "mongo/util/time_support.h"
 
@@ -43,7 +41,8 @@ namespace executor {
  * An asynchronous waitable timer interface.
  */
 class AsyncTimerInterface {
-    MONGO_DISALLOW_COPYING(AsyncTimerInterface);
+    AsyncTimerInterface(const AsyncTimerInterface&) = delete;
+    AsyncTimerInterface& operator=(const AsyncTimerInterface&) = delete;
 
 public:
     virtual ~AsyncTimerInterface() = default;
@@ -82,7 +81,8 @@ protected:
  * A factory for AsyncTimers.
  */
 class AsyncTimerFactoryInterface {
-    MONGO_DISALLOW_COPYING(AsyncTimerFactoryInterface);
+    AsyncTimerFactoryInterface(const AsyncTimerFactoryInterface&) = delete;
+    AsyncTimerFactoryInterface& operator=(const AsyncTimerFactoryInterface&) = delete;
 
 public:
     virtual ~AsyncTimerFactoryInterface() = default;
