@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -35,8 +34,8 @@
 #include <tuple>
 #include <utility>
 
-#include "mongo/client/dbclientinterface.h"
 #include "mongo/client/read_preference.h"
+#include "mongo/db/dbmessage.h"
 #include "mongo/db/namespace_string.h"
 #include "mongo/rpc/message.h"
 #include "mongo/rpc/metadata.h"
