@@ -1,23 +1,24 @@
 /**
- *    Copyright (C) 2015 MongoDB Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -33,7 +34,6 @@
 #include <string>
 #include <vector>
 
-#include "mongo/base/disallow_copying.h"
 #include "mongo/db/keys_collection_document.h"
 #include "mongo/db/repl/optime_with.h"
 #include "mongo/db/write_concern_options.h"
@@ -82,7 +82,8 @@ struct ConnectionPoolStats;
  * move to be run on the config server primary.
  */
 class ShardingCatalogClient {
-    MONGO_DISALLOW_COPYING(ShardingCatalogClient);
+    ShardingCatalogClient(const ShardingCatalogClient&) = delete;
+    ShardingCatalogClient& operator=(const ShardingCatalogClient&) = delete;
 
     // Allows ShardingCatalogManager to access _exhaustiveFindOnConfig
     friend class ShardingCatalogManager;
@@ -202,7 +203,8 @@ public:
                                                          repl::ReadConcernLevel readConcern) = 0;
 
     /**
-     * Retrieves all tags for the specified collection.
+     * Retrieves all zones defined for the specified collection. The returned vector is sorted based
+     * on the min key of the zones.
      *
      * Returns a !OK status if an error occurs.
      */
@@ -266,23 +268,6 @@ public:
                                            const WriteConcernOptions& writeConcern,
                                            repl::ReadConcernLevel readConcern) = 0;
 
-    /**
-     * Writes a diagnostic event to the action log.
-     */
-    virtual Status logAction(OperationContext* opCtx,
-                             const std::string& what,
-                             const std::string& ns,
-                             const BSONObj& detail) = 0;
-
-    /**
-     * Writes a diagnostic event to the change log.
-     */
-    virtual Status logChange(OperationContext* opCtx,
-                             const std::string& what,
-                             const std::string& ns,
-                             const BSONObj& detail,
-                             const WriteConcernOptions& writeConcern) = 0;
-
     /**
      * Reads global sharding settings from the confing.settings collection. The key parameter is
      * used as the _id of the respective setting document.
@@ -336,6 +321,19 @@ public:
                                         const BSONObj& doc,
                                         const WriteConcernOptions& writeConcern) = 0;
 
+    /**
+     * Directly inserts documents in the specified namespace on the config server. Inserts said
+     * documents using a retryable write. Underneath, a session is created and destroyed -- this
+     * ad-hoc session creation strategy should never be used outside of specific, non-performant
+     * code paths.
+     *
+     * Must only be used for insertions in the 'config' database.
+     */
+    virtual void insertConfigDocumentsAsRetryableWrite(OperationContext* opCtx,
+                                                       const NamespaceString& nss,
+                                                       std::vector<BSONObj> docs,
+                                                       const WriteConcernOptions& writeConcern) = 0;
+
     /**
      * Updates a single document in the specified namespace on the config server. The document must
      * have an _id index. Must only be used for updates to the 'config' database.
