@@ -1,29 +1,30 @@
 /**
- *    Copyright 2010 10gen Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects
- *    for all of the code used other than as permitted herein. If you modify
- *    file(s) with this exception, you may extend this exception to your
- *    version of the file(s), but you are not obligated to do so. If you do not
- *    wish to do so, delete this exception statement from your version. If you
- *    delete this exception statement from all source files in the program,
- *    then also delete it in the license file.
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
  */
 
 #define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kNetwork
@@ -33,8 +34,8 @@
 #include "mongo/s/client/parallel.h"
 
 #include "mongo/client/constants.h"
+#include "mongo/client/dbclient_cursor.h"
 #include "mongo/client/dbclient_rs.h"
-#include "mongo/client/dbclientcursor.h"
 #include "mongo/client/replica_set_monitor.h"
 #include "mongo/db/bson/dotted_path_support.h"
 #include "mongo/db/query/query_request.h"
@@ -48,9 +49,9 @@
 
 namespace mongo {
 
-using std::shared_ptr;
 using std::map;
 using std::set;
+using std::shared_ptr;
 using std::string;
 using std::vector;
 
@@ -58,8 +59,6 @@ namespace dps = ::mongo::dotted_path_support;
 
 namespace {
 
-LabeledLevel pc("pcursor", 2);
-
 /**
  * Throws an exception wrapping the error document in this cursor when the error flag is set.
  */
@@ -218,7 +217,7 @@ void ParallelSortClusteredCursor::init(OperationContext* opCtx) {
     } else {
         // You can only get here by using the legacy constructor
         // TODO: Eliminate this
-        _oldInit();
+        _oldInit(opCtx);
     }
 }
 
@@ -351,7 +350,7 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
     if (!state->conn) {
         const auto shard =
             uassertStatusOK(Grid::get(opCtx)->shardRegistry()->getShard(opCtx, shardId));
-        state->conn.reset(new ShardConnection(shard->getConnString(), ns.ns(), manager));
+        state->conn.reset(new ShardConnection(opCtx, shard->getConnString(), ns.ns(), manager));
     }
 
     const DBClientBase* rawConn = state->conn->getRawConn();
@@ -373,7 +372,8 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
             // that the primary is now up on it's own and has to rely on other threads to refresh
             // node states.
 
-            OCCASIONALLY {
+            static Occasionally sampler;
+            if (sampler.tick()) {
                 const DBClientReplicaSet* repl = dynamic_cast<const DBClientReplicaSet*>(rawConn);
                 dassert(repl);
                 warning() << "Primary for " << repl->getServerAddress()
@@ -387,8 +387,8 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
 
     try {
         if (state->conn->setVersion()) {
-            LOG(pc) << "needed to set remote version on connection to value "
-                    << "compatible with " << vinfo;
+            LOG(2) << "pcursor: needed to set remote version on connection to value "
+                   << "compatible with " << vinfo;
         }
     } catch (const DBException& dbExcep) {
         auto errCode = dbExcep.code();
@@ -398,7 +398,8 @@ void ParallelSortClusteredCursor::setupVersionAndHandleSlaveOk(
             // It's okay if we don't set the version when talking to a secondary, we can
             // be stale in any case.
 
-            OCCASIONALLY {
+            static Occasionally sampler;
+            if (sampler.tick()) {
                 const DBClientReplicaSet* repl =
                     dynamic_cast<const DBClientReplicaSet*>(state->conn->getRawConn());
                 dassert(repl);
@@ -417,14 +418,14 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
     const NamespaceString nss(!_cInfo.isEmpty() ? _cInfo.versionedNS : _qSpec.ns());
 
     string prefix;
-    if (MONGO_unlikely(shouldLog(pc))) {
+    if (MONGO_unlikely(shouldLog(logger::LogSeverity::Debug(2)))) {
         if (_totalTries > 0) {
             prefix = str::stream() << "retrying (" << _totalTries << " tries)";
         } else {
             prefix = "creating";
         }
     }
-    LOG(pc) << prefix << " pcursor over " << _qSpec << " and " << _cInfo;
+    LOG(2) << "pcursor: " << prefix << " pcursor over " << _qSpec << " and " << _cInfo;
 
     shared_ptr<ChunkManager> manager;
     shared_ptr<Shard> primary;
@@ -447,7 +448,7 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
     string vinfo;
 
     if (manager) {
-        if (MONGO_unlikely(shouldLog(pc))) {
+        if (MONGO_unlikely(shouldLog(logger::LogSeverity::Debug(2)))) {
             vinfo = str::stream() << "[" << manager->getns().ns() << " @ "
                                   << manager->getVersion().toString() << "]";
         }
@@ -457,7 +458,7 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                                      !_cInfo.isEmpty() ? _cInfo.cmdCollation : BSONObj(),
                                      &shardIds);
     } else if (primary) {
-        if (MONGO_unlikely(shouldLog(pc))) {
+        if (MONGO_unlikely(shouldLog(logger::LogSeverity::Debug(2)))) {
             vinfo = str::stream() << "[unsharded @ " << primary->toString() << "]";
         }
 
@@ -469,14 +470,14 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
         const auto& shardId = cmEntry.first;
 
         if (shardIds.find(shardId) == shardIds.end()) {
-            LOG(pc) << "closing cursor on shard " << shardId
-                    << " as the connection is no longer required by " << vinfo;
+            LOG(2) << "pcursor: closing cursor on shard " << shardId
+                   << " as the connection is no longer required by " << vinfo;
 
             cmEntry.second.cleanup(true);
         }
     }
 
-    LOG(pc) << "initializing over " << shardIds.size() << " shards required by " << vinfo;
+    LOG(2) << "pcursor: initializing over " << shardIds.size() << " shards required by " << vinfo;
 
     // Don't retry indefinitely for whatever reason
     _totalTries++;
@@ -485,8 +486,8 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
     for (const ShardId& shardId : shardIds) {
         auto& mdata = _cursorMap[shardId];
 
-        LOG(pc) << "initializing on shard " << shardId << ", current connection state is "
-                << mdata.toBSON();
+        LOG(2) << "pcursor: initializing on shard " << shardId << ", current connection state is "
+               << mdata.toBSON();
 
         // This may be the first time connecting to this shard, if so we can get an error here
         try {
@@ -546,7 +547,7 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
 
                     state->cursor.reset(new DBClientCursor(
                         state->conn->get(),
-                        ns,
+                        NamespaceString(ns),
                         _qSpec.query(),
                         isCommand() ? 1 : 0,  // nToReturn (0 if query indicates multi)
                         0,                    // nToSkip
@@ -564,16 +565,17 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                         // shard or if we keep better track of chunks, we can actually add the skip
                         // value into the cursor and/or make some assumptions about the return value
                         // size ( (batch size + skip amount) / num_servers ).
-                        _qSpec.ntoreturn() == 0 ? 0 : (_qSpec.ntoreturn() > 0
-                                                           ? _qSpec.ntoreturn() + _qSpec.ntoskip()
-                                                           : _qSpec.ntoreturn() -
-                                                               _qSpec.ntoskip())));  // batchSize
+                        _qSpec.ntoreturn() == 0
+                            ? 0
+                            : (_qSpec.ntoreturn() > 0
+                                   ? _qSpec.ntoreturn() + _qSpec.ntoskip()
+                                   : _qSpec.ntoreturn() - _qSpec.ntoskip())));  // batchSize
                 } else {
                     // Single shard query
 
                     state->cursor.reset(new DBClientCursor(
                         state->conn->get(),
-                        ns,
+                        NamespaceString(ns),
                         _qSpec.query(),
                         _qSpec.ntoreturn(),  // nToReturn
                         _qSpec.ntoskip(),    // nToSkip
@@ -595,9 +597,9 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
 
                 // Without full initialization, throw an exception
                 uassert(15987,
-                        str::stream() << "could not fully initialize cursor on shard " << shardId
-                                      << ", current connection state is "
-                                      << mdata.toBSON().toString(),
+                        str::stream()
+                            << "could not fully initialize cursor on shard " << shardId
+                            << ", current connection state is " << mdata.toBSON().toString(),
                         success);
 
                 mdata.retryNext = false;
@@ -605,9 +607,9 @@ void ParallelSortClusteredCursor::startInit(OperationContext* opCtx) {
                 mdata.finished = true;
             }
 
-            LOG(pc) << "initialized " << (isCommand() ? "command " : "query ")
-                    << (lazyInit ? "(lazily) " : "(full) ") << "on shard " << shardId
-                    << ", current connection state is " << mdata.toBSON();
+            LOG(2) << "pcursor: initialized " << (isCommand() ? "command " : "query ")
+                   << (lazyInit ? "(lazily) " : "(full) ") << "on shard " << shardId
+                   << ", current connection state is " << mdata.toBSON();
         } catch (StaleConfigException& e) {
             // Our version isn't compatible with the current version anymore on at least one shard,
             // need to retry immediately
@@ -702,14 +704,14 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
     bool retry = false;
     map<string, StaleConfigException> staleNSExceptions;
 
-    LOG(pc) << "finishing over " << _cursorMap.size() << " shards";
+    LOG(2) << "pcursor: finishing over " << _cursorMap.size() << " shards";
 
     for (auto& cmEntry : _cursorMap) {
         const auto& shardId = cmEntry.first;
         auto& mdata = cmEntry.second;
 
-        LOG(pc) << "finishing on shard " << shardId << ", current connection state is "
-                << mdata.toBSON();
+        LOG(2) << "pcursor: finishing on shard " << shardId << ", current connection state is "
+               << mdata.toBSON();
 
         // Ignore empty conns for now
         if (!mdata.pcState)
@@ -756,8 +758,8 @@ void ParallelSortClusteredCursor::finishInit(OperationContext* opCtx) {
                 // Finalize state
                 state->cursor->attach(state->conn.get());  // Closes connection for us
 
-                LOG(pc) << "finished on shard " << shardId << ", current connection state is "
-                        << mdata.toBSON();
+                LOG(2) << "pcursor: finished on shard " << shardId
+                       << ", current connection state is " << mdata.toBSON();
             }
         } catch (StaleConfigException& e) {
             retry = true;
@@ -911,7 +913,7 @@ std::shared_ptr<DBClientCursor> ParallelSortClusteredCursor::getShardCursor(
 }
 
 // DEPRECATED (but still used by map/reduce)
-void ParallelSortClusteredCursor::_oldInit() {
+void ParallelSortClusteredCursor::_oldInit(OperationContext* opCtx) {
     // make sure we're not already initialized
     verify(!_cursors);
     _cursors = new DBClientCursorHolder[_numServers];
@@ -970,7 +972,7 @@ void ParallelSortClusteredCursor::_oldInit() {
                 // here
                 try {
                     conns.push_back(shared_ptr<ShardConnection>(new ShardConnection(
-                        uassertStatusOK(ConnectionString::parse(serverHost)), _ns)));
+                        opCtx, uassertStatusOK(ConnectionString::parse(serverHost)), _ns)));
                 } catch (std::exception& e) {
                     socketExs.push_back(e.what() + errLoc);
                     if (!returnPartial) {
@@ -990,8 +992,7 @@ void ParallelSortClusteredCursor::_oldInit() {
 
                 // Version is zero b/c this is deprecated codepath
                 staleConfigExs.push_back(str::stream() << "stale config detected for " << _ns
-                                                       << " in ParallelCursor::_init "
-                                                       << errLoc);
+                                                       << " in ParallelCursor::_init " << errLoc);
                 break;
             }
 
@@ -1002,7 +1003,7 @@ void ParallelSortClusteredCursor::_oldInit() {
             if (!_cursors[i].get())
                 _cursors[i].reset(
                     new DBClientCursor(conns[i]->get(),
-                                       _ns,
+                                       NamespaceString(_ns),
                                        _query,
                                        0,                                 // nToReturn
                                        0,                                 // nToSkip
@@ -1053,8 +1054,8 @@ void ParallelSortClusteredCursor::_oldInit() {
                     _cursors[i].reset(NULL, NULL);
 
                     if (!retry) {
-                        socketExs.push_back(str::stream() << "error querying server: "
-                                                          << servers[i]);
+                        socketExs.push_back(str::stream()
+                                            << "error querying server: " << servers[i]);
                         conns[i]->done();
                     } else {
                         retryQueries.insert(i);
@@ -1274,12 +1275,7 @@ void ParallelConnectionMetadata::cleanup(bool full) {
 
 BSONObj ParallelConnectionMetadata::toBSON() const {
     return BSON("state" << (pcState ? pcState->toBSON() : BSONObj()) << "retryNext" << retryNext
-                        << "init"
-                        << initialized
-                        << "finish"
-                        << finished
-                        << "errored"
-                        << errored);
+                        << "init" << initialized << "finish" << finished << "errored" << errored);
 }
 
 std::string ParallelConnectionState::toString() const {
