@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -130,7 +129,7 @@ TEST_F(ShardRemoteTest, NetworkReplyWithLastCommittedOpTime) {
         return std::make_tuple(result, metadata);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 
     // Verify the targeted shard has updated its lastCommittedOpTime.
     ASSERT_EQ(expectedTime,
@@ -157,7 +156,7 @@ TEST_F(ShardRemoteTest, NetworkReplyWithoutLastCommittedOpTime) {
         return std::make_tuple(result, metadata);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 
     // Verify the targeted shard has not updated its lastCommittedOpTime.
     ASSERT_EQ(LogicalTime::kUninitialized,
@@ -186,14 +185,15 @@ TEST_F(ShardRemoteTest, ScatterGatherRepliesWithLastCommittedOpTime) {
         onCommandWithMetadata([&](const executor::RemoteCommandRequest& request) {
             std::vector<BSONObj> batch = {BSON("_id" << 1)};
             CursorResponse cursorResponse(nss, CursorId(123), batch);
-            auto result = cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
+            auto result = BSONObjBuilder(
+                cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse));
+            result.appendElements(makeLastCommittedOpTimeMetadata(expectedTime));
 
-            return executor::RemoteCommandResponse(
-                result, makeLastCommittedOpTimeMetadata(expectedTime), Milliseconds(1));
+            return executor::RemoteCommandResponse(result.obj(), Milliseconds(1));
         });
     }
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 
     // Verify all shards updated their lastCommittedOpTime.
     for (auto shardId : kTestShardIds) {
