@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -125,7 +124,7 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithSuccess) {
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableError) {
@@ -147,7 +146,7 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableError) {
         ASSERT_EQ(_nss.coll(), request.cmdObj.firstElement().valueStringData());
         return Status(ErrorCodes::FailedToParse, "failed to parse");
     });
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableErrorAllowPartialResults) {
@@ -170,7 +169,7 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableErrorAllowParti
         ASSERT_EQ(_nss.coll(), request.cmdObj.firstElement().valueStringData());
         return Status(ErrorCodes::FailedToParse, "failed to parse");
     });
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccess) {
@@ -202,7 +201,7 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccess)
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccessAllowPartialResults) {
@@ -235,7 +234,7 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccessAl
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrors) {
@@ -259,7 +258,7 @@ TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrors) {
             return Status(ErrorCodes::HostUnreachable, "host unreachable");
         });
     }
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrorsAllowPartialResults) {
@@ -287,7 +286,7 @@ TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrorsAllowPartialResu
             return Status(ErrorCodes::HostUnreachable, "host unreachable");
         });
     }
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesRespondWithSuccess) {
@@ -316,7 +315,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesRespondWithSuccess) {
         });
     }
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithNonretriableError) {
@@ -358,7 +357,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithNonretriableErr
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest,
@@ -402,7 +401,7 @@ TEST_F(EstablishCursorsTest,
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithRetriableErrorThenSuccess) {
@@ -453,7 +452,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithRetriableErrorT
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest,
@@ -505,7 +504,7 @@ TEST_F(EstablishCursorsTest,
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrors) {
@@ -555,7 +554,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrors) {
         });
     }
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrorsAllowPartialResults) {
@@ -607,7 +606,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrorsAllo
         });
     }
 
-    future.timed_get(kFutureTimeout);
+    future.default_timed_get();
 }
 
 }  // namespace
