@@ -101,6 +101,7 @@
 #include "mongo/util/exception_filter_win32.h"
 #include "mongo/util/exit.h"
 #include "mongo/util/fast_clock_source_factory.h"
+#include "mongo/util/latch_analyzer.h"
 #include "mongo/util/log.h"
 #include "mongo/util/net/socket_exception.h"
 #include "mongo/util/net/socket_utils.h"
@@ -338,6 +339,10 @@ void cleanupTask(ServiceContext* serviceContext) {
     }
 
     audit::logShutdown(Client::getCurrent());
+
+#ifndef MONGO_CONFIG_USE_RAW_LATCHES
+    LatchAnalyzer::get(serviceContext).dump();
+#endif
 }
 
 Status initializeSharding(OperationContext* opCtx) {
