@@ -1,30 +1,30 @@
-// engine.h
-
-/*    Copyright 2009 10gen Inc.
+/**
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects
- *    for all of the code used other than as permitted herein. If you modify
- *    file(s) with this exception, you may extend this exception to your
- *    version of the file(s), but you are not obligated to do so. If you do not
- *    wish to do so, delete this exception statement from your version. If you
- *    delete this exception statement from all source files in the program,
- *    then also delete it in the license file.
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
  */
 
 #pragma once
@@ -47,7 +47,8 @@ struct JSFile {
 };
 
 class Scope {
-    MONGO_DISALLOW_COPYING(Scope);
+    Scope(const Scope&) = delete;
+    Scope& operator=(const Scope&) = delete;
 
 public:
     Scope();
@@ -63,7 +64,6 @@ public:
         init(&o);
     }
 
-    virtual void localConnectForDbEval(OperationContext* opCtx, const char* dbName) = 0;
     virtual void externalSetup() = 0;
     virtual void setLocalDB(const std::string& localDBName) {
         _localDBName = localDBName;
@@ -174,14 +174,9 @@ public:
 
     static void validateObjectIdString(const std::string& str);
 
-    /** increments the number of times a scope was used */
-    void incTimesUsed() {
-        ++_numTimesUsed;
-    }
-
-    /** gets the number of times a scope was used */
-    int getTimesUsed() const {
-        return _numTimesUsed;
+    /** gets the time at which the scope was created */
+    Date_t getCreateTime() const {
+        return _createTime;
     }
 
     /** return true if last invoke() return'd native code */
@@ -189,20 +184,6 @@ public:
         return _lastRetIsNativeCode;
     }
 
-    class NoDBAccess {
-        Scope* _s;
-
-    public:
-        NoDBAccess(Scope* s) : _s(s) {}
-        ~NoDBAccess() {
-            _s->rename("____db____", "db");
-        }
-    };
-    NoDBAccess disableDBAccess(const char* why) {
-        rename("db", "____db____");
-        return NoDBAccess(this);
-    }
-
 protected:
     friend class PooledScope;
 
@@ -217,14 +198,15 @@ protected:
     std::string _localDBName;
     int64_t _loadedVersion;
     std::set<std::string> _storedNames;
-    static AtomicInt64 _lastVersion;
+    static AtomicWord<long long> _lastVersion;
     FunctionCacheMap _cachedFunctions;
-    int _numTimesUsed;
+    Date_t _createTime;
     bool _lastRetIsNativeCode;  // v8 only: set to true if eval'd script returns a native func
 };
 
 class ScriptEngine : public KillOpListenerInterface {
-    MONGO_DISALLOW_COPYING(ScriptEngine);
+    ScriptEngine(const ScriptEngine&) = delete;
+    ScriptEngine& operator=(const ScriptEngine&) = delete;
 
 public:
     ScriptEngine();
@@ -297,4 +279,4 @@ const char* jsSkipWhiteSpace(const char* raw);
 
 ScriptEngine* getGlobalScriptEngine();
 void setGlobalScriptEngine(ScriptEngine* impl);
-}
+}  // namespace mongo
