@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -38,7 +37,9 @@
 #include "mongo/db/client.h"
 #include "mongo/db/dbmessage.h"
 #include "mongo/db/stats/counters.h"
+#include "mongo/db/traffic_recorder.h"
 #include "mongo/rpc/message.h"
+#include "mongo/rpc/op_msg.h"
 #include "mongo/stdx/memory.h"
 #include "mongo/transport/message_compressor_manager.h"
 #include "mongo/transport/service_entry_point.h"
@@ -56,37 +57,91 @@
 
 namespace mongo {
 namespace {
-// Set up proper headers for formatting an exhaust request, if we need to
-bool setExhaustMessage(Message* m, const DbResponse& dbresponse) {
+/**
+ * Creates and returns a legacy exhaust message, if exhaust is allowed. The returned message is to
+ * be used as the subsequent 'synthetic' exhaust request. Returns an empty message if exhaust is not
+ * allowed. Any messages that do not have an opcode of OP_MSG are considered legacy.
+ */
+Message makeLegacyExhaustMessage(Message* m, const DbResponse& dbresponse) {
+    // OP_QUERY responses are always of type OP_REPLY.
+    invariant(dbresponse.response.operation() == opReply);
+
+    if (dbresponse.exhaustNS.empty()) {
+        return Message();
+    }
+
     MsgData::View header = dbresponse.response.header();
     QueryResult::View qr = header.view2ptr();
     long long cursorid = qr.getCursorId();
 
-    if (!cursorid) {
-        return false;
+    if (cursorid == 0) {
+        return Message();
     }
 
-    invariant(dbresponse.exhaustNS.size() && dbresponse.exhaustNS[0]);
-
-    auto ns = dbresponse.exhaustNS;  // m->reset() will free this so we must cache a copy
-
-    m->reset();
-
-    // Rebuild out the response.
+    // Generate a message that will act as the subsequent 'synthetic' exhaust request.
     BufBuilder b(512);
-    b.appendNum(static_cast<int>(0) /* size set later in setLen() */);
+    b.appendNum(static_cast<int>(0));          // size set later in setLen()
     b.appendNum(header.getId());               // message id
     b.appendNum(header.getResponseToMsgId());  // in response to
     b.appendNum(static_cast<int>(dbGetMore));  // opCode is OP_GET_MORE
     b.appendNum(static_cast<int>(0));          // Must be ZERO (reserved)
-    b.appendStr(ns);                           // Namespace
+    b.appendStr(dbresponse.exhaustNS);         // Namespace
     b.appendNum(static_cast<int>(0));          // ntoreturn
     b.appendNum(cursorid);                     // cursor id from the OP_REPLY
 
     MsgData::View(b.buf()).setLen(b.len());
-    m->setData(b.release());
 
-    return true;
+    return Message(b.release());
+}
+
+/**
+ * Given a request and its already generated response, checks for exhaust flags. If exhaust is
+ * allowed, modifies the given request message to produce the subsequent exhaust message, and
+ * modifies the response message to indicate it is part of an exhaust stream. Returns the modified
+ * request message for it to be used as the subsequent, 'synthetic' exhaust request. Returns an
+ * empty message if exhaust is not allowed.
+ *
+ * Currently only supports exhaust for 'getMore' commands.
+ */
+Message makeExhaustMessage(Message requestMsg, DbResponse* dbresponse) {
+    if (requestMsg.operation() == dbQuery) {
+        return makeLegacyExhaustMessage(&requestMsg, *dbresponse);
+    }
+
+    if (!OpMsgRequest::isFlagSet(requestMsg, OpMsg::kExhaustSupported)) {
+        return Message();
+    }
+
+    // Only support exhaust for 'getMore' commands.
+    auto request = OpMsgRequest::parse(requestMsg);
+    if (request.getCommandName() != "getMore"_sd) {
+        return Message();
+    }
+
+    // A returned cursor id of '0' indicates that the cursor is exhausted and so the exhaust stream
+    // should be terminated. Also make sure the cursor namespace is valid.
+    if (dbresponse->exhaustCursorId == 0 || dbresponse->exhaustNS.empty()) {
+        return Message();
+    }
+
+    const bool checksumPresent = OpMsg::isFlagSet(requestMsg, OpMsg::kChecksumPresent);
+    OpMsg::removeChecksum(&dbresponse->response);
+    // Indicate that the response is part of an exhaust stream. Re-checksum if needed.
+    OpMsg::setFlag(&dbresponse->response, OpMsg::kMoreToCome);
+    if (checksumPresent) {
+        OpMsg::appendChecksum(&dbresponse->response);
+    }
+
+    // Return an augmented form of the initial request, which is to be used as the next request to
+    // be processed by the database. The id of the response is used as the request id of this
+    // 'synthetic' request. Re-checksum if needed.
+    OpMsg::removeChecksum(&requestMsg);
+    requestMsg.header().setId(dbresponse->response.header().getId());
+    requestMsg.header().setResponseToMsgId(dbresponse->response.header().getResponseToMsgId());
+    if (checksumPresent) {
+        OpMsg::appendChecksum(&requestMsg);
+    }
+    return requestMsg;
 }
 
 }  // namespace
@@ -105,7 +160,8 @@ class ServiceStateMachine::ThreadGuard {
 
 public:
     explicit ThreadGuard(ServiceStateMachine* ssm) : _ssm{ssm} {
-        auto owned = _ssm->_owned.compareAndSwap(Ownership::kUnowned, Ownership::kOwned);
+        auto owned = Ownership::kUnowned;
+        _ssm->_owned.compareAndSwap(&owned, Ownership::kOwned);
         if (owned == Ownership::kStatic) {
             dassert(haveClient());
             dassert(Client::getCurrent() == _ssm->_dbClientPtr);
@@ -308,7 +364,8 @@ void ServiceStateMachine::_sourceCallback(Status status) {
                                       transport::ServiceExecutorTaskName::kSSMProcessMessage);
     } else if (ErrorCodes::isInterruption(status.code()) ||
                ErrorCodes::isNetworkError(status.code())) {
-        LOG(2) << "Session from " << remote << " encountered a network error during SourceMessage";
+        LOG(2) << "Session from " << remote
+               << " encountered a network error during SourceMessage: " << status;
         _state.store(State::EndSession);
     } else if (status == TransportLayer::TicketSessionClosedStatus) {
         // Our session may have been closed internally.
@@ -360,6 +417,9 @@ void ServiceStateMachine::_sinkCallback(Status status) {
 void ServiceStateMachine::_processMessage(ThreadGuard guard) {
     invariant(!_inMessage.empty());
 
+    TrafficRecorder::get(_serviceContext)
+        .observe(_sessionHandle, _serviceContext->getPreciseClockSource()->now(), _inMessage);
+
     auto& compressorMgr = MessageCompressorManager::forSession(_session());
 
     _compressorId = boost::none;
@@ -388,17 +448,30 @@ void ServiceStateMachine::_processMessage(ThreadGuard guard) {
     Message& toSink = dbresponse.response;
     if (!toSink.empty()) {
         invariant(!OpMsg::isFlagSet(_inMessage, OpMsg::kMoreToCome));
+        invariant(!OpMsg::isFlagSet(toSink, OpMsg::kChecksumPresent));
+
+        // Update the header for the response message.
         toSink.header().setId(nextMessageId());
         toSink.header().setResponseToMsgId(_inMessage.header().getId());
-
-        // If this is an exhaust cursor, don't source more Messages
-        if (dbresponse.exhaustNS.size() > 0 && setExhaustMessage(&_inMessage, dbresponse)) {
-            _inExhaust = true;
-        } else {
-            _inExhaust = false;
-            _inMessage.reset();
+        if (OpMsg::isFlagSet(_inMessage, OpMsg::kChecksumPresent)) {
+#ifdef MONGO_CONFIG_SSL
+            if (!SSLPeerInfo::forSession(_session()).isTLS) {
+                OpMsg::appendChecksum(&toSink);
+            }
+#else
+            OpMsg::appendChecksum(&toSink);
+#endif
         }
 
+        // If the incoming message has the exhaust flag set and is a 'getMore' command, then we
+        // bypass the normal RPC behavior. We will sink the response to the network, but we also
+        // synthesize a new 'getMore' request, as if we sourced a new message from the network. This
+        // new request is sent to the database once again to be processed. This cycle repeats as
+        // long as the associated cursor is not exhausted. Once it is exhausted, we will send a
+        // final response, terminating the exhaust stream.
+        _inMessage = makeExhaustMessage(_inMessage, &dbresponse);
+        _inExhaust = !_inMessage.empty();
+
         networkCounter.hitLogicalOut(toSink.size());
 
         if (_compressorId) {
@@ -406,6 +479,10 @@ void ServiceStateMachine::_processMessage(ThreadGuard guard) {
             uassertStatusOK(swm.getStatus());
             toSink = swm.getValue();
         }
+
+        TrafficRecorder::get(_serviceContext)
+            .observe(_sessionHandle, _serviceContext->getPreciseClockSource()->now(), toSink);
+
         _sinkMessage(std::move(guard), std::move(toSink));
 
     } else {
@@ -477,7 +554,7 @@ void ServiceStateMachine::_scheduleNextWithGuard(ThreadGuard guard,
                                                  transport::ServiceExecutor::ScheduleFlags flags,
                                                  transport::ServiceExecutorTaskName taskName,
                                                  Ownership ownershipModel) {
-    auto func = [ ssm = shared_from_this(), ownershipModel ] {
+    auto func = [ssm = shared_from_this(), ownershipModel] {
         ThreadGuard guard(ssm.get());
         if (ownershipModel == Ownership::kStatic)
             guard.markStaticOwnership();
