@@ -1,6 +1,3 @@
-// debug_util.cpp
-
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -125,4 +122,4 @@ void setupSIGTRAPforGDB() {
 #else
 void setupSIGTRAPforGDB() {}
 #endif
-}
+}  // namespace mongo
