@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -42,7 +41,7 @@
 #include "mongo/base/string_data.h"
 #include "mongo/bson/util/builder.h"
 #include "mongo/util/assert_util.h"
-#include "mongo/util/mongoutils/str.h"
+#include "mongo/util/str.h"
 
 namespace mongo {
 namespace dns {
@@ -403,7 +402,7 @@ private:
     void streamCore(StreamLike& os) const {
         std::for_each(rbegin(_nameComponents),
                       rend(_nameComponents),
-                      [ first = true, &os ](const auto& component) mutable {
+                      [first = true, &os](const auto& component) mutable {
                           if (!first)
                               os << '.';
                           first = false;
@@ -440,7 +439,7 @@ private:
     // FQDNs and Relative Names are discriminated by this field.
     Qualification fullyQualified;
 };
-}  // detail_dns_host_name
+}  // namespace detail_dns_host_name
 
 // The `operator==` function has to be defined out-of-line, because it uses `make_equality_lens`
 // which is an auto-deduced return type function defined later in the class body.
