@@ -1662,7 +1662,9 @@ StatusWith<std::vector<std::string>> getSubjectAlternativeNames(PCCERT_CONTEXT c
                 sa->sin6_family = AF_INET6;
                 memcpy(&(sa->sin6_addr), ipAddrStruct.pbData, ipAddrStruct.cbData);
             }
-            names.push_back(SockAddr(ss, sizeof(struct sockaddr_storage)).getAddr());
+            names.push_back(
+                SockAddr(reinterpret_cast<sockaddr*>(&ss), sizeof(struct sockaddr_storage))
+                    .getAddr());
         }
     }
     return names;
