@@ -1,4 +1,3 @@
-
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -45,7 +44,7 @@ namespace mongo {
 
 namespace repl {
 class OplogEntryBase;
-class ReplOperation;
+class DurableReplOperation;
 }  // namespace repl
 
 namespace idl {
@@ -67,14 +66,19 @@ class UUID {
     friend class ShardsvrShardCollectionResponse;
     friend class DatabaseVersion;
     friend class DbCheckOplogCollection;
+    friend class EncryptionPlaceholder;
     friend class idl::import::One_UUID;
+    friend class IndexBuildEntry;
+    friend class KeyStoreRecord;
     friend class LogicalSessionId;
     friend class LogicalSessionToClient;
     friend class LogicalSessionIdToClient;
     friend class LogicalSessionFromClient;
+    friend class ResolvedKeyId;
     friend class repl::OplogEntryBase;
-    friend class repl::ReplOperation;
+    friend class repl::DurableReplOperation;
     friend class ResumeTokenInternal;
+    friend class VoteCommitIndexBuild;
 
 public:
     /**
@@ -122,7 +126,7 @@ public:
      * Returns a ConstDataRange view of the UUID.
      */
     ConstDataRange toCDR() const {
-        return ConstDataRange(reinterpret_cast<const char*>(_uuid.data()), _uuid.size());
+        return ConstDataRange(_uuid);
     }
 
     /**
@@ -130,6 +134,11 @@ public:
      */
     void appendToBuilder(BSONObjBuilder* builder, StringData name) const;
 
+    /**
+     * Appends to array builder as BinData(4, "...").
+     */
+    void appendToArrayBuilder(BSONArrayBuilder* builder) const;
+
     /**
      * Returns a BSON object of the form { uuid: BinData(4, "...") }.
      */
